declare namespace _default {
    export namespace backend {
        /**
         * @edata
         * @typedef {Object} SearchOptions
         * @property {string} key 关键字 getServerTime-获取服务器时间戳, getPKInfo-获取主播PK信息
         * @property {Object} [param] 参数
         */
        /**
         * @edata
         * @typedef {Object} GetServerTimeRsp
         * @property {number} startTime 开始的时间戳
         */
        /**
         * @edata
         * @typedef {Object} MemberInfo
         * @property {string} nickName 成员昵称
         * @property {string} avatarUrl 成员头像
         * @property {string} scorce 成员分数
         * @property {string} unionId 成员分数
         * @property {number} roomId 成员分数
         */
        /**
         * @edata
         * @typedef {Object} TeamInfo
         * @property {string} teamName 队伍名称
         * @property {number} teamScore 队伍分数
         * @property {number} scoreLevel 分数等级
         * @property {Array.<MemberInfo>} memberInfos 成员信息
         */
        /**
         * @edata
         * @typedef {Object} GetPKInfoRsp
         * @property {boolean} onPk 是否正在PK
         * @property {TeamInfo} leftTeam 发起队伍
         * @property {TeamInfo} rightTeam 接受队伍（数据结构同发起队伍）
         * @property {number} pkStatus PK状态, 0-不处于PK模式, 1-开启PK模式, 2-开启PK准备, 3-某局PK进行中, 4-某局PK结束中, 5-三局两胜结束
         * @property {number} pkResult PK结果, 0-平局, 1-左边赢, 2-右边赢
         * @property {number} remainSeconds 剩余秒数
         * @property {number} pkModeType 模式, 0-礼物模式, 1-礼物+人气模式, 2-匹配模式
         * @property {Array.<number>} pkResults 3局2胜每小局的结果, 0-平局, 1-左边赢, -1-右边赢
         */
        /**
         * 通用查询后台状态接口
         * @eapi
         * @param {SearchOptions} params 参数
         * @returns {Promise<GetServerTimeRsp|GetPKInfoRsp>} // key传入getServerTime参数时，返回GetServerTimeRsp，传入getPKInfo参数时, 返回GetPKInfoRsp
         */
        export function commonQuery(params: {
            /**
             * 关键字 getServerTime-获取服务器时间戳, getPKInfo-获取主播PK信息
             */
            key: string;
            /**
             * 参数
             */
            param?: Object;
        }): Promise<{
            /**
             * 开始的时间戳
             */
            startTime: number;
        } | {
            /**
             * 是否正在PK
             */
            onPk: boolean;
            /**
             * 发起队伍
             */
            leftTeam: {
                /**
                 * 队伍名称
                 */
                teamName: string;
                /**
                 * 队伍分数
                 */
                teamScore: number;
                /**
                 * 分数等级
                 */
                scoreLevel: number;
                /**
                 * 成员信息
                 */
                memberInfos: {
                    /**
                     * 成员昵称
                     */
                    nickName: string;
                    /**
                     * 成员头像
                     */
                    avatarUrl: string;
                    /**
                     * 成员分数
                     */
                    scorce: string;
                    /**
                     * 成员分数
                     */
                    unionId: string;
                    /**
                     * 成员分数
                     */
                    roomId: number;
                }[];
            };
            /**
             * 接受队伍（数据结构同发起队伍）
             */
            rightTeam: {
                /**
                 * 队伍名称
                 */
                teamName: string;
                /**
                 * 队伍分数
                 */
                teamScore: number;
                /**
                 * 分数等级
                 */
                scoreLevel: number;
                /**
                 * 成员信息
                 */
                memberInfos: {
                    /**
                     * 成员昵称
                     */
                    nickName: string;
                    /**
                     * 成员头像
                     */
                    avatarUrl: string;
                    /**
                     * 成员分数
                     */
                    scorce: string;
                    /**
                     * 成员分数
                     */
                    unionId: string;
                    /**
                     * 成员分数
                     */
                    roomId: number;
                }[];
            };
            /**
             * PK状态, 0-不处于PK模式, 1-开启PK模式, 2-开启PK准备, 3-某局PK进行中, 4-某局PK结束中, 5-三局两胜结束
             */
            pkStatus: number;
            /**
             * PK结果, 0-平局, 1-左边赢, 2-右边赢
             */
            pkResult: number;
            /**
             * 剩余秒数
             */
            remainSeconds: number;
            /**
             * 模式, 0-礼物模式, 1-礼物+人气模式, 2-匹配模式
             */
            pkModeType: number;
            /**
             * 3局2胜每小局的结果, 0-平局, 1-左边赢, -1-右边赢
             */
            pkResults: number[];
        }>;
        /**
         * @edata
         * @typedef {Object} SearchOptions
         * @property {string} key 关键字 getServerTime-获取服务器时间戳, getPKInfo-获取主播PK信息
         * @property {Object} [param] 参数
         */
        /**
         * @edata
         * @typedef {Object} GetServerTimeRsp
         * @property {number} startTime 开始的时间戳
         */
        /**
         * @edata
         * @typedef {Object} MemberInfo
         * @property {string} nickName 成员昵称
         * @property {string} avatarUrl 成员头像
         * @property {string} scorce 成员分数
         * @property {string} unionId 成员分数
         * @property {number} roomId 成员分数
         */
        /**
         * @edata
         * @typedef {Object} TeamInfo
         * @property {string} teamName 队伍名称
         * @property {number} teamScore 队伍分数
         * @property {number} scoreLevel 分数等级
         * @property {Array.<MemberInfo>} memberInfos 成员信息
         */
        /**
         * @edata
         * @typedef {Object} GetPKInfoRsp
         * @property {boolean} onPk 是否正在PK
         * @property {TeamInfo} leftTeam 发起队伍
         * @property {TeamInfo} rightTeam 接受队伍（数据结构同发起队伍）
         * @property {number} pkStatus PK状态, 0-不处于PK模式, 1-开启PK模式, 2-开启PK准备, 3-某局PK进行中, 4-某局PK结束中, 5-三局两胜结束
         * @property {number} pkResult PK结果, 0-平局, 1-左边赢, 2-右边赢
         * @property {number} remainSeconds 剩余秒数
         * @property {number} pkModeType 模式, 0-礼物模式, 1-礼物+人气模式, 2-匹配模式
         * @property {Array.<number>} pkResults 3局2胜每小局的结果, 0-平局, 1-左边赢, -1-右边赢
         */
        /**
         * 通用查询后台状态接口
         * @eapi
         * @param {SearchOptions} params 参数
         * @returns {Promise<GetServerTimeRsp|GetPKInfoRsp>} // key传入getServerTime参数时，返回GetServerTimeRsp，传入getPKInfo参数时, 返回GetPKInfoRsp
         */
        export function commonQuery(params: {
            /**
             * 关键字 getServerTime-获取服务器时间戳, getPKInfo-获取主播PK信息
             */
            key: string;
            /**
             * 参数
             */
            param?: Object;
        }): Promise<{
            /**
             * 开始的时间戳
             */
            startTime: number;
        } | {
            /**
             * 是否正在PK
             */
            onPk: boolean;
            /**
             * 发起队伍
             */
            leftTeam: {
                /**
                 * 队伍名称
                 */
                teamName: string;
                /**
                 * 队伍分数
                 */
                teamScore: number;
                /**
                 * 分数等级
                 */
                scoreLevel: number;
                /**
                 * 成员信息
                 */
                memberInfos: {
                    /**
                     * 成员昵称
                     */
                    nickName: string;
                    /**
                     * 成员头像
                     */
                    avatarUrl: string;
                    /**
                     * 成员分数
                     */
                    scorce: string;
                    /**
                     * 成员分数
                     */
                    unionId: string;
                    /**
                     * 成员分数
                     */
                    roomId: number;
                }[];
            };
            /**
             * 接受队伍（数据结构同发起队伍）
             */
            rightTeam: {
                /**
                 * 队伍名称
                 */
                teamName: string;
                /**
                 * 队伍分数
                 */
                teamScore: number;
                /**
                 * 分数等级
                 */
                scoreLevel: number;
                /**
                 * 成员信息
                 */
                memberInfos: {
                    /**
                     * 成员昵称
                     */
                    nickName: string;
                    /**
                     * 成员头像
                     */
                    avatarUrl: string;
                    /**
                     * 成员分数
                     */
                    scorce: string;
                    /**
                     * 成员分数
                     */
                    unionId: string;
                    /**
                     * 成员分数
                     */
                    roomId: number;
                }[];
            };
            /**
             * PK状态, 0-不处于PK模式, 1-开启PK模式, 2-开启PK准备, 3-某局PK进行中, 4-某局PK结束中, 5-三局两胜结束
             */
            pkStatus: number;
            /**
             * PK结果, 0-平局, 1-左边赢, 2-右边赢
             */
            pkResult: number;
            /**
             * 剩余秒数
             */
            remainSeconds: number;
            /**
             * 模式, 0-礼物模式, 1-礼物+人气模式, 2-匹配模式
             */
            pkModeType: number;
            /**
             * 3局2胜每小局的结果, 0-平局, 1-左边赢, -1-右边赢
             */
            pkResults: number[];
        }>;
        /**
         * @edata
         * @typedef {Enum} ControlPanelExtTypes
         * @param {string} web_popup 虎牙主站-浮窗
         * @param {string} app_popup 虎牙直播APP-浮窗
         * @param {string} zs_anchor_popup 虎牙助手-浮窗
         * @param {string} pc_popup PC观众端浮窗
         * @param {string} web_video_com  虎牙主站-面板
         * @param {string} app_panel 虎牙直播APP-面板
         * @param {string} pc_panel PC观众端面板
         */
        /**
         * @edata
         * @typedef {Enum} ControlPanelLoadExtTypes
         * @param {string} web_popup 虎牙主站-浮窗
         * @param {string} app_popup 虎牙直播APP-浮窗
         * @param {string} zs_anchor_popup 虎牙助手-浮窗
         * @param {string} pc_popup PC观众端浮窗
         *
         */
        /**
         * @edata
         * @typedef {Enum} ControlEntranceExtTypes
         * @param {string} web_video_com  虎牙主站-面板
         * @param {string} app_panel 虎牙直播APP-面板
         * @param {string} pc_panel PC观众端面板
         */
        /**
         * @edata
         * @typedef {Object} ControlReq
         * @property {ControlEntranceExtTypes|ControlPanelLoadExtTypes|ControlPanelExtTypes} extTypes 观众端小程序类型枚举（逗号分隔），一共有3种枚举，每种枚举都与key对应。
         * @property {boolean} visible 是否显示
         */
        /**
         * @edata
         * @typedef {Object} ControlRsp
         * @property {number} status 状态码, 0为成功
         * @property {string} msg 描述
         */
        /**
         * @edata
         * @inner
         * @typedef {Object} SendMessageReqByRoomId
         * @property {string} message 发言内容，默认长度30个字符，过长会自动截断
         * @property {number} roomId 直播间ID
         */
        /**
         * @edata
         * @inner
         * @typedef {Object} SendMessageReq
         * @property {string} message 发言内容，默认长度30个字符，过长会自动截断
         */
        /**
         * @edata
         * @inner
         * @typedef {Enum} SendMessageErrorEnum
         * @param {number} number2  发送失败/权限问题/频率超出
         * @param {number} number17 贵族表情拦截
         * @param {number} number107 直播间封禁弹幕或者高危敏感词
         * @param {number} number905 未绑定手机号
         */
        /**
         * @edata
         * @inner
         * @typedef {Object} SendMessageRsp
         * @property {string} message 错误提示
         * @property {SendMessageErrorEnum} res 状态码
         */
        /**
         * @edata
         * @typedef {Enum} ControOperateKey
         * @param {string} controlEntrance  主播端控制观众端小程序入口
         * @param {string} controlPanelLoad 主播端控制观众端小程序面板加载
         * @param {string} controlPanelShow 主播端控制观众端小程序面板展示
         */
        /**
         * @edata
         * @typedef {Object} ControOperateOptions
         * @property {ControOperateKey} key 关键字
         * @property {ControlReq} param 参数,
         */
        /**
         * @edata
         * @inner
         * @typedef {Enum} SendMessageOperateKey
         * @param {string} sendUserMessage 当前直播间发言接口
         * @param {string} sendRoomMessage 指定直播间发言接口
         */
        /**
         * @edata
         * @inner
         * @typedef {Object} SendMessageOperateOptions
         * @property {SendMessageOperateKey} key 关键字
         * @property {SendMessageReq|SendMessageReqByRoomId} param 参数,
         */
        /**
         * 通用上行接口
         * @summary 端上直接请求服务器
         * @eapi
         * @param {ControOperateOptions|SendMessageOperateOptions} params 操作选项
         * @returns {Promise<ControlRsp|SendMessageRsp>} 返回结果
         */
        export function commonOperate(params: {
            /**
             * 关键字
             */
            key: any;
            /**
             * 参数,
             */
            param: {
                /**
                 * 观众端小程序类型枚举（逗号分隔），一共有3种枚举，每种枚举都与key对应。
                 */
                extTypes: any;
                /**
                 * 是否显示
                 */
                visible: boolean;
            };
        } | {
            /**
             * 关键字
             */
            key: any;
            /**
             * 参数,
             */
            param: {
                /**
                 * 发言内容，默认长度30个字符，过长会自动截断
                 */
                message: string;
            } | {
                /**
                 * 发言内容，默认长度30个字符，过长会自动截断
                 */
                message: string;
                /**
                 * 直播间ID
                 */
                roomId: number;
            };
        }): Promise<{
            /**
             * 状态码, 0为成功
             */
            status: number;
            /**
             * 描述
             */
            msg: string;
        } | {
            /**
             * 错误提示
             */
            message: string;
            /**
             * 状态码
             */
            res: any;
        }>;
        /**
         * @edata
         * @typedef {Enum} ControlPanelExtTypes
         * @param {string} web_popup 虎牙主站-浮窗
         * @param {string} app_popup 虎牙直播APP-浮窗
         * @param {string} zs_anchor_popup 虎牙助手-浮窗
         * @param {string} pc_popup PC观众端浮窗
         * @param {string} web_video_com  虎牙主站-面板
         * @param {string} app_panel 虎牙直播APP-面板
         * @param {string} pc_panel PC观众端面板
         */
        /**
         * @edata
         * @typedef {Enum} ControlPanelLoadExtTypes
         * @param {string} web_popup 虎牙主站-浮窗
         * @param {string} app_popup 虎牙直播APP-浮窗
         * @param {string} zs_anchor_popup 虎牙助手-浮窗
         * @param {string} pc_popup PC观众端浮窗
         *
         */
        /**
         * @edata
         * @typedef {Enum} ControlEntranceExtTypes
         * @param {string} web_video_com  虎牙主站-面板
         * @param {string} app_panel 虎牙直播APP-面板
         * @param {string} pc_panel PC观众端面板
         */
        /**
         * @edata
         * @typedef {Object} ControlReq
         * @property {ControlEntranceExtTypes|ControlPanelLoadExtTypes|ControlPanelExtTypes} extTypes 观众端小程序类型枚举（逗号分隔），一共有3种枚举，每种枚举都与key对应。
         * @property {boolean} visible 是否显示
         */
        /**
         * @edata
         * @typedef {Object} ControlRsp
         * @property {number} status 状态码, 0为成功
         * @property {string} msg 描述
         */
        /**
         * @edata
         * @inner
         * @typedef {Object} SendMessageReqByRoomId
         * @property {string} message 发言内容，默认长度30个字符，过长会自动截断
         * @property {number} roomId 直播间ID
         */
        /**
         * @edata
         * @inner
         * @typedef {Object} SendMessageReq
         * @property {string} message 发言内容，默认长度30个字符，过长会自动截断
         */
        /**
         * @edata
         * @inner
         * @typedef {Enum} SendMessageErrorEnum
         * @param {number} number2  发送失败/权限问题/频率超出
         * @param {number} number17 贵族表情拦截
         * @param {number} number107 直播间封禁弹幕或者高危敏感词
         * @param {number} number905 未绑定手机号
         */
        /**
         * @edata
         * @inner
         * @typedef {Object} SendMessageRsp
         * @property {string} message 错误提示
         * @property {SendMessageErrorEnum} res 状态码
         */
        /**
         * @edata
         * @typedef {Enum} ControOperateKey
         * @param {string} controlEntrance  主播端控制观众端小程序入口
         * @param {string} controlPanelLoad 主播端控制观众端小程序面板加载
         * @param {string} controlPanelShow 主播端控制观众端小程序面板展示
         */
        /**
         * @edata
         * @typedef {Object} ControOperateOptions
         * @property {ControOperateKey} key 关键字
         * @property {ControlReq} param 参数,
         */
        /**
         * @edata
         * @inner
         * @typedef {Enum} SendMessageOperateKey
         * @param {string} sendUserMessage 当前直播间发言接口
         * @param {string} sendRoomMessage 指定直播间发言接口
         */
        /**
         * @edata
         * @inner
         * @typedef {Object} SendMessageOperateOptions
         * @property {SendMessageOperateKey} key 关键字
         * @property {SendMessageReq|SendMessageReqByRoomId} param 参数,
         */
        /**
         * 通用上行接口
         * @summary 端上直接请求服务器
         * @eapi
         * @param {ControOperateOptions|SendMessageOperateOptions} params 操作选项
         * @returns {Promise<ControlRsp|SendMessageRsp>} 返回结果
         */
        export function commonOperate(params: {
            /**
             * 关键字
             */
            key: any;
            /**
             * 参数,
             */
            param: {
                /**
                 * 观众端小程序类型枚举（逗号分隔），一共有3种枚举，每种枚举都与key对应。
                 */
                extTypes: any;
                /**
                 * 是否显示
                 */
                visible: boolean;
            };
        } | {
            /**
             * 关键字
             */
            key: any;
            /**
             * 参数,
             */
            param: {
                /**
                 * 发言内容，默认长度30个字符，过长会自动截断
                 */
                message: string;
            } | {
                /**
                 * 发言内容，默认长度30个字符，过长会自动截断
                 */
                message: string;
                /**
                 * 直播间ID
                 */
                roomId: number;
            };
        }): Promise<{
            /**
             * 状态码, 0为成功
             */
            status: number;
            /**
             * 描述
             */
            msg: string;
        } | {
            /**
             * 错误提示
             */
            message: string;
            /**
             * 状态码
             */
            res: any;
        }>;
    }
}
export default _default;
