declare namespace _default {
    export namespace context {
        /**
         * @edata
         * @callback ContextOnCallback
         * @param {Object} content 宿主消息
         */
        /**
         * 监听直播间消息
         * @eapi
         * @param {string} topic 宿主消息名 subscribeSubmit-【观众端】当前观众订阅状态发生变化, giftSubmit-【观众端】当前观众送礼, barrageSubmit-当前用户发送弹幕
         * @param {ContextOnCallback} callback 收到消息时回调 返回消息内容
         */
        export function on(topic: string, callback: (content: Object) => any): any;
        /**
         * @edata
         * @callback ContextOnCallback
         * @param {Object} content 宿主消息
         */
        /**
         * 监听直播间消息
         * @eapi
         * @param {string} topic 宿主消息名 subscribeSubmit-【观众端】当前观众订阅状态发生变化, giftSubmit-【观众端】当前观众送礼, barrageSubmit-当前用户发送弹幕
         * @param {ContextOnCallback} callback 收到消息时回调 返回消息内容
         */
        export function on(topic: string, callback: (content: Object) => any): any;
        /**
         * 取消监听直播间消息
         * @eapi
         * @param {string} topic 宿主消息名 subscribeSubmit-【观众端】当前观众订阅状态发生变化, giftSubmit-【观众端】当前观众送礼, barrageSubmit-当前用户发送弹幕
         * @param {ContextOnCallback} [callback] 收到消息时回调 返回消息内容
         */
        export function off(topic: string, callback?: ((content: Object) => any) | undefined): any;
        /**
         * 取消监听直播间消息
         * @eapi
         * @param {string} topic 宿主消息名 subscribeSubmit-【观众端】当前观众订阅状态发生变化, giftSubmit-【观众端】当前观众送礼, barrageSubmit-当前用户发送弹幕
         * @param {ContextOnCallback} [callback] 收到消息时回调 返回消息内容
         */
        export function off(topic: string, callback?: ((content: Object) => any) | undefined): any;
        /**
         * 显示互动通道入口红点
         * @summary 仅面板类型小程序适用
         * @eapi
         * @returns {Promise<void>} 返回是否显示成功
         */
        export function showActivityBadge(): Promise<void>;
        /**
         * 显示互动通道入口红点
         * @summary 仅面板类型小程序适用
         * @eapi
         * @returns {Promise<void>} 返回是否显示成功
         */
        export function showActivityBadge(): Promise<void>;
        /**
         * 显示toast
         * @eapi
         * @param {string} message toast中显示的消息
         * @returns {Promise<void>}
         */
        export function showToast(message: string): Promise<void>;
        /**
         * 显示toast
         * @eapi
         * @param {string} message toast中显示的消息
         * @returns {Promise<void>}
         */
        export function showToast(message: string): Promise<void>;
        /**
         * 全区域位置信息
         * @edata
         * @typedef {Object} PositionInfo
         * @property {number} left 安全区域距离容器左侧的像素值
         * @property {number} top 安全区域距离容器上侧的像素值
         * @property {number} right 安全区域距离容器右侧的像素值
         * @property {number} bottom 安全区域距离容器下侧的像素值
         */
        /**
         * 获取安全区域的位置
         * @eapi
         * @returns {Promise<PositionInfo>} 返回安全区域位置信息
         */
        export function getSafeAreaPosition(): Promise<{
            /**
             * 安全区域距离容器左侧的像素值
             */
            left: number;
            /**
             * 安全区域距离容器上侧的像素值
             */
            top: number;
            /**
             * 安全区域距离容器右侧的像素值
             */
            right: number;
            /**
             * 安全区域距离容器下侧的像素值
             */
            bottom: number;
        }>;
        /**
         * 全区域位置信息
         * @edata
         * @typedef {Object} PositionInfo
         * @property {number} left 安全区域距离容器左侧的像素值
         * @property {number} top 安全区域距离容器上侧的像素值
         * @property {number} right 安全区域距离容器右侧的像素值
         * @property {number} bottom 安全区域距离容器下侧的像素值
         */
        /**
         * 获取安全区域的位置
         * @eapi
         * @returns {Promise<PositionInfo>} 返回安全区域位置信息
         */
        export function getSafeAreaPosition(): Promise<{
            /**
             * 安全区域距离容器左侧的像素值
             */
            left: number;
            /**
             * 安全区域距离容器上侧的像素值
             */
            top: number;
            /**
             * 安全区域距离容器右侧的像素值
             */
            right: number;
            /**
             * 安全区域距离容器下侧的像素值
             */
            bottom: number;
        }>;
        /**
         * 容器变化消息
         * @edata
         * @typedef {Object} LayoutInfo
         * @property {number} screenWidth 容器宽度
         * @property {number} screenHeight 容器高度
         * @property {boolean} isLandscape 是否横屏，web端固定为true
         */
        /**
         * 小程序容器布局变化回调
         * @edata
         * @callback LayoutChange
         * @param {LayoutInfo} info 容器变化消息
         */
        /**
         * 监听当前直播间小程序容器布局变化消息
         * @summary 适用于浮窗小程序类型
         * @eapi
         * @param {LayoutChange} callback 小程序容器布局变化回调
         * @returns {Promise<void>}
         */
        export function onLayoutChange(callback: (info: {
            /**
             * 容器宽度
             */
            screenWidth: number;
            /**
             * 容器高度
             */
            screenHeight: number;
            /**
             * 是否横屏，web端固定为true
             */
            isLandscape: boolean;
        }) => any): Promise<void>;
        /**
         * 容器变化消息
         * @edata
         * @typedef {Object} LayoutInfo
         * @property {number} screenWidth 容器宽度
         * @property {number} screenHeight 容器高度
         * @property {boolean} isLandscape 是否横屏，web端固定为true
         */
        /**
         * 小程序容器布局变化回调
         * @edata
         * @callback LayoutChange
         * @param {LayoutInfo} info 容器变化消息
         */
        /**
         * 监听当前直播间小程序容器布局变化消息
         * @summary 适用于浮窗小程序类型
         * @eapi
         * @param {LayoutChange} callback 小程序容器布局变化回调
         * @returns {Promise<void>}
         */
        export function onLayoutChange(callback: (info: {
            /**
             * 容器宽度
             */
            screenWidth: number;
            /**
             * 容器高度
             */
            screenHeight: number;
            /**
             * 是否横屏，web端固定为true
             */
            isLandscape: boolean;
        }) => any): Promise<void>;
        /**
         * 引导订阅
         * @summary 用户完成交互后自动帮用户订阅当前直播间
         * @eapi
         * @returns {Promise<void>}
         */
        export function leadSubscribe(): Promise<void>;
        /**
         * 引导订阅
         * @summary 用户完成交互后自动帮用户订阅当前直播间
         * @eapi
         * @returns {Promise<void>}
         */
        export function leadSubscribe(): Promise<void>;
        /**
         * 直播间礼物配置
         * @edata
         * @typedef {Object} RoomGiftConfig
         * @property {number} giftId 礼物Id
         * @property {string} giftName 礼物名称
         * @property {string} giftLogo 礼物图标
         * @property {string} giftGif 小程序图标（gif动图）
         * @property {number} giftPriceHuya 礼物价格（虎牙币）
         * @property {number} giftPriceGreenBean 礼物价格（金豆）
         * @property {number} giftPriceWhiteBean 礼物价格（银豆）, -1-表示此礼物不支持使用银豆购买
         */
        /**
         * 获取当前直播间礼物配置
         * @eapi
         * @returns {Promise<RoomGiftConfig>} 返回直播间礼物配置
         */
        export function getGiftConf(): Promise<{
            /**
             * 礼物Id
             */
            giftId: number;
            /**
             * 礼物名称
             */
            giftName: string;
            /**
             * 礼物图标
             */
            giftLogo: string;
            /**
             * 小程序图标（gif动图）
             */
            giftGif: string;
            /**
             * 礼物价格（虎牙币）
             */
            giftPriceHuya: number;
            /**
             * 礼物价格（金豆）
             */
            giftPriceGreenBean: number;
            /**
             * 礼物价格（银豆）, -1-表示此礼物不支持使用银豆购买
             */
            giftPriceWhiteBean: number;
        }>;
        /**
         * 直播间礼物配置
         * @edata
         * @typedef {Object} RoomGiftConfig
         * @property {number} giftId 礼物Id
         * @property {string} giftName 礼物名称
         * @property {string} giftLogo 礼物图标
         * @property {string} giftGif 小程序图标（gif动图）
         * @property {number} giftPriceHuya 礼物价格（虎牙币）
         * @property {number} giftPriceGreenBean 礼物价格（金豆）
         * @property {number} giftPriceWhiteBean 礼物价格（银豆）, -1-表示此礼物不支持使用银豆购买
         */
        /**
         * 获取当前直播间礼物配置
         * @eapi
         * @returns {Promise<RoomGiftConfig>} 返回直播间礼物配置
         */
        export function getGiftConf(): Promise<{
            /**
             * 礼物Id
             */
            giftId: number;
            /**
             * 礼物名称
             */
            giftName: string;
            /**
             * 礼物图标
             */
            giftLogo: string;
            /**
             * 小程序图标（gif动图）
             */
            giftGif: string;
            /**
             * 礼物价格（虎牙币）
             */
            giftPriceHuya: number;
            /**
             * 礼物价格（金豆）
             */
            giftPriceGreenBean: number;
            /**
             * 礼物价格（银豆）, -1-表示此礼物不支持使用银豆购买
             */
            giftPriceWhiteBean: number;
        }>;
        /**
         * 发送礼物信息
         * @edata
         * @typedef {Object} SendGiftInfo
         * @property {number} giftId 发送礼物Id
         * @property {number} giftCount 发送礼物个数
         */
        /**
         * 当前观众送礼
         * @summary 需要用户授权使用
         * @eapi
         * @param {SendGiftInfo} params 发送礼物信息
         * @returns {Promise<void>}
         */
        export function sendGift(params: {
            /**
             * 发送礼物Id
             */
            giftId: number;
            /**
             * 发送礼物个数
             */
            giftCount: number;
        }): Promise<void>;
        /**
         * 发送礼物信息
         * @edata
         * @typedef {Object} SendGiftInfo
         * @property {number} giftId 发送礼物Id
         * @property {number} giftCount 发送礼物个数
         */
        /**
         * 当前观众送礼
         * @summary 需要用户授权使用
         * @eapi
         * @param {SendGiftInfo} params 发送礼物信息
         * @returns {Promise<void>}
         */
        export function sendGift(params: {
            /**
             * 发送礼物Id
             */
            giftId: number;
            /**
             * 发送礼物个数
             */
            giftCount: number;
        }): Promise<void>;
        /**
         * 引导当前观众送礼
         * @summary 一般需要和监听当前用户送礼的消息配合使用
         * @eapi
         * @returns {Promise<void>} 引导成功返回送礼人信息
         */
        export function leadGift(): Promise<void>;
        /**
         * 引导当前观众送礼
         * @summary 一般需要和监听当前用户送礼的消息配合使用
         * @eapi
         * @returns {Promise<void>} 引导成功返回送礼人信息
         */
        export function leadGift(): Promise<void>;
        /**
         * 送礼人信息
         * @edata
         * @typedef {Object} GifterInfo
         * @property {string} sendNick 送礼人的昵称
         * @property {string} senderAvatarUrl 送礼人的头像地址
         * @property {string} itemName 礼物名称
         * @property {number} sendItemCount 礼物数量
         * @property {number} sendItemComboHits 送礼连击数
         * @property {number} itemId 礼物Id
         * @property {string} unionId 用户unionId
         */
        /**
         * 礼物变化过滤条件
         * @edata
         * @typedef {Object} GiftChangeOptions
         * @property {string} [sendNick] 用户昵称关键字
         * @property {string} [itemName] 礼物名称关键字
         * @property {number} [minSendItemCount] 礼物数量超过这个值才监听
         * @property {number} [minSendItemComboHits] 连击数量超过这个值才监听
         */
        /**
         * 礼物信息回调
         * @edata
         * @callback GiftChange
         * @param {GifterInfo} giftInfo 送礼人信息
         */
        /**
         * 监听当前直播间礼物变化消息
         * @summary 只保留最新的一次监听
         * - 最大触发频率为每50毫秒一条
         * @eapi
         * @param {GiftChangeOptions} options 过滤条件
         * @param {GiftChange} callback 礼物信息回调
         * @returns {Promise<void>} 操作结果
         */
        export function onGiftChange(options: {
            /**
             * 用户昵称关键字
             */
            sendNick?: string;
            /**
             * 礼物名称关键字
             */
            itemName?: string;
            /**
             * 礼物数量超过这个值才监听
             */
            minSendItemCount?: number;
            /**
             * 连击数量超过这个值才监听
             */
            minSendItemComboHits?: number;
        }, callback: (giftInfo: {
            /**
             * 送礼人的昵称
             */
            sendNick: string;
            /**
             * 送礼人的头像地址
             */
            senderAvatarUrl: string;
            /**
             * 礼物名称
             */
            itemName: string;
            /**
             * 礼物数量
             */
            sendItemCount: number;
            /**
             * 送礼连击数
             */
            sendItemComboHits: number;
            /**
             * 礼物Id
             */
            itemId: number;
            /**
             * 用户unionId
             */
            unionId: string;
        }) => any): Promise<void>;
        /**
         * 送礼人信息
         * @edata
         * @typedef {Object} GifterInfo
         * @property {string} sendNick 送礼人的昵称
         * @property {string} senderAvatarUrl 送礼人的头像地址
         * @property {string} itemName 礼物名称
         * @property {number} sendItemCount 礼物数量
         * @property {number} sendItemComboHits 送礼连击数
         * @property {number} itemId 礼物Id
         * @property {string} unionId 用户unionId
         */
        /**
         * 礼物变化过滤条件
         * @edata
         * @typedef {Object} GiftChangeOptions
         * @property {string} [sendNick] 用户昵称关键字
         * @property {string} [itemName] 礼物名称关键字
         * @property {number} [minSendItemCount] 礼物数量超过这个值才监听
         * @property {number} [minSendItemComboHits] 连击数量超过这个值才监听
         */
        /**
         * 礼物信息回调
         * @edata
         * @callback GiftChange
         * @param {GifterInfo} giftInfo 送礼人信息
         */
        /**
         * 监听当前直播间礼物变化消息
         * @summary 只保留最新的一次监听
         * - 最大触发频率为每50毫秒一条
         * @eapi
         * @param {GiftChangeOptions} options 过滤条件
         * @param {GiftChange} callback 礼物信息回调
         * @returns {Promise<void>} 操作结果
         */
        export function onGiftChange(options: {
            /**
             * 用户昵称关键字
             */
            sendNick?: string;
            /**
             * 礼物名称关键字
             */
            itemName?: string;
            /**
             * 礼物数量超过这个值才监听
             */
            minSendItemCount?: number;
            /**
             * 连击数量超过这个值才监听
             */
            minSendItemComboHits?: number;
        }, callback: (giftInfo: {
            /**
             * 送礼人的昵称
             */
            sendNick: string;
            /**
             * 送礼人的头像地址
             */
            senderAvatarUrl: string;
            /**
             * 礼物名称
             */
            itemName: string;
            /**
             * 礼物数量
             */
            sendItemCount: number;
            /**
             * 送礼连击数
             */
            sendItemComboHits: number;
            /**
             * 礼物Id
             */
            itemId: number;
            /**
             * 用户unionId
             */
            unionId: string;
        }) => any): Promise<void>;
        /**
         * 取消监听当前直播间礼物变化消息
         * @eapi
         * @returns {Promise<void>} 操作结果
         */
        export function offGiftChange(): Promise<void>;
        /**
         * 取消监听当前直播间礼物变化消息
         * @eapi
         * @returns {Promise<void>} 操作结果
         */
        export function offGiftChange(): Promise<void>;
        /**
         * 引导当前用户发送弹幕
         * @summary 一般需要和监听当前用户发言的消息配合使用
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function leadBarrage(): Promise<void>;
        /**
         * 引导当前用户发送弹幕
         * @summary 一般需要和监听当前用户发言的消息配合使用
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function leadBarrage(): Promise<void>;
        /**
         * 弹幕消息
         * @edata
         * @typedef {Object} BarragerInfo
         * @property {string} sendNick 发言人的昵称
         * @property {string} senderAvatarUrl 发言人的头像地址
         * @property {number} senderGender 发言人的性别, 0-女, 1-男
         * @property {number} nobleLevel 发言人的贵族等级
         * @property {number} fansLevel 发言人的粉丝等级
         * @property {string} content 弹幕内容
         * @property {string} unionId 用户unionId
         */
        /**
         * 弹幕信息回调
         * @edata
         * @callback BarrageCallback 弹幕信息回调
         * @param {BarragerInfo} barrageInfo 弹幕消息
         */
        /**
         * 弹幕筛选条件
         * @edata
         * @typedef {Object} OnBarrageChangeOptions
         * @property {string} [sendNick] 用户昵称关键字
         * @property {number} [nobleLevel] 贵族等级
         * @property {number} [fansLevel] 粉丝等级
         * @property {string} [content] 弹幕内容关键字
         */
        /**
         * 监听所有弹幕
         * @summary 只保留最新的一次监听
         * - 最大触发频率为每50毫秒一条
         * @eapi
         * @param {OnBarrageChangeOptions} options 弹幕筛选条件
         * @param {BarrageCallback} callback 弹幕信息回调
         * @returns {Promise<void>}
         */
        export function onBarrageChange(options: {
            /**
             * 用户昵称关键字
             */
            sendNick?: string;
            /**
             * 贵族等级
             */
            nobleLevel?: number;
            /**
             * 粉丝等级
             */
            fansLevel?: number;
            /**
             * 弹幕内容关键字
             */
            content?: string;
        }, callback: (barrageInfo: {
            /**
             * 发言人的昵称
             */
            sendNick: string;
            /**
             * 发言人的头像地址
             */
            senderAvatarUrl: string;
            /**
             * 发言人的性别, 0-女, 1-男
             */
            senderGender: number;
            /**
             * 发言人的贵族等级
             */
            nobleLevel: number;
            /**
             * 发言人的粉丝等级
             */
            fansLevel: number;
            /**
             * 弹幕内容
             */
            content: string;
            /**
             * 用户unionId
             */
            unionId: string;
        }) => any): Promise<void>;
        /**
         * 弹幕消息
         * @edata
         * @typedef {Object} BarragerInfo
         * @property {string} sendNick 发言人的昵称
         * @property {string} senderAvatarUrl 发言人的头像地址
         * @property {number} senderGender 发言人的性别, 0-女, 1-男
         * @property {number} nobleLevel 发言人的贵族等级
         * @property {number} fansLevel 发言人的粉丝等级
         * @property {string} content 弹幕内容
         * @property {string} unionId 用户unionId
         */
        /**
         * 弹幕信息回调
         * @edata
         * @callback BarrageCallback 弹幕信息回调
         * @param {BarragerInfo} barrageInfo 弹幕消息
         */
        /**
         * 弹幕筛选条件
         * @edata
         * @typedef {Object} OnBarrageChangeOptions
         * @property {string} [sendNick] 用户昵称关键字
         * @property {number} [nobleLevel] 贵族等级
         * @property {number} [fansLevel] 粉丝等级
         * @property {string} [content] 弹幕内容关键字
         */
        /**
         * 监听所有弹幕
         * @summary 只保留最新的一次监听
         * - 最大触发频率为每50毫秒一条
         * @eapi
         * @param {OnBarrageChangeOptions} options 弹幕筛选条件
         * @param {BarrageCallback} callback 弹幕信息回调
         * @returns {Promise<void>}
         */
        export function onBarrageChange(options: {
            /**
             * 用户昵称关键字
             */
            sendNick?: string;
            /**
             * 贵族等级
             */
            nobleLevel?: number;
            /**
             * 粉丝等级
             */
            fansLevel?: number;
            /**
             * 弹幕内容关键字
             */
            content?: string;
        }, callback: (barrageInfo: {
            /**
             * 发言人的昵称
             */
            sendNick: string;
            /**
             * 发言人的头像地址
             */
            senderAvatarUrl: string;
            /**
             * 发言人的性别, 0-女, 1-男
             */
            senderGender: number;
            /**
             * 发言人的贵族等级
             */
            nobleLevel: number;
            /**
             * 发言人的粉丝等级
             */
            fansLevel: number;
            /**
             * 弹幕内容
             */
            content: string;
            /**
             * 用户unionId
             */
            unionId: string;
        }) => any): Promise<void>;
        /**
         * 关闭监听所有弹幕
         * @eapi
         * @returns {Promise<void>}
         */
        export function offBarrageChange(): Promise<void>;
        /**
         * 关闭监听所有弹幕
         * @eapi
         * @returns {Promise<void>}
         */
        export function offBarrageChange(): Promise<void>;
        /**
         * 开启守护消息
         * @edata
         * @typedef {Object} OpenGuardianNotice
         * @property {number} openDays 开通或者续费天数
         * @property {number} lastGuardianLevel 开通或者续费之前的守护等级
         * @property {number} openGuardianLevel 开通或续费后守护等级
         * @property {string} presenterNick 主播昵称
         * @property {number} roomId 房间Id
         * @property {string} unionId 用户unionId
         * @property {string} userAvatarUrl 用户头像
         * @property {string} userNick 用户昵称
         */
        /**
         * 开通守护回调
         * @edata
         * @callback OpenGuardianNoticeCallback
         * @param {OpenGuardianNotice} notice 开启守护消息
         */
        /**
         * 监听开通守护参数
         * @edata
         * @typedef {Object} OpenGuardianNoticeParams
         * @property {OpenGuardianNoticeCallback} callback 开通守护回调
         */
        /**
         * 监听开通守护
         * @eapi
         * @param {OpenGuardianNoticeParams} params 监听开通守护参数
         * @returns {Promise<void>}
         */
        export function onOpenGuardianNotice(params: {
            /**
             * 开通守护回调
             */
            callback: (notice: {
                /**
                 * 开通或者续费天数
                 */
                openDays: number;
                /**
                 * 开通或者续费之前的守护等级
                 */
                lastGuardianLevel: number;
                /**
                 * 开通或续费后守护等级
                 */
                openGuardianLevel: number;
                /**
                 * 主播昵称
                 */
                presenterNick: string;
                /**
                 * 房间Id
                 */
                roomId: number;
                /**
                 * 用户unionId
                 */
                unionId: string;
                /**
                 * 用户头像
                 */
                userAvatarUrl: string;
                /**
                 * 用户昵称
                 */
                userNick: string;
            }) => any;
        }): Promise<void>;
        /**
         * 开启守护消息
         * @edata
         * @typedef {Object} OpenGuardianNotice
         * @property {number} openDays 开通或者续费天数
         * @property {number} lastGuardianLevel 开通或者续费之前的守护等级
         * @property {number} openGuardianLevel 开通或续费后守护等级
         * @property {string} presenterNick 主播昵称
         * @property {number} roomId 房间Id
         * @property {string} unionId 用户unionId
         * @property {string} userAvatarUrl 用户头像
         * @property {string} userNick 用户昵称
         */
        /**
         * 开通守护回调
         * @edata
         * @callback OpenGuardianNoticeCallback
         * @param {OpenGuardianNotice} notice 开启守护消息
         */
        /**
         * 监听开通守护参数
         * @edata
         * @typedef {Object} OpenGuardianNoticeParams
         * @property {OpenGuardianNoticeCallback} callback 开通守护回调
         */
        /**
         * 监听开通守护
         * @eapi
         * @param {OpenGuardianNoticeParams} params 监听开通守护参数
         * @returns {Promise<void>}
         */
        export function onOpenGuardianNotice(params: {
            /**
             * 开通守护回调
             */
            callback: (notice: {
                /**
                 * 开通或者续费天数
                 */
                openDays: number;
                /**
                 * 开通或者续费之前的守护等级
                 */
                lastGuardianLevel: number;
                /**
                 * 开通或续费后守护等级
                 */
                openGuardianLevel: number;
                /**
                 * 主播昵称
                 */
                presenterNick: string;
                /**
                 * 房间Id
                 */
                roomId: number;
                /**
                 * 用户unionId
                 */
                unionId: string;
                /**
                 * 用户头像
                 */
                userAvatarUrl: string;
                /**
                 * 用户昵称
                 */
                userNick: string;
            }) => any;
        }): Promise<void>;
        /**
         * 关闭监听开通守护
         * @returns {Promise<void>}
         */
        export function offOpenGuardianNotice(): Promise<void>;
        /**
         * 关闭监听开通守护
         * @returns {Promise<void>}
         */
        export function offOpenGuardianNotice(): Promise<void>;
        /**
         * 开启贵族消息
         * @edata
         * @typedef {Object} OpenNobleNotice
         * @property {number} startTime 贵族生效unix时间戳，单位是秒
         * @property {number} endTime 贵族失效unix时间戳，单位是秒
         * @property {number} openFlag 标志, 1-首次(非贵族开通任一贵族,或者低等级贵族更换高等级的贵族操作,都并入到首开), 2-续费
         * @property {number} months 开通月数
         * @property {number} nobleLevel 贵族等级
         * @property {number} nobleAttrType 贵族等级类型
         * @property {string} nobleName 贵族名
         * @property {number} roomId 房间Id
         * @property {string} unionId 用户unionId
         * @property {string} userAvatarUrl 用户头像
         * @property {string} userNick 用户昵称
         */
        /**
         * 开通贵族回调
         * @edata
         * @callback OpenNobleNoticeCallback
         * @param {OpenNobleNotice} notice 开启贵族消息
         */
        /**
         * 监听开通贵族参数
         * @edata
         * @typedef {Object} OnOpenNobleNoticeParams
         * @property {OpenNobleNoticeCallback} callback 监听开通贵族
         */
        /**
         * 监听开通贵族
         * @eapi
         * @param {OnOpenNobleNoticeParams} params 监听开通贵族参数
         * @returns {Promise<void>}
         */
        export function onOpenNobleNotice(params: {
            /**
             * 监听开通贵族
             */
            callback: (notice: {
                /**
                 * 贵族生效unix时间戳，单位是秒
                 */
                startTime: number;
                /**
                 * 贵族失效unix时间戳，单位是秒
                 */
                endTime: number;
                /**
                 * 标志, 1-首次(非贵族开通任一贵族,或者低等级贵族更换高等级的贵族操作,都并入到首开), 2-续费
                 */
                openFlag: number;
                /**
                 * 开通月数
                 */
                months: number;
                /**
                 * 贵族等级
                 */
                nobleLevel: number;
                /**
                 * 贵族等级类型
                 */
                nobleAttrType: number;
                /**
                 * 贵族名
                 */
                nobleName: string;
                /**
                 * 房间Id
                 */
                roomId: number;
                /**
                 * 用户unionId
                 */
                unionId: string;
                /**
                 * 用户头像
                 */
                userAvatarUrl: string;
                /**
                 * 用户昵称
                 */
                userNick: string;
            }) => any;
        }): Promise<void>;
        /**
         * 开启贵族消息
         * @edata
         * @typedef {Object} OpenNobleNotice
         * @property {number} startTime 贵族生效unix时间戳，单位是秒
         * @property {number} endTime 贵族失效unix时间戳，单位是秒
         * @property {number} openFlag 标志, 1-首次(非贵族开通任一贵族,或者低等级贵族更换高等级的贵族操作,都并入到首开), 2-续费
         * @property {number} months 开通月数
         * @property {number} nobleLevel 贵族等级
         * @property {number} nobleAttrType 贵族等级类型
         * @property {string} nobleName 贵族名
         * @property {number} roomId 房间Id
         * @property {string} unionId 用户unionId
         * @property {string} userAvatarUrl 用户头像
         * @property {string} userNick 用户昵称
         */
        /**
         * 开通贵族回调
         * @edata
         * @callback OpenNobleNoticeCallback
         * @param {OpenNobleNotice} notice 开启贵族消息
         */
        /**
         * 监听开通贵族参数
         * @edata
         * @typedef {Object} OnOpenNobleNoticeParams
         * @property {OpenNobleNoticeCallback} callback 监听开通贵族
         */
        /**
         * 监听开通贵族
         * @eapi
         * @param {OnOpenNobleNoticeParams} params 监听开通贵族参数
         * @returns {Promise<void>}
         */
        export function onOpenNobleNotice(params: {
            /**
             * 监听开通贵族
             */
            callback: (notice: {
                /**
                 * 贵族生效unix时间戳，单位是秒
                 */
                startTime: number;
                /**
                 * 贵族失效unix时间戳，单位是秒
                 */
                endTime: number;
                /**
                 * 标志, 1-首次(非贵族开通任一贵族,或者低等级贵族更换高等级的贵族操作,都并入到首开), 2-续费
                 */
                openFlag: number;
                /**
                 * 开通月数
                 */
                months: number;
                /**
                 * 贵族等级
                 */
                nobleLevel: number;
                /**
                 * 贵族等级类型
                 */
                nobleAttrType: number;
                /**
                 * 贵族名
                 */
                nobleName: string;
                /**
                 * 房间Id
                 */
                roomId: number;
                /**
                 * 用户unionId
                 */
                unionId: string;
                /**
                 * 用户头像
                 */
                userAvatarUrl: string;
                /**
                 * 用户昵称
                 */
                userNick: string;
            }) => any;
        }): Promise<void>;
        /**
         * 关闭监听开通贵族
         * @eapi
         * @returns {Promise<void>}
         */
        export function offOpenNobleNotice(): Promise<void>;
        /**
         * 关闭监听开通贵族
         * @eapi
         * @returns {Promise<void>}
         */
        export function offOpenNobleNotice(): Promise<void>;
        /**
        * 高级用户进场消息
        * @edata
        * @typedef {Object} VipEnterBannerNotice
        * @property {string} badgeName 粉丝标签名
        * @property {number} fansLevel 粉丝等级
        * @property {number} nobleLevel 贵族等级
        * @property {number} nobleAttrType 贵族等级类型
        * @property {string} nobleName 贵族名
        * @property {string} unionId 用户unionId
        * @property {number} roomId 房间Id
        * @property {string} userAvatarUrl 用户头像
        * @property {string} userNick 用户昵称
        */
        /**
         * 高级用户进场回调
         * @edata
         * @callback VipEnterBannerNoticeCallback
         * @param {VipEnterBannerNotice} notice 高级用户进场消息
         */
        /**
         * 监听高级用户进场参数
         * @edata
         * @typedef {Object} VipEnterBannerNoticeParams
         * @property {VipEnterBannerNoticeCallback} callback 高级用户进场信息回调
         */
        /**
         * 监听高级用户进场
         * @eapi
         * @param {VipEnterBannerNoticeParams} params 参数
         * @returns {Promise<void>}
         */
        export function onVipEnterBannerNotice(params: {
            /**
             * 高级用户进场信息回调
             */
            callback: (notice: {
                /**
                 * 粉丝标签名
                 */
                badgeName: string;
                /**
                 * 粉丝等级
                 */
                fansLevel: number;
                /**
                 * 贵族等级
                 */
                nobleLevel: number;
                /**
                 * 贵族等级类型
                 */
                nobleAttrType: number;
                /**
                 * 贵族名
                 */
                nobleName: string;
                /**
                 * 用户unionId
                 */
                unionId: string;
                /**
                 * 房间Id
                 */
                roomId: number;
                /**
                 * 用户头像
                 */
                userAvatarUrl: string;
                /**
                 * 用户昵称
                 */
                userNick: string;
            }) => any;
        }): Promise<void>;
        /**
        * 高级用户进场消息
        * @edata
        * @typedef {Object} VipEnterBannerNotice
        * @property {string} badgeName 粉丝标签名
        * @property {number} fansLevel 粉丝等级
        * @property {number} nobleLevel 贵族等级
        * @property {number} nobleAttrType 贵族等级类型
        * @property {string} nobleName 贵族名
        * @property {string} unionId 用户unionId
        * @property {number} roomId 房间Id
        * @property {string} userAvatarUrl 用户头像
        * @property {string} userNick 用户昵称
        */
        /**
         * 高级用户进场回调
         * @edata
         * @callback VipEnterBannerNoticeCallback
         * @param {VipEnterBannerNotice} notice 高级用户进场消息
         */
        /**
         * 监听高级用户进场参数
         * @edata
         * @typedef {Object} VipEnterBannerNoticeParams
         * @property {VipEnterBannerNoticeCallback} callback 高级用户进场信息回调
         */
        /**
         * 监听高级用户进场
         * @eapi
         * @param {VipEnterBannerNoticeParams} params 参数
         * @returns {Promise<void>}
         */
        export function onVipEnterBannerNotice(params: {
            /**
             * 高级用户进场信息回调
             */
            callback: (notice: {
                /**
                 * 粉丝标签名
                 */
                badgeName: string;
                /**
                 * 粉丝等级
                 */
                fansLevel: number;
                /**
                 * 贵族等级
                 */
                nobleLevel: number;
                /**
                 * 贵族等级类型
                 */
                nobleAttrType: number;
                /**
                 * 贵族名
                 */
                nobleName: string;
                /**
                 * 用户unionId
                 */
                unionId: string;
                /**
                 * 房间Id
                 */
                roomId: number;
                /**
                 * 用户头像
                 */
                userAvatarUrl: string;
                /**
                 * 用户昵称
                 */
                userNick: string;
            }) => any;
        }): Promise<void>;
        /**
         * 取消监听高级用户进场
         * @eapi
         * @returns {Promise<void>}
         */
        export function offVipEnterBannerNotice(): Promise<void>;
        /**
         * 取消监听高级用户进场
         * @eapi
         * @returns {Promise<void>}
         */
        export function offVipEnterBannerNotice(): Promise<void>;
        /**
         * 直播间分享消息
         * @edata
         * @typedef {Object} ShareLiveNotice
         * @property {string} actionUrl 直播间跳转链接
         * @property {string} content 分享内容
         * @property {string} imageUrl 分享图片的url
         * @property {string} presenterUnionId 主播unionId
         * @property {number} roomId 房间Id
         * @property {number} shareType 分享类型，默认0
         * @property {string} sharerNick 分享人的昵称
         * @property {string} sharerUnionId 分享人的unionId
         * @property {string} subtitle 直播间副标题
         * @property {string} title 直播间标题
         */
        /**
         * 分享直播间回调
         * @edata
         * @callback ShareLiveNoticeCallback
         * @param {ShareLiveNotice} notice 直播间分享消息
         */
        /**
         * 监听分享直播间参数
         * @edata
         * @typedef {Object} ShareLiveNoticeParams
         * @property {ShareLiveNoticeCallback} callback 分享直播间回调
         */
        /**
         * 监听分享直播间事件
         * @eapi
         * @param {ShareLiveNoticeParams} params 监听分享直播间参数
         * @returns {Promise<void>}
         */
        export function onShareLiveNotice(params: {
            /**
             * 分享直播间回调
             */
            callback: (notice: {
                /**
                 * 直播间跳转链接
                 */
                actionUrl: string;
                /**
                 * 分享内容
                 */
                content: string;
                /**
                 * 分享图片的url
                 */
                imageUrl: string;
                /**
                 * 主播unionId
                 */
                presenterUnionId: string;
                /**
                 * 房间Id
                 */
                roomId: number;
                /**
                 * 分享类型，默认0
                 */
                shareType: number;
                /**
                 * 分享人的昵称
                 */
                sharerNick: string;
                /**
                 * 分享人的unionId
                 */
                sharerUnionId: string;
                /**
                 * 直播间副标题
                 */
                subtitle: string;
                /**
                 * 直播间标题
                 */
                title: string;
            }) => any;
        }): Promise<void>;
        /**
         * 直播间分享消息
         * @edata
         * @typedef {Object} ShareLiveNotice
         * @property {string} actionUrl 直播间跳转链接
         * @property {string} content 分享内容
         * @property {string} imageUrl 分享图片的url
         * @property {string} presenterUnionId 主播unionId
         * @property {number} roomId 房间Id
         * @property {number} shareType 分享类型，默认0
         * @property {string} sharerNick 分享人的昵称
         * @property {string} sharerUnionId 分享人的unionId
         * @property {string} subtitle 直播间副标题
         * @property {string} title 直播间标题
         */
        /**
         * 分享直播间回调
         * @edata
         * @callback ShareLiveNoticeCallback
         * @param {ShareLiveNotice} notice 直播间分享消息
         */
        /**
         * 监听分享直播间参数
         * @edata
         * @typedef {Object} ShareLiveNoticeParams
         * @property {ShareLiveNoticeCallback} callback 分享直播间回调
         */
        /**
         * 监听分享直播间事件
         * @eapi
         * @param {ShareLiveNoticeParams} params 监听分享直播间参数
         * @returns {Promise<void>}
         */
        export function onShareLiveNotice(params: {
            /**
             * 分享直播间回调
             */
            callback: (notice: {
                /**
                 * 直播间跳转链接
                 */
                actionUrl: string;
                /**
                 * 分享内容
                 */
                content: string;
                /**
                 * 分享图片的url
                 */
                imageUrl: string;
                /**
                 * 主播unionId
                 */
                presenterUnionId: string;
                /**
                 * 房间Id
                 */
                roomId: number;
                /**
                 * 分享类型，默认0
                 */
                shareType: number;
                /**
                 * 分享人的昵称
                 */
                sharerNick: string;
                /**
                 * 分享人的unionId
                 */
                sharerUnionId: string;
                /**
                 * 直播间副标题
                 */
                subtitle: string;
                /**
                 * 直播间标题
                 */
                title: string;
            }) => any;
        }): Promise<void>;
        /**
         * 取消监听分享直播间事件
         * @eapi
         */
        export function offShareLiveNotice(): any;
        /**
         * 取消监听分享直播间事件
         * @eapi
         */
        export function offShareLiveNotice(): any;
        /**
         * 获取当前观众是否订阅当前主播
         * @eapi
         * @returns {Promise<boolean>} 返回是否订阅
         */
        export function getSubscribeInfo(): Promise<boolean>;
        /**
         * 获取当前观众是否订阅当前主播
         * @eapi
         * @returns {Promise<boolean>} 返回是否订阅
         */
        export function getSubscribeInfo(): Promise<boolean>;
        /**
         * 主播信息
         * @edata
         * @typedef {Object} StreamerInfo
         * @property {string} streamerNick 主播昵称
         * @property {string} streamerAvatarUrl 主播头像地址
         * @property {number} streamerSex 主播性别, 1-表示男, 2-表示女
         * @property {string} streamerRoomId 房间Id
         * @property {number} streamerLevel 主播等级
         * @property {string} streamerUnionId 主播unionId
         */
        /**
         * 获取主播信息
         * @eapi
         * @returns {Promise<StreamerInfo>} 返回用户信息
         */
        export function getStreamerInfo(): Promise<{
            /**
             * 主播昵称
             */
            streamerNick: string;
            /**
             * 主播头像地址
             */
            streamerAvatarUrl: string;
            /**
             * 主播性别, 1-表示男, 2-表示女
             */
            streamerSex: number;
            /**
             * 房间Id
             */
            streamerRoomId: string;
            /**
             * 主播等级
             */
            streamerLevel: number;
            /**
             * 主播unionId
             */
            streamerUnionId: string;
        }>;
        /**
         * 主播信息
         * @edata
         * @typedef {Object} StreamerInfo
         * @property {string} streamerNick 主播昵称
         * @property {string} streamerAvatarUrl 主播头像地址
         * @property {number} streamerSex 主播性别, 1-表示男, 2-表示女
         * @property {string} streamerRoomId 房间Id
         * @property {number} streamerLevel 主播等级
         * @property {string} streamerUnionId 主播unionId
         */
        /**
         * 获取主播信息
         * @eapi
         * @returns {Promise<StreamerInfo>} 返回用户信息
         */
        export function getStreamerInfo(): Promise<{
            /**
             * 主播昵称
             */
            streamerNick: string;
            /**
             * 主播头像地址
             */
            streamerAvatarUrl: string;
            /**
             * 主播性别, 1-表示男, 2-表示女
             */
            streamerSex: number;
            /**
             * 房间Id
             */
            streamerRoomId: string;
            /**
             * 主播等级
             */
            streamerLevel: number;
            /**
             * 主播unionId
             */
            streamerUnionId: string;
        }>;
        /**
         * APP信息
         * @edata
         * @typedef {Object} ContextInfo
         * @property {string} version 版本信息
         * @property {string} huyaUA UA信息
         */
        /**
         * @eapi
         * 获取app信息，目前返回app版本、UA
         * @returns {Promise<ContextInfo>} 返回app信息
         */
        export function getContextInfo(): Promise<{
            /**
             * 版本信息
             */
            version: string;
            /**
             * UA信息
             */
            huyaUA: string;
        }>;
        /**
         * APP信息
         * @edata
         * @typedef {Object} ContextInfo
         * @property {string} version 版本信息
         * @property {string} huyaUA UA信息
         */
        /**
         * @eapi
         * 获取app信息，目前返回app版本、UA
         * @returns {Promise<ContextInfo>} 返回app信息
         */
        export function getContextInfo(): Promise<{
            /**
             * 版本信息
             */
            version: string;
            /**
             * UA信息
             */
            huyaUA: string;
        }>;
        /**
         * 直播间信息
         * @edata
         * @typedef {Object} RespLiveInfo
         * @property {string} gameName 品类，如果isOn为false，则为上次开播的品类
         * @property {number} liveCount 人气，如果isOn为false，则为上次开播的人气
         * @property {string} roomTitle 直播间介绍，如果isOn为false，则为上次开播的直播间介绍
         * @property {number} startTime 开播时间戳（秒)，如果isOn为false，则为上次开播的时间戳
         * @property {boolean} isOn 是否在播
         */
        /**
         * 获取直播间信息
         * @eapi
         * @returns {Promise<RespLiveInfo>} 返回直播间信息
         */
        export function getLiveInfo(): Promise<{
            /**
             * 品类，如果isOn为false，则为上次开播的品类
             */
            gameName: string;
            /**
             * 人气，如果isOn为false，则为上次开播的人气
             */
            liveCount: number;
            /**
             * 直播间介绍，如果isOn为false，则为上次开播的直播间介绍
             */
            roomTitle: string;
            /**
             * 开播时间戳（秒)，如果isOn为false，则为上次开播的时间戳
             */
            startTime: number;
            /**
             * 是否在播
             */
            isOn: boolean;
        }>;
        /**
         * 直播间信息
         * @edata
         * @typedef {Object} RespLiveInfo
         * @property {string} gameName 品类，如果isOn为false，则为上次开播的品类
         * @property {number} liveCount 人气，如果isOn为false，则为上次开播的人气
         * @property {string} roomTitle 直播间介绍，如果isOn为false，则为上次开播的直播间介绍
         * @property {number} startTime 开播时间戳（秒)，如果isOn为false，则为上次开播的时间戳
         * @property {boolean} isOn 是否在播
         */
        /**
         * 获取直播间信息
         * @eapi
         * @returns {Promise<RespLiveInfo>} 返回直播间信息
         */
        export function getLiveInfo(): Promise<{
            /**
             * 品类，如果isOn为false，则为上次开播的品类
             */
            gameName: string;
            /**
             * 人气，如果isOn为false，则为上次开播的人气
             */
            liveCount: number;
            /**
             * 直播间介绍，如果isOn为false，则为上次开播的直播间介绍
             */
            roomTitle: string;
            /**
             * 开播时间戳（秒)，如果isOn为false，则为上次开播的时间戳
             */
            startTime: number;
            /**
             * 是否在播
             */
            isOn: boolean;
        }>;
        /**
         * 用户信息
         * @edata
         * @typedef {Object} UserInfo
         * @property {string} userNick 用户昵称
         * @property {string} userAvatarUrl 用户头像地址
         * @property {number} userLevel 用户等级
         * @property {string} userUnionId 用户的unionId
         */
        /**
         * 获取用户信息
         * @summary 需要用户授权使用
         * @eapi
         * @returns {Promise<UserInfo>} 返回用户信息
         */
        export function getUserInfo(): Promise<{
            /**
             * 用户昵称
             */
            userNick: string;
            /**
             * 用户头像地址
             */
            userAvatarUrl: string;
            /**
             * 用户等级
             */
            userLevel: number;
            /**
             * 用户的unionId
             */
            userUnionId: string;
        }>;
        /**
         * 用户信息
         * @edata
         * @typedef {Object} UserInfo
         * @property {string} userNick 用户昵称
         * @property {string} userAvatarUrl 用户头像地址
         * @property {number} userLevel 用户等级
         * @property {string} userUnionId 用户的unionId
         */
        /**
         * 获取用户信息
         * @summary 需要用户授权使用
         * @eapi
         * @returns {Promise<UserInfo>} 返回用户信息
         */
        export function getUserInfo(): Promise<{
            /**
             * 用户昵称
             */
            userNick: string;
            /**
             * 用户头像地址
             */
            userAvatarUrl: string;
            /**
             * 用户等级
             */
            userLevel: number;
            /**
             * 用户的unionId
             */
            userUnionId: string;
        }>;
        /**
         * 榜单单个数据
         * @edata
         * @typedef {Object} RankItem
         * @property {string} userNick 包含用户昵称
         * @property {string} userAvatarUrl 用户头像地址
         * @property {number} score 贡献值
         * @property {number} fansLevel 粉丝等级
         */
        /**
         * @edata
         * @typedef {Object} RankInfo
         * @property {string} badgeName 粉丝标签名
         * @property {Array.<RankItem>} rank 榜单列表
         */
        /**
         * 获取直播间的粉丝榜信息
         * @eapi
         * @returns {Promise<RankInfo>} 返回直播间粉丝榜信息
         */
        export function getFansRank(): Promise<{
            /**
             * 粉丝标签名
             */
            badgeName: string;
            /**
             * 榜单列表
             */
            rank: {
                /**
                 * 包含用户昵称
                 */
                userNick: string;
                /**
                 * 用户头像地址
                 */
                userAvatarUrl: string;
                /**
                 * 贡献值
                 */
                score: number;
                /**
                 * 粉丝等级
                 */
                fansLevel: number;
            }[];
        }>;
        /**
         * 榜单单个数据
         * @edata
         * @typedef {Object} RankItem
         * @property {string} userNick 包含用户昵称
         * @property {string} userAvatarUrl 用户头像地址
         * @property {number} score 贡献值
         * @property {number} fansLevel 粉丝等级
         */
        /**
         * @edata
         * @typedef {Object} RankInfo
         * @property {string} badgeName 粉丝标签名
         * @property {Array.<RankItem>} rank 榜单列表
         */
        /**
         * 获取直播间的粉丝榜信息
         * @eapi
         * @returns {Promise<RankInfo>} 返回直播间粉丝榜信息
         */
        export function getFansRank(): Promise<{
            /**
             * 粉丝标签名
             */
            badgeName: string;
            /**
             * 榜单列表
             */
            rank: {
                /**
                 * 包含用户昵称
                 */
                userNick: string;
                /**
                 * 用户头像地址
                 */
                userAvatarUrl: string;
                /**
                 * 贡献值
                 */
                score: number;
                /**
                 * 粉丝等级
                 */
                fansLevel: number;
            }[];
        }>;
        /**
         * Vip信息
         * @edata
         * @typedef {Object} VipItem
         * @property {string} userNick 用户昵称
         * @property {string} userAvatarUrl 用户头像地址
         * @property {number} nobleLevel 贵族等级
         * @property {string} nobleName 贵族名称
         */
        /**
         * 获取直播间所有贵宾信息
         * @eapi
         * @returns {Promise<Array.<VipItem>>} 返回直播间所有贵宾信息
         */
        export function getVip(): Promise<{
            /**
             * 用户昵称
             */
            userNick: string;
            /**
             * 用户头像地址
             */
            userAvatarUrl: string;
            /**
             * 贵族等级
             */
            nobleLevel: number;
            /**
             * 贵族名称
             */
            nobleName: string;
        }[]>;
        /**
         * Vip信息
         * @edata
         * @typedef {Object} VipItem
         * @property {string} userNick 用户昵称
         * @property {string} userAvatarUrl 用户头像地址
         * @property {number} nobleLevel 贵族等级
         * @property {string} nobleName 贵族名称
         */
        /**
         * 获取直播间所有贵宾信息
         * @eapi
         * @returns {Promise<Array.<VipItem>>} 返回直播间所有贵宾信息
         */
        export function getVip(): Promise<{
            /**
             * 用户昵称
             */
            userNick: string;
            /**
             * 用户头像地址
             */
            userAvatarUrl: string;
            /**
             * 贵族等级
             */
            nobleLevel: number;
            /**
             * 贵族名称
             */
            nobleName: string;
        }[]>;
        /**
         * 获取直播间的周贡榜信息
         * @eapi
         * @returns {Promise<Array.<RankItem>>} 返回周贡榜榜单数据
         */
        export function getWeekRank(): Promise<{
            /**
             * 包含用户昵称
             */
            userNick: string;
            /**
             * 用户头像地址
             */
            userAvatarUrl: string;
            /**
             * 贡献值
             */
            score: number;
            /**
             * 粉丝等级
             */
            fansLevel: number;
        }[]>;
        /**
         * 获取直播间的周贡榜信息
         * @eapi
         * @returns {Promise<Array.<RankItem>>} 返回周贡榜榜单数据
         */
        export function getWeekRank(): Promise<{
            /**
             * 包含用户昵称
             */
            userNick: string;
            /**
             * 用户头像地址
             */
            userAvatarUrl: string;
            /**
             * 贡献值
             */
            score: number;
            /**
             * 粉丝等级
             */
            fansLevel: number;
        }[]>;
        /**
         * 发送弹幕分组标签参数
         * @edata
         * @typedef {Object} SendBarrageTagParams
         * @property {string} tag 发送弹幕标签
         */
        /**
         * 设置发送弹幕分组标签
         * @eapi
         * @param {SendBarrageTagParams} param 发送弹幕分组标签参数
         * @returns {Promise<void>} 返回设置发送弹幕分组标签是否显示成功
         */
        export function setSendBarrageTag(param: {
            /**
             * 发送弹幕标签
             */
            tag: string;
        }): Promise<void>;
        /**
         * 发送弹幕分组标签参数
         * @edata
         * @typedef {Object} SendBarrageTagParams
         * @property {string} tag 发送弹幕标签
         */
        /**
         * 设置发送弹幕分组标签
         * @eapi
         * @param {SendBarrageTagParams} param 发送弹幕分组标签参数
         * @returns {Promise<void>} 返回设置发送弹幕分组标签是否显示成功
         */
        export function setSendBarrageTag(param: {
            /**
             * 发送弹幕标签
             */
            tag: string;
        }): Promise<void>;
        /**
         * 显示弹幕分组标签参数
         * @edata
         * @typedef {Object} DisplayBarrageTagParams
         * @property {Array.<string>} tags 显示弹幕标签组
         */
        /**
         * 设置显示弹幕分组标签
         * @eapi
         * @param {DisplayBarrageTagParams} param 显示弹幕分组标签参数
         * @returns {Promise<void>} 返回设置显示弹幕分组标签是否显示成功
         */
        export function setDisplayBarrageTags(param: {
            /**
             * 显示弹幕标签组
             */
            tags: string[];
        }): Promise<void>;
        /**
         * 显示弹幕分组标签参数
         * @edata
         * @typedef {Object} DisplayBarrageTagParams
         * @property {Array.<string>} tags 显示弹幕标签组
         */
        /**
         * 设置显示弹幕分组标签
         * @eapi
         * @param {DisplayBarrageTagParams} param 显示弹幕分组标签参数
         * @returns {Promise<void>} 返回设置显示弹幕分组标签是否显示成功
         */
        export function setDisplayBarrageTags(param: {
            /**
             * 显示弹幕标签组
             */
            tags: string[];
        }): Promise<void>;
        /**
         * 分享配置
         * @edata
         * @typedef {Object} ShareParams
         * @property {string} platform 平台, all-全部平台(默认), weixin-微信, circle-朋友圈, qq-QQ, qzone-QQ空间, sinaweibo-新浪微博, copy-复制链接
         * @property {string} title 标题
         * @property {string} content 摘要
         * @property {string} shareUrl H5地址
         * @property {string} imageUrl 图片地址
         * @property {string} [imageData] 图片内容
         * @property {string} [miniprogramUrl] 小程序url
         * @property {string} mediaType 分享类型, 1-H5分享(默认), 2-图片分享, 5-微信小程序
         */
        /**
         * 分享直播间
         * @eapi
         * @param {ShareParams} params 分享配置
         * @returns {Promise<void>} 返回分享直播间是否成功
         */
        export function share(params: {
            /**
             * 平台, all-全部平台(默认), weixin-微信, circle-朋友圈, qq-QQ, qzone-QQ空间, sinaweibo-新浪微博, copy-复制链接
             */
            platform: string;
            /**
             * 标题
             */
            title: string;
            /**
             * 摘要
             */
            content: string;
            /**
             * H5地址
             */
            shareUrl: string;
            /**
             * 图片地址
             */
            imageUrl: string;
            /**
             * 图片内容
             */
            imageData?: string;
            /**
             * 小程序url
             */
            miniprogramUrl?: string;
            /**
             * 分享类型, 1-H5分享(默认), 2-图片分享, 5-微信小程序
             */
            mediaType: string;
        }): Promise<void>;
        /**
         * 分享配置
         * @edata
         * @typedef {Object} ShareParams
         * @property {string} platform 平台, all-全部平台(默认), weixin-微信, circle-朋友圈, qq-QQ, qzone-QQ空间, sinaweibo-新浪微博, copy-复制链接
         * @property {string} title 标题
         * @property {string} content 摘要
         * @property {string} shareUrl H5地址
         * @property {string} imageUrl 图片地址
         * @property {string} [imageData] 图片内容
         * @property {string} [miniprogramUrl] 小程序url
         * @property {string} mediaType 分享类型, 1-H5分享(默认), 2-图片分享, 5-微信小程序
         */
        /**
         * 分享直播间
         * @eapi
         * @param {ShareParams} params 分享配置
         * @returns {Promise<void>} 返回分享直播间是否成功
         */
        export function share(params: {
            /**
             * 平台, all-全部平台(默认), weixin-微信, circle-朋友圈, qq-QQ, qzone-QQ空间, sinaweibo-新浪微博, copy-复制链接
             */
            platform: string;
            /**
             * 标题
             */
            title: string;
            /**
             * 摘要
             */
            content: string;
            /**
             * H5地址
             */
            shareUrl: string;
            /**
             * 图片地址
             */
            imageUrl: string;
            /**
             * 图片内容
             */
            imageData?: string;
            /**
             * 小程序url
             */
            miniprogramUrl?: string;
            /**
             * 分享类型, 1-H5分享(默认), 2-图片分享, 5-微信小程序
             */
            mediaType: string;
        }): Promise<void>;
        /**
         * 订阅者概况
         * @edata
         * @typedef {Object} SubscriberSummary
         * @property {number} subscribeCount 	当前主播订阅人数
         */
        /**
         * 获取当前主播的订阅概况
         * 订阅了当前直播间的订阅者的信息
         * @eapi
         * @returns {Promise<SubscriberSummary>} 订阅者概况
         */
        export function getSubscriberSummary(): Promise<{
            /**
             * 当前主播订阅人数
             */
            subscribeCount: number;
        }>;
        /**
         * 订阅者概况
         * @edata
         * @typedef {Object} SubscriberSummary
         * @property {number} subscribeCount 	当前主播订阅人数
         */
        /**
         * 获取当前主播的订阅概况
         * 订阅了当前直播间的订阅者的信息
         * @eapi
         * @returns {Promise<SubscriberSummary>} 订阅者概况
         */
        export function getSubscriberSummary(): Promise<{
            /**
             * 当前主播订阅人数
             */
            subscribeCount: number;
        }>;
        /**
         * 订阅人
         * @edata
         * @typedef {Object} SubscriberInfo
         * @property {string} userNick 用户昵称
         */
        /**
         * 订阅者消息
         * @edata
         * @typedef {Object} SubscriberInfos
         * @property {Array.<SubscriberInfo>} subscriberList 订阅用户列表
         */
        /**
         * 订阅信息改变回调
         * @edata
         * @callback SubscriberChangeCallback
         * @param {SubscriberInfos} subscriberInfo 订阅者消息
         */
        /**
         * 订阅信息过滤条件
         * @edata
         * @typedef {Object} SubscriberOptions
         * @property {string} userNick 用户昵称
         */
        /**
         * 监听订阅信息改变
         * @summary 只保留最新的一次监听
         * @eapi
         * @param {SubscriberOptions} options 订阅信息过滤条件
         * @param {SubscriberChangeCallback} callback 订阅信息改变回调
         * @returns {Promise<void>}
         */
        export function onSubscriberChange(options: {
            /**
             * 用户昵称
             */
            userNick: string;
        }, callback: (subscriberInfo: {
            /**
             * 订阅用户列表
             */
            subscriberList: {
                /**
                 * 用户昵称
                 */
                userNick: string;
            }[];
        }) => any): Promise<void>;
        /**
         * 订阅人
         * @edata
         * @typedef {Object} SubscriberInfo
         * @property {string} userNick 用户昵称
         */
        /**
         * 订阅者消息
         * @edata
         * @typedef {Object} SubscriberInfos
         * @property {Array.<SubscriberInfo>} subscriberList 订阅用户列表
         */
        /**
         * 订阅信息改变回调
         * @edata
         * @callback SubscriberChangeCallback
         * @param {SubscriberInfos} subscriberInfo 订阅者消息
         */
        /**
         * 订阅信息过滤条件
         * @edata
         * @typedef {Object} SubscriberOptions
         * @property {string} userNick 用户昵称
         */
        /**
         * 监听订阅信息改变
         * @summary 只保留最新的一次监听
         * @eapi
         * @param {SubscriberOptions} options 订阅信息过滤条件
         * @param {SubscriberChangeCallback} callback 订阅信息改变回调
         * @returns {Promise<void>}
         */
        export function onSubscriberChange(options: {
            /**
             * 用户昵称
             */
            userNick: string;
        }, callback: (subscriberInfo: {
            /**
             * 订阅用户列表
             */
            subscriberList: {
                /**
                 * 用户昵称
                 */
                userNick: string;
            }[];
        }) => any): Promise<void>;
        /**
         * 取消监听订阅信息改变
         * @eapi
         * @returns {Promise<void>}
         */
        export function offSubscriberChange(): Promise<void>;
        /**
         * 取消监听订阅信息改变
         * @eapi
         * @returns {Promise<void>}
         */
        export function offSubscriberChange(): Promise<void>;
        /**
         * @edata
         * @typedef {Object} Barrage
         * @property {boolean} enable 是否接收弹幕（包括大弹幕、小弹幕、送礼弹幕等）
         */
        /**
         * @edata
         * @typedef {Object} Effect
         * @property {boolean} giftEffectEnable 是否接收并显示礼物特效
         * @property {boolean} nobleEffectEnable 是否接收并显示贵族特效
         */
        /**
         * @edata
         * @typedef {Object} Player
         * @property {string} status 播放器状态 playing-播放, paused-停止
         */
        /**
         * @edata
         * @typedef {Object} UI
         * @property {boolean} activated 是否激活UI（人气、主播头像、送礼、弹幕输入框、小程序等相关UI元素）
         */
        /**
         * @edata
         * @typedef {Object} Stream
         * @property {string} videoStreamStatus 视频流状态, playing-播放, paused-暂停
         * @property {string} audioStreamStatus 音频流状态, playing-播放, paused-暂停
         */
        /**
         * @edata
         * @typedef {Object} Orientation
         * @property {string} value 设备方向, portrait-竖屏, landscape-横屏
         * @property {boolean} [locked] 是否锁定方向
         */
        /**
         * @edata
         * @typedef {Object} Features
         * @property {Barrage} [barrage] 弹幕功能信息
         * @property {Effect} [effect] 特效功能信息
         * @property {Player} [player] 播放功能信息
         * @property {UI} [ui] UI功能信息
         * @property {Stream} [stream] 流功能信息
         * @property {Orientation} [orientation] 设备方向信息
         */
        /**
        * @edata
        * @typedef {string} FeatureKey 相关功能key, barrage-弹幕功能, efect-特效功能, player-播放功能, ui-UI功能, stream-流功能, orientation-设备方向
        */
        /**
         * 获取直播间功能
         * @eapi
         * @param {Array.<FeatureKey>} params 相关功能的键的数组（可以提供一个或者多个）
         * @returns {Promise<Features>} 返回 直播间功能信息（根据参数提供的键会有对应的字段）
         */
        export function getLiveRoomFeatures(params: string[]): Promise<{
            /**
             * 弹幕功能信息
             */
            barrage?: {
                /**
                 * 是否接收弹幕（包括大弹幕、小弹幕、送礼弹幕等）
                 */
                enable: boolean;
            };
            /**
             * 特效功能信息
             */
            effect?: {
                /**
                 * 是否接收并显示礼物特效
                 */
                giftEffectEnable: boolean;
                /**
                 * 是否接收并显示贵族特效
                 */
                nobleEffectEnable: boolean;
            };
            /**
             * 播放功能信息
             */
            player?: {
                /**
                 * 播放器状态 playing-播放, paused-停止
                 */
                status: string;
            };
            /**
             * UI功能信息
             */
            ui?: {
                /**
                 * 是否激活UI（人气、主播头像、送礼、弹幕输入框、小程序等相关UI元素）
                 */
                activated: boolean;
            };
            /**
             * 流功能信息
             */
            stream?: {
                /**
                 * 视频流状态, playing-播放, paused-暂停
                 */
                videoStreamStatus: string;
                /**
                 * 音频流状态, playing-播放, paused-暂停
                 */
                audioStreamStatus: string;
            };
            /**
             * 设备方向信息
             */
            orientation?: {
                /**
                 * 设备方向, portrait-竖屏, landscape-横屏
                 */
                value: string;
                /**
                 * 是否锁定方向
                 */
                locked?: boolean;
            };
        }>;
        /**
         * @edata
         * @typedef {Object} Barrage
         * @property {boolean} enable 是否接收弹幕（包括大弹幕、小弹幕、送礼弹幕等）
         */
        /**
         * @edata
         * @typedef {Object} Effect
         * @property {boolean} giftEffectEnable 是否接收并显示礼物特效
         * @property {boolean} nobleEffectEnable 是否接收并显示贵族特效
         */
        /**
         * @edata
         * @typedef {Object} Player
         * @property {string} status 播放器状态 playing-播放, paused-停止
         */
        /**
         * @edata
         * @typedef {Object} UI
         * @property {boolean} activated 是否激活UI（人气、主播头像、送礼、弹幕输入框、小程序等相关UI元素）
         */
        /**
         * @edata
         * @typedef {Object} Stream
         * @property {string} videoStreamStatus 视频流状态, playing-播放, paused-暂停
         * @property {string} audioStreamStatus 音频流状态, playing-播放, paused-暂停
         */
        /**
         * @edata
         * @typedef {Object} Orientation
         * @property {string} value 设备方向, portrait-竖屏, landscape-横屏
         * @property {boolean} [locked] 是否锁定方向
         */
        /**
         * @edata
         * @typedef {Object} Features
         * @property {Barrage} [barrage] 弹幕功能信息
         * @property {Effect} [effect] 特效功能信息
         * @property {Player} [player] 播放功能信息
         * @property {UI} [ui] UI功能信息
         * @property {Stream} [stream] 流功能信息
         * @property {Orientation} [orientation] 设备方向信息
         */
        /**
        * @edata
        * @typedef {string} FeatureKey 相关功能key, barrage-弹幕功能, efect-特效功能, player-播放功能, ui-UI功能, stream-流功能, orientation-设备方向
        */
        /**
         * 获取直播间功能
         * @eapi
         * @param {Array.<FeatureKey>} params 相关功能的键的数组（可以提供一个或者多个）
         * @returns {Promise<Features>} 返回 直播间功能信息（根据参数提供的键会有对应的字段）
         */
        export function getLiveRoomFeatures(params: string[]): Promise<{
            /**
             * 弹幕功能信息
             */
            barrage?: {
                /**
                 * 是否接收弹幕（包括大弹幕、小弹幕、送礼弹幕等）
                 */
                enable: boolean;
            };
            /**
             * 特效功能信息
             */
            effect?: {
                /**
                 * 是否接收并显示礼物特效
                 */
                giftEffectEnable: boolean;
                /**
                 * 是否接收并显示贵族特效
                 */
                nobleEffectEnable: boolean;
            };
            /**
             * 播放功能信息
             */
            player?: {
                /**
                 * 播放器状态 playing-播放, paused-停止
                 */
                status: string;
            };
            /**
             * UI功能信息
             */
            ui?: {
                /**
                 * 是否激活UI（人气、主播头像、送礼、弹幕输入框、小程序等相关UI元素）
                 */
                activated: boolean;
            };
            /**
             * 流功能信息
             */
            stream?: {
                /**
                 * 视频流状态, playing-播放, paused-暂停
                 */
                videoStreamStatus: string;
                /**
                 * 音频流状态, playing-播放, paused-暂停
                 */
                audioStreamStatus: string;
            };
            /**
             * 设备方向信息
             */
            orientation?: {
                /**
                 * 设备方向, portrait-竖屏, landscape-横屏
                 */
                value: string;
                /**
                 * 是否锁定方向
                 */
                locked?: boolean;
            };
        }>;
        /**
         * @edata
         * @typedef {Object} FeaturesResp
         * @property {boolean} barrage 设置弹幕功能结果
         * @property {boolean} effect 设置特效功能结果
         * @property {boolean} player 设置播放功能结果
         * @property {boolean} ui 设置UI功能结果
         * @property {boolean} stream 设置流功能结果
         * @property {boolean} orientation 设置设备方向功能结果
         */
        /**
         * 设置直播间功能
         * @eapi
         * @param {Features} params 相关功能的键以及要设置的参数（可以提供一个键或者多个）
         * @returns {Promise<FeaturesResp>} 功能设置结果（根据参数提供的键会有对应的字段）
         */
        export function setLiveRoomFeatures(params: {
            /**
             * 弹幕功能信息
             */
            barrage?: {
                /**
                 * 是否接收弹幕（包括大弹幕、小弹幕、送礼弹幕等）
                 */
                enable: boolean;
            };
            /**
             * 特效功能信息
             */
            effect?: {
                /**
                 * 是否接收并显示礼物特效
                 */
                giftEffectEnable: boolean;
                /**
                 * 是否接收并显示贵族特效
                 */
                nobleEffectEnable: boolean;
            };
            /**
             * 播放功能信息
             */
            player?: {
                /**
                 * 播放器状态 playing-播放, paused-停止
                 */
                status: string;
            };
            /**
             * UI功能信息
             */
            ui?: {
                /**
                 * 是否激活UI（人气、主播头像、送礼、弹幕输入框、小程序等相关UI元素）
                 */
                activated: boolean;
            };
            /**
             * 流功能信息
             */
            stream?: {
                /**
                 * 视频流状态, playing-播放, paused-暂停
                 */
                videoStreamStatus: string;
                /**
                 * 音频流状态, playing-播放, paused-暂停
                 */
                audioStreamStatus: string;
            };
            /**
             * 设备方向信息
             */
            orientation?: {
                /**
                 * 设备方向, portrait-竖屏, landscape-横屏
                 */
                value: string;
                /**
                 * 是否锁定方向
                 */
                locked?: boolean;
            };
        }): Promise<{
            /**
             * 设置弹幕功能结果
             */
            barrage: boolean;
            /**
             * 设置特效功能结果
             */
            effect: boolean;
            /**
             * 设置播放功能结果
             */
            player: boolean;
            /**
             * 设置UI功能结果
             */
            ui: boolean;
            /**
             * 设置流功能结果
             */
            stream: boolean;
            /**
             * 设置设备方向功能结果
             */
            orientation: boolean;
        }>;
        /**
         * @edata
         * @typedef {Object} FeaturesResp
         * @property {boolean} barrage 设置弹幕功能结果
         * @property {boolean} effect 设置特效功能结果
         * @property {boolean} player 设置播放功能结果
         * @property {boolean} ui 设置UI功能结果
         * @property {boolean} stream 设置流功能结果
         * @property {boolean} orientation 设置设备方向功能结果
         */
        /**
         * 设置直播间功能
         * @eapi
         * @param {Features} params 相关功能的键以及要设置的参数（可以提供一个键或者多个）
         * @returns {Promise<FeaturesResp>} 功能设置结果（根据参数提供的键会有对应的字段）
         */
        export function setLiveRoomFeatures(params: {
            /**
             * 弹幕功能信息
             */
            barrage?: {
                /**
                 * 是否接收弹幕（包括大弹幕、小弹幕、送礼弹幕等）
                 */
                enable: boolean;
            };
            /**
             * 特效功能信息
             */
            effect?: {
                /**
                 * 是否接收并显示礼物特效
                 */
                giftEffectEnable: boolean;
                /**
                 * 是否接收并显示贵族特效
                 */
                nobleEffectEnable: boolean;
            };
            /**
             * 播放功能信息
             */
            player?: {
                /**
                 * 播放器状态 playing-播放, paused-停止
                 */
                status: string;
            };
            /**
             * UI功能信息
             */
            ui?: {
                /**
                 * 是否激活UI（人气、主播头像、送礼、弹幕输入框、小程序等相关UI元素）
                 */
                activated: boolean;
            };
            /**
             * 流功能信息
             */
            stream?: {
                /**
                 * 视频流状态, playing-播放, paused-暂停
                 */
                videoStreamStatus: string;
                /**
                 * 音频流状态, playing-播放, paused-暂停
                 */
                audioStreamStatus: string;
            };
            /**
             * 设备方向信息
             */
            orientation?: {
                /**
                 * 设备方向, portrait-竖屏, landscape-横屏
                 */
                value: string;
                /**
                 * 是否锁定方向
                 */
                locked?: boolean;
            };
        }): Promise<{
            /**
             * 设置弹幕功能结果
             */
            barrage: boolean;
            /**
             * 设置特效功能结果
             */
            effect: boolean;
            /**
             * 设置播放功能结果
             */
            player: boolean;
            /**
             * 设置UI功能结果
             */
            ui: boolean;
            /**
             * 设置流功能结果
             */
            stream: boolean;
            /**
             * 设置设备方向功能结果
             */
            orientation: boolean;
        }>;
    }
}
export default _default;
