declare namespace _default {
    export namespace fs {
        /**
         * 文件信息
         * @edata
         * @typedef {Object} UrlInfo
         * @property {string} url 文件的地址
         */
        /**
         * 上传图片
         * @summary 调用该接口时弹出系统选择图片的UI，选择图片后自动上传
         * - 上传成功后返回图片地址
         * - 大小限制：6M
         * @eapi
         * @returns {Promise<UrlInfo>} 调用结果
         */
        export function uploadImg(): Promise<{
            /**
             * 文件的地址
             */
            url: string;
        }>;
        /**
         * 文件信息
         * @edata
         * @typedef {Object} UrlInfo
         * @property {string} url 文件的地址
         */
        /**
         * 上传图片
         * @summary 调用该接口时弹出系统选择图片的UI，选择图片后自动上传
         * - 上传成功后返回图片地址
         * - 大小限制：6M
         * @eapi
         * @returns {Promise<UrlInfo>} 调用结果
         */
        export function uploadImg(): Promise<{
            /**
             * 文件的地址
             */
            url: string;
        }>;
        /**
         * 离线资源是否下载完成
         * @eapi
         * @param {UrlInfo} params 监听参数
         * @returns {Promise<void>} 调用结果
         */
        export function offlineFileReady(params: {
            /**
             * 文件的地址
             */
            url: string;
        }): Promise<void>;
        /**
         * 离线资源是否下载完成
         * @eapi
         * @param {UrlInfo} params 监听参数
         * @returns {Promise<void>} 调用结果
         */
        export function offlineFileReady(params: {
            /**
             * 文件的地址
             */
            url: string;
        }): Promise<void>;
        /**
         * 通用上传文件接口
         * @summary 调用该接口时弹出系统选择文件的UI，选择图片后自动上传
         * - 上传成功后返回文件的地址
         * @eapi
         * @returns {Promise<UrlInfo>} 调用结果
         */
        export function uploadFile(): Promise<{
            /**
             * 文件的地址
             */
            url: string;
        }>;
        /**
         * 通用上传文件接口
         * @summary 调用该接口时弹出系统选择文件的UI，选择图片后自动上传
         * - 上传成功后返回文件的地址
         * @eapi
         * @returns {Promise<UrlInfo>} 调用结果
         */
        export function uploadFile(): Promise<{
            /**
             * 文件的地址
             */
            url: string;
        }>;
        /**
         * 下载资源信息
         * @edata
         * @typedef {Object} BatchRes
         * @property {string} url 要下载的资源url
         * @property {string} md5 资源md5
         * @property {boolean} unzip 自动解压
         */
        /**
         * 批量下载资源
         * @summary 这个接口仅用于创建批量下载资源的任务，resolve并不等于文件下载完毕
         * - 需要使用hyExt.context.on('downloadProgress')消息来监听每个任务的下载进度
         * @eapi
         * @param {Array.<BatchRes>} params 下载资源信息
         * @returns {Promise<void>} 调用结果
         */
        export function downloadBatchRes(params: {
            /**
             * 要下载的资源url
             */
            url: string;
            /**
             * 资源md5
             */
            md5: string;
            /**
             * 自动解压
             */
            unzip: boolean;
        }[]): Promise<void>;
        /**
         * 下载资源信息
         * @edata
         * @typedef {Object} BatchRes
         * @property {string} url 要下载的资源url
         * @property {string} md5 资源md5
         * @property {boolean} unzip 自动解压
         */
        /**
         * 批量下载资源
         * @summary 这个接口仅用于创建批量下载资源的任务，resolve并不等于文件下载完毕
         * - 需要使用hyExt.context.on('downloadProgress')消息来监听每个任务的下载进度
         * @eapi
         * @param {Array.<BatchRes>} params 下载资源信息
         * @returns {Promise<void>} 调用结果
         */
        export function downloadBatchRes(params: {
            /**
             * 要下载的资源url
             */
            url: string;
            /**
             * 资源md5
             */
            md5: string;
            /**
             * 自动解压
             */
            unzip: boolean;
        }[]): Promise<void>;
        /**
         * 要删除的资源信息
         * @edata
         * @typedef {Object} RemoveRes
         * @property {string} md5 资源md5
         */
        /**
         * 删除资源
         * @eapi
         * @param {RemoveRes} params 要删除的资源信息
         * @returns {Promise<void>} 调用结果
         */
        export function removeRes(params: {
            /**
             * 资源md5
             */
            md5: string;
        }): Promise<void>;
        /**
         * 要删除的资源信息
         * @edata
         * @typedef {Object} RemoveRes
         * @property {string} md5 资源md5
         */
        /**
         * 删除资源
         * @eapi
         * @param {RemoveRes} params 要删除的资源信息
         * @returns {Promise<void>} 调用结果
         */
        export function removeRes(params: {
            /**
             * 资源md5
             */
            md5: string;
        }): Promise<void>;
        /**
         * 判断结果
         * @edata
         * @typedef {Object} ExistsResp
         * @property {boolean} isExists 是否存在
         */
        /**
         * 判断资源是否存在参数
         * @edata
         * @typedef {Object} ExistsReq
         * @property {string} md5 资源md5
         * @property {string} fileName 文件名
         */
        /**
         * 判断资源是否存在
         * @eapi
         * @param {ExistsReq} params 要判断的资源信息
         * @returns {Promise<ExistsResp>} 查询结果结果
         */
        export function isResExists(params: {
            /**
             * 资源md5
             */
            md5: string;
            /**
             * 文件名
             */
            fileName: string;
        }): Promise<{
            /**
             * 是否存在
             */
            isExists: boolean;
        }>;
        /**
         * 判断结果
         * @edata
         * @typedef {Object} ExistsResp
         * @property {boolean} isExists 是否存在
         */
        /**
         * 判断资源是否存在参数
         * @edata
         * @typedef {Object} ExistsReq
         * @property {string} md5 资源md5
         * @property {string} fileName 文件名
         */
        /**
         * 判断资源是否存在
         * @eapi
         * @param {ExistsReq} params 要判断的资源信息
         * @returns {Promise<ExistsResp>} 查询结果结果
         */
        export function isResExists(params: {
            /**
             * 资源md5
             */
            md5: string;
            /**
             * 文件名
             */
            fileName: string;
        }): Promise<{
            /**
             * 是否存在
             */
            isExists: boolean;
        }>;
    }
}
export default _default;
