declare namespace _default {
    export namespace observer {
        /**
         * 小程序消息回调
         * @edata
         * @callback ObserverCallback
         * @param {string} content 消息内容
         */
        /**
         * 监听小程序消息
         * @summary 通过[小程序API](/api/list.md)或者hyExt.observer.emit发送虎牙小程序消息，使用这个接口接收
         * - 主播端（PC主播端/助手APP）无法接收到通过调用hyExt.observer.emit触发的消息，只能收到[小程序API](/api/list.md)的消息
         * @eapi
         * @param {string} topic 消息名
         * @param {ObserverCallback} callback 收到消息时回调 返回对应消息名的后台消息content
         */
        export function on(topic: string, callback: (content: string) => any): any;
        /**
         * 小程序消息回调
         * @edata
         * @callback ObserverCallback
         * @param {string} content 消息内容
         */
        /**
         * 监听小程序消息
         * @summary 通过[小程序API](/api/list.md)或者hyExt.observer.emit发送虎牙小程序消息，使用这个接口接收
         * - 主播端（PC主播端/助手APP）无法接收到通过调用hyExt.observer.emit触发的消息，只能收到[小程序API](/api/list.md)的消息
         * @eapi
         * @param {string} topic 消息名
         * @param {ObserverCallback} callback 收到消息时回调 返回对应消息名的后台消息content
         */
        export function on(topic: string, callback: (content: string) => any): any;
        /**
         * 取消监听后台消息
         * @eapi
         * @param {string} topic 消息名
         * @param {ObserverCallback} [callback] 消息回调
         */
        export function off(topic: string, callback?: ((content: string) => any) | undefined): any;
        /**
         * 取消监听后台消息
         * @eapi
         * @param {string} topic 消息名
         * @param {ObserverCallback} [callback] 消息回调
         */
        export function off(topic: string, callback?: ((content: string) => any) | undefined): any;
        /**
         * 触发小程序消息
         * @summary 频率限制（每分钟最高请求10次）
         * @eapi
         * @param {string} topic 小程序消息名
         * @param {string} message 小程序消息内容
         * @returns {Promise<void>}
         */
        export function emit(topic: string, message: string): Promise<void>;
        /**
         * 触发小程序消息
         * @summary 频率限制（每分钟最高请求10次）
         * @eapi
         * @param {string} topic 小程序消息名
         * @param {string} message 小程序消息内容
         * @returns {Promise<void>}
         */
        export function emit(topic: string, message: string): Promise<void>;
        /**
         * 本地小程序消息回调
         * @edata
         * @callback LocalMessageCallback
         * @param {string} message 消息内容
         */
        /**
         * 监听本地小程序参数
         * @edata
         * @typedef {Object} LocalMessageParams
         * @property {string} eventName 消息名
         * @property {LocalMessageCallback} callback 消息回调
         */
        /**
         * 监听本地小程序消息
         * @summary 仅保留最后一次监听
         * @eapi
         * @param {LocalMessageParams} params 监听本地小程序参数
         * @returns {Promise<void>}
         */
        export function onLocalMessage({ eventName, callback }: {
            /**
             * 消息名
             */
            eventName: string;
            /**
             * 消息回调
             */
            callback: (message: string) => any;
        }): Promise<void>;
        /**
         * 本地小程序消息回调
         * @edata
         * @callback LocalMessageCallback
         * @param {string} message 消息内容
         */
        /**
         * 监听本地小程序参数
         * @edata
         * @typedef {Object} LocalMessageParams
         * @property {string} eventName 消息名
         * @property {LocalMessageCallback} callback 消息回调
         */
        /**
         * 监听本地小程序消息
         * @summary 仅保留最后一次监听
         * @eapi
         * @param {LocalMessageParams} params 监听本地小程序参数
         * @returns {Promise<void>}
         */
        export function onLocalMessage({ eventName, callback }: {
            /**
             * 消息名
             */
            eventName: string;
            /**
             * 消息回调
             */
            callback: (message: string) => any;
        }): Promise<void>;
        /**
         * 取消监听参数
         * @edata
         * @typedef {Object} OffLocalMessageParams
         * @property {string} eventName 消息名
         */
        /**
         * 取消监听自身小程序消息
         * @eapi
         * @param {OffLocalMessageParams} params 取消监听参数
         * @returns {Promise<void>}
         */
        export function offLocalMessage({ eventName }: {
            /**
             * 消息名
             */
            eventName: string;
        }): Promise<void>;
        /**
         * 取消监听参数
         * @edata
         * @typedef {Object} OffLocalMessageParams
         * @property {string} eventName 消息名
         */
        /**
         * 取消监听自身小程序消息
         * @eapi
         * @param {OffLocalMessageParams} params 取消监听参数
         * @returns {Promise<void>}
         */
        export function offLocalMessage({ eventName }: {
            /**
             * 消息名
             */
            eventName: string;
        }): Promise<void>;
        /**
         * 本地消息参数
         * @edata
         * @typedef {Object} PostLocalMessageParams
         * @property {string} eventName 消息名
         * @property {string} message 消息内容
         */
        /**
         * 触发小程序本地消息
         * @eapi
         * @param {PostLocalMessageParams} params 本地消息参数
         * @returns {Promise<void>} 调用结果
         */
        export function postLocalMessage({ eventName, message }: {
            /**
             * 消息名
             */
            eventName: string;
            /**
             * 消息内容
             */
            message: string;
        }): Promise<void>;
        /**
         * 本地消息参数
         * @edata
         * @typedef {Object} PostLocalMessageParams
         * @property {string} eventName 消息名
         * @property {string} message 消息内容
         */
        /**
         * 触发小程序本地消息
         * @eapi
         * @param {PostLocalMessageParams} params 本地消息参数
         * @returns {Promise<void>} 调用结果
         */
        export function postLocalMessage({ eventName, message }: {
            /**
             * 消息名
             */
            eventName: string;
            /**
             * 消息内容
             */
            message: string;
        }): Promise<void>;
    }
}
export default _default;
