declare namespace _default {
    export namespace pc {
        /**
         * 下载资源参数
         * @edata
         * @typedef {Object} DownloadResParams
         * @property {string} url 要下载资源的url
         * @property {string} md5 资源的md5
         * @property {boolean} [unzip] 自动解压
         */
        /**
         * 下载资源
         * @eapi
         * @param {DownloadResParams} param 下载资源参数
         * @returns {Promise<void>} 下载失败reject
         */
        export function downloadRes(param: {
            /**
             * 要下载资源的url
             */
            url: string;
            /**
             * 资源的md5
             */
            md5: string;
            /**
             * 自动解压
             */
            unzip?: boolean;
        }): Promise<void>;
        /**
         * 下载资源参数
         * @edata
         * @typedef {Object} DownloadResParams
         * @property {string} url 要下载资源的url
         * @property {string} md5 资源的md5
         * @property {boolean} [unzip] 自动解压
         */
        /**
         * 下载资源
         * @eapi
         * @param {DownloadResParams} param 下载资源参数
         * @returns {Promise<void>} 下载失败reject
         */
        export function downloadRes(param: {
            /**
             * 要下载资源的url
             */
            url: string;
            /**
             * 资源的md5
             */
            md5: string;
            /**
             * 自动解压
             */
            unzip?: boolean;
        }): Promise<void>;
        /**
         * 外部EXE参数
         * @edata
         * @typedef {Object} LaunchExeParams
         * @property {string} name exe的名称
         * @property {string} md5 exe的md5
         * @property {Object} [params] 额外的参数
         */
        /**
         * 启动外部EXE
         * @eapi
         * @param {LaunchExeParams} param 外部EXE参数
         * @returns {Promise<void>} 启动失败reject
         */
        export function launchExe(param: {
            /**
             * exe的名称
             */
            name: string;
            /**
             * exe的md5
             */
            md5: string;
            /**
             * 额外的参数
             */
            params?: Object;
        }): Promise<void>;
        /**
         * 外部EXE参数
         * @edata
         * @typedef {Object} LaunchExeParams
         * @property {string} name exe的名称
         * @property {string} md5 exe的md5
         * @property {Object} [params] 额外的参数
         */
        /**
         * 启动外部EXE
         * @eapi
         * @param {LaunchExeParams} param 外部EXE参数
         * @returns {Promise<void>} 启动失败reject
         */
        export function launchExe(param: {
            /**
             * exe的名称
             */
            name: string;
            /**
             * exe的md5
             */
            md5: string;
            /**
             * 额外的参数
             */
            params?: Object;
        }): Promise<void>;
        /**
         * Exe消息回调
         * @edata
         * @callback ExeCallback
         * @param {string} data 消息内容
         */
        /**
         * 监听小程序外部EXE消息参数
         * @edata
         * @typedef {Object} ExeMessageParams
         * @property {string} md5 要监听消息exe的md5
         * @property {ExeCallback} callback 消息回调
         */
        /**
         * 监听小程序外部EXE消息
         * @eapi
         * @param {ExeMessageParams} param 监听小程序外部EXE消息参数
         * @returns {Promise<void>} 注册监听失败 reject
         */
        export function onExeMessage(param: {
            /**
             * 要监听消息exe的md5
             */
            md5: string;
            /**
             * 消息回调
             */
            callback: (data: string) => any;
        }): Promise<void>;
        /**
         * Exe消息回调
         * @edata
         * @callback ExeCallback
         * @param {string} data 消息内容
         */
        /**
         * 监听小程序外部EXE消息参数
         * @edata
         * @typedef {Object} ExeMessageParams
         * @property {string} md5 要监听消息exe的md5
         * @property {ExeCallback} callback 消息回调
         */
        /**
         * 监听小程序外部EXE消息
         * @eapi
         * @param {ExeMessageParams} param 监听小程序外部EXE消息参数
         * @returns {Promise<void>} 注册监听失败 reject
         */
        export function onExeMessage(param: {
            /**
             * 要监听消息exe的md5
             */
            md5: string;
            /**
             * 消息回调
             */
            callback: (data: string) => any;
        }): Promise<void>;
        /**
         * 状态信息
         * @edata
         * @typedef {Object} ExeStateInfo
         * @property {string} state 枚举状态 "0"-exe启动成功, "1"-exe启动失败, "2"-exe退出, "3"-exe为建立链接, "4"-exe链接成功, "5"-exe断开链接, "6"-exe网络错误
         */
        /**
         * Exe状态变化回调
         * @edata
         * @callback ExeStateCallback
         * @param {ExeStateInfo} info 消息内容
         */
        /**
         * EXE状态监听
         * @edata
         * @typedef {Object} ExeStateListener
         * @property {string} md5 exe的md5
         * @property {ExeStateCallback} callback 状态变化回调
         */
        /**
         * 监听小程序外部EXE状态变化消息
         * @eapi
         * @param {ExeStateListener} param 传入参数
         * @returns {Promise<void>} 注册监听失败 reject
         */
        export function onExeStateChange(param: {
            /**
             * exe的md5
             */
            md5: string;
            /**
             * 状态变化回调
             */
            callback: (info: {
                /**
                 * 枚举状态 "0"-exe启动成功, "1"-exe启动失败, "2"-exe退出, "3"-exe为建立链接, "4"-exe链接成功, "5"-exe断开链接, "6"-exe网络错误
                 */
                state: string;
            }) => any;
        }): Promise<void>;
        /**
         * 状态信息
         * @edata
         * @typedef {Object} ExeStateInfo
         * @property {string} state 枚举状态 "0"-exe启动成功, "1"-exe启动失败, "2"-exe退出, "3"-exe为建立链接, "4"-exe链接成功, "5"-exe断开链接, "6"-exe网络错误
         */
        /**
         * Exe状态变化回调
         * @edata
         * @callback ExeStateCallback
         * @param {ExeStateInfo} info 消息内容
         */
        /**
         * EXE状态监听
         * @edata
         * @typedef {Object} ExeStateListener
         * @property {string} md5 exe的md5
         * @property {ExeStateCallback} callback 状态变化回调
         */
        /**
         * 监听小程序外部EXE状态变化消息
         * @eapi
         * @param {ExeStateListener} param 传入参数
         * @returns {Promise<void>} 注册监听失败 reject
         */
        export function onExeStateChange(param: {
            /**
             * exe的md5
             */
            md5: string;
            /**
             * 状态变化回调
             */
            callback: (info: {
                /**
                 * 枚举状态 "0"-exe启动成功, "1"-exe启动失败, "2"-exe退出, "3"-exe为建立链接, "4"-exe链接成功, "5"-exe断开链接, "6"-exe网络错误
                 */
                state: string;
            }) => any;
        }): Promise<void>;
        /**
         * 发到EXE的信息
         * @edata
         * @typedef {Object} SendToExeInfo
         * @property {string} md5 要发送消息exe的md5
         * @property {string} data 要发送消息exe的数据
         */
        /**
         * 发送消息到小程序外部EXE
         * @eapi
         * @param {SendToExeInfo} param 发到EXE的信息
         * @returns {Promise<void>} 发送失败 reject
         */
        export function sendToExe(param: {
            /**
             * 要发送消息exe的md5
             */
            md5: string;
            /**
             * 要发送消息exe的数据
             */
            data: string;
        }): Promise<void>;
        /**
         * 发到EXE的信息
         * @edata
         * @typedef {Object} SendToExeInfo
         * @property {string} md5 要发送消息exe的md5
         * @property {string} data 要发送消息exe的数据
         */
        /**
         * 发送消息到小程序外部EXE
         * @eapi
         * @param {SendToExeInfo} param 发到EXE的信息
         * @returns {Promise<void>} 发送失败 reject
         */
        export function sendToExe(param: {
            /**
             * 要发送消息exe的md5
             */
            md5: string;
            /**
             * 要发送消息exe的数据
             */
            data: string;
        }): Promise<void>;
        /**
         * 带token的url信息
         * @edata
         * @typedef {Object} TokenUrlInfo
         * @property {string} tokenUrl 带token的url
         */
        /**
         * 获取带token的url参数
         * @edata
         * @typedef {Object} TokenUrlParams
         * @property {string} baseUrl 基础url
         */
        /**
         * 获取带token的url
         * @eapi
         * @param {TokenUrlParams} param 获取带token的url参数
         * @returns {Promise<TokenUrlInfo>} 返回信息
         */
        export function getTokenUrl(param: {
            /**
             * 基础url
             */
            baseUrl: string;
        }): Promise<{
            /**
             * 带token的url
             */
            tokenUrl: string;
        }>;
        /**
         * 带token的url信息
         * @edata
         * @typedef {Object} TokenUrlInfo
         * @property {string} tokenUrl 带token的url
         */
        /**
         * 获取带token的url参数
         * @edata
         * @typedef {Object} TokenUrlParams
         * @property {string} baseUrl 基础url
         */
        /**
         * 获取带token的url
         * @eapi
         * @param {TokenUrlParams} param 获取带token的url参数
         * @returns {Promise<TokenUrlInfo>} 返回信息
         */
        export function getTokenUrl(param: {
            /**
             * 基础url
             */
            baseUrl: string;
        }): Promise<{
            /**
             * 带token的url
             */
            tokenUrl: string;
        }>;
    }
}
export default _default;
