declare namespace _default {
    export namespace panel {
        /**
         * 布局信息
         * @edata
         * @typedef {Object} LayoutData
         * @property {boolean} visible 是否可见，默认true
         * @property {number} x 左上角横坐标占容器的比例
         * @property {number} y 左上角纵坐标占容器的比例
         * @property {number} width 宽度占容器的比例
         * @property {number} height 高度占容器的比例
         * @property {boolean} [animate] 是否带动画效果
         * @property {number} [duration] 动画时长（毫秒）
         * @property {number} [alpha] 不透明度
         */
        /**
         * 设置小程序布局
         * @summary 适用于浮窗小程序
         * @eapi
         * @param {LayoutData} params 布局信息
         * @returns {Promise<void>} 调用结果
         */
        export function setLayout(params: {
            /**
             * 是否可见，默认true
             */
            visible: boolean;
            /**
             * 左上角横坐标占容器的比例
             */
            x: number;
            /**
             * 左上角纵坐标占容器的比例
             */
            y: number;
            /**
             * 宽度占容器的比例
             */
            width: number;
            /**
             * 高度占容器的比例
             */
            height: number;
            /**
             * 是否带动画效果
             */
            animate?: boolean;
            /**
             * 动画时长（毫秒）
             */
            duration?: number;
            /**
             * 不透明度
             */
            alpha?: number;
        }): Promise<void>;
        /**
         * 布局信息
         * @edata
         * @typedef {Object} LayoutData
         * @property {boolean} visible 是否可见，默认true
         * @property {number} x 左上角横坐标占容器的比例
         * @property {number} y 左上角纵坐标占容器的比例
         * @property {number} width 宽度占容器的比例
         * @property {number} height 高度占容器的比例
         * @property {boolean} [animate] 是否带动画效果
         * @property {number} [duration] 动画时长（毫秒）
         * @property {number} [alpha] 不透明度
         */
        /**
         * 设置小程序布局
         * @summary 适用于浮窗小程序
         * @eapi
         * @param {LayoutData} params 布局信息
         * @returns {Promise<void>} 调用结果
         */
        export function setLayout(params: {
            /**
             * 是否可见，默认true
             */
            visible: boolean;
            /**
             * 左上角横坐标占容器的比例
             */
            x: number;
            /**
             * 左上角纵坐标占容器的比例
             */
            y: number;
            /**
             * 宽度占容器的比例
             */
            width: number;
            /**
             * 高度占容器的比例
             */
            height: number;
            /**
             * 是否带动画效果
             */
            animate?: boolean;
            /**
             * 动画时长（毫秒）
             */
            duration?: number;
            /**
             * 不透明度
             */
            alpha?: number;
        }): Promise<void>;
        /**
         * 主动销毁当前小程序
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function disposal(): Promise<void>;
        /**
         * 主动销毁当前小程序
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function disposal(): Promise<void>;
        /**
         * 设置关闭按钮参数
         * @edata
         * @typedef {Object} SetBtnParams
         * @property {boolean} enable 是否启用原生关闭按钮
         * @property {number} [x] 相对于小程序视图左上角的横坐标
         * @property {number} [y] 相对于小程序视图左上角的纵坐标
         * @property {number} [width] 关闭按钮的宽度
         * @property {number} [height] 关闭按钮的高度
         * @property {string} [imgUrl] 关闭按钮的背景图
         */
        /**
         * 设置浮窗小程序的关闭按钮
         * @summary 仅支持浮窗类型的小程序
         * - 用户点击这个原生的关闭按钮后小程序会被强制销毁
         * @eapi
         * @param {SetBtnParams} params 设置关闭按钮参数
         * @returns {Promise<void>} 设置结果
         */
        export function setPopupCloseBtn(params: {
            /**
             * 是否启用原生关闭按钮
             */
            enable: boolean;
            /**
             * 相对于小程序视图左上角的横坐标
             */
            x?: number;
            /**
             * 相对于小程序视图左上角的纵坐标
             */
            y?: number;
            /**
             * 关闭按钮的宽度
             */
            width?: number;
            /**
             * 关闭按钮的高度
             */
            height?: number;
            /**
             * 关闭按钮的背景图
             */
            imgUrl?: string;
        }): Promise<void>;
        /**
         * 设置关闭按钮参数
         * @edata
         * @typedef {Object} SetBtnParams
         * @property {boolean} enable 是否启用原生关闭按钮
         * @property {number} [x] 相对于小程序视图左上角的横坐标
         * @property {number} [y] 相对于小程序视图左上角的纵坐标
         * @property {number} [width] 关闭按钮的宽度
         * @property {number} [height] 关闭按钮的高度
         * @property {string} [imgUrl] 关闭按钮的背景图
         */
        /**
         * 设置浮窗小程序的关闭按钮
         * @summary 仅支持浮窗类型的小程序
         * - 用户点击这个原生的关闭按钮后小程序会被强制销毁
         * @eapi
         * @param {SetBtnParams} params 设置关闭按钮参数
         * @returns {Promise<void>} 设置结果
         */
        export function setPopupCloseBtn(params: {
            /**
             * 是否启用原生关闭按钮
             */
            enable: boolean;
            /**
             * 相对于小程序视图左上角的横坐标
             */
            x?: number;
            /**
             * 相对于小程序视图左上角的纵坐标
             */
            y?: number;
            /**
             * 关闭按钮的宽度
             */
            width?: number;
            /**
             * 关闭按钮的高度
             */
            height?: number;
            /**
             * 关闭按钮的背景图
             */
            imgUrl?: string;
        }): Promise<void>;
    }
}
export default _default;
