declare namespace _default {
    export namespace reg {
        /**
         * @edata
         * @typedef {Object} SpeechResp 语音识别消息
         * @property {string} data 语音识别出来的文字
         */
        /**
         * 语音识别回调
         * @edata
         * @callback SpeechCallback
         * @param {SpeechResp} recognition 语音识别消息
         */
        /**
         * 语音识别参数
         * @edata
         * @typedef {Object} SpeechParams 参数
         * @property {Array.<string>} hotwords 热词
         * @property {SpeechCallback} callback 语音识别回调
         */
        /**
         * 监听当前直播间语音识别消息
         * @eapi
         * @param {SpeechParams} param 语音识别参数
         * @returns {Promise<void>} 调用结果
         */
        export function onSpeechRecognition(param: {
            /**
             * 热词
             */
            hotwords: string[];
            /**
             * 语音识别回调
             */
            callback: (recognition: {
                /**
                 * 语音识别出来的文字
                 */
                data: string;
            }) => any;
        }): Promise<void>;
        /**
         * @edata
         * @typedef {Object} SpeechResp 语音识别消息
         * @property {string} data 语音识别出来的文字
         */
        /**
         * 语音识别回调
         * @edata
         * @callback SpeechCallback
         * @param {SpeechResp} recognition 语音识别消息
         */
        /**
         * 语音识别参数
         * @edata
         * @typedef {Object} SpeechParams 参数
         * @property {Array.<string>} hotwords 热词
         * @property {SpeechCallback} callback 语音识别回调
         */
        /**
         * 监听当前直播间语音识别消息
         * @eapi
         * @param {SpeechParams} param 语音识别参数
         * @returns {Promise<void>} 调用结果
         */
        export function onSpeechRecognition(param: {
            /**
             * 热词
             */
            hotwords: string[];
            /**
             * 语音识别回调
             */
            callback: (recognition: {
                /**
                 * 语音识别出来的文字
                 */
                data: string;
            }) => any;
        }): Promise<void>;
        /**
         * 取消监听当前直播间语音识别消息
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function offSpeechRecognition(): Promise<void>;
        /**
         * 取消监听当前直播间语音识别消息
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function offSpeechRecognition(): Promise<void>;
        /**
         * @edata
         * @typedef {Object} GestureResp 手势识别消息
         * @property {string} key 手势识别的标识 BIXIN-比心
         */
        /**
         * 手势识别回调
         * @edata
         * @callback GestureCallback
         * @param {GestureResp} recognition 识别消息
         */
        /**
         * @edata
         * @typedef {Object} GestureRecognitionParams
         * @property {GestureCallback} callback 手势识别回调
         */
        /**
         * 监听当前直播间手势识别消息
         * @summary 双面镜、两屏、三屏的时候提示接口不支持
         * @eapi
         * @param {GestureRecognitionParams} param 手势识别参数
         * @returns {Promise<void>} 调用结果
         */
        export function onGestureRecognition(param: {
            /**
             * 手势识别回调
             */
            callback: (recognition: {
                /**
                 * 手势识别的标识 BIXIN-比心
                 */
                key: string;
            }) => any;
        }): Promise<void>;
        /**
         * @edata
         * @typedef {Object} GestureResp 手势识别消息
         * @property {string} key 手势识别的标识 BIXIN-比心
         */
        /**
         * 手势识别回调
         * @edata
         * @callback GestureCallback
         * @param {GestureResp} recognition 识别消息
         */
        /**
         * @edata
         * @typedef {Object} GestureRecognitionParams
         * @property {GestureCallback} callback 手势识别回调
         */
        /**
         * 监听当前直播间手势识别消息
         * @summary 双面镜、两屏、三屏的时候提示接口不支持
         * @eapi
         * @param {GestureRecognitionParams} param 手势识别参数
         * @returns {Promise<void>} 调用结果
         */
        export function onGestureRecognition(param: {
            /**
             * 手势识别回调
             */
            callback: (recognition: {
                /**
                 * 手势识别的标识 BIXIN-比心
                 */
                key: string;
            }) => any;
        }): Promise<void>;
        /**
         * 取消监听当前直播间手势识别消息
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function offGestureRecognition(): Promise<void>;
        /**
         * 取消监听当前直播间手势识别消息
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function offGestureRecognition(): Promise<void>;
        /**
         * 画布信息
         * @edata
         * @typedef {Object} CanvasInfo
         * @property {number} width 画布宽度
         * @property {number} height 画布高度
         */
        /**
         * 骨骼点信息
         * @edata
         * @typedef {Object} KeypointInfo
         * @property {number} x 横坐标（值域 [0, 画布宽]，单位是像素）
         * @property {number} y 纵坐标（值域 [0, 画布宽]，单位是像素）
         * @property {number} score 置信度（值越高表示识别得越准确）
         * @property {string} id 骨骼点的标识 "0"-NOSE, "1"-LEFT_EYE, "2"-RIGHT_EYE, "3"-LEFT_EAR, "4"-RIGHT_EAR, "5"-LEFT_SHOULDER, "6"-RIGHT_SHOULDER, "7"-LEFT_ELBOW, "8"-RIGHT_ELBOW, "9"-LEFT_WRIST, "10"-RIGHT_WRIST, "11"-LEFT_HIP, "12"-RIGHT_HIP, "13"-LEFT_KNEE, "14"-RIGHT_KNEE, "15"-LEFT_ANKLE, "16"-RIGHT_ANKLE, "17"-LEFT_HAND, "18"-RIGHT_HAND
         */
        /**
         * 骨骼识别消息
         * @edata
         * @typedef {Object} SkeletonResp
         * @property {CanvasInfo} canvas 画布信息
         * @property {Array.<KeypointInfo>} keypoints 骨骼点
         */
        /**
         * 骨骼识别回调
         * @edata
         * @callback SkeletonCallback
         * @param {SkeletonResp} recognition 骨骼识别消息
         */
        /**
         * 骨骼识别消息
         * @edata
         * @typedef {Object} HumanSkeletonDetectionParams
         * @property {SkeletonCallback} callback 骨骼识别回调
         */
        /**
         * 监听当前直播间肢体骨骼点检测消息
         * @summary 双面镜、两屏、三屏的时候提示接口不支持
         * - 开启左右翻转后点的下标和识别部位的对应关系会发生变化
         * @eapi
         * @param {HumanSkeletonDetectionParams} param 参数
         * @returns {Promise<void>} 调用结果
         */
        export function onHumanSkeletonDetection(param: {
            /**
             * 骨骼识别回调
             */
            callback: (recognition: {
                /**
                 * 画布信息
                 */
                canvas: {
                    /**
                     * 画布宽度
                     */
                    width: number;
                    /**
                     * 画布高度
                     */
                    height: number;
                };
                /**
                 * 骨骼点
                 */
                keypoints: {
                    /**
                     * 横坐标（值域 [0, 画布宽]，单位是像素）
                     */
                    x: number;
                    /**
                     * 纵坐标（值域 [0, 画布宽]，单位是像素）
                     */
                    y: number;
                    /**
                     * 置信度（值越高表示识别得越准确）
                     */
                    score: number;
                    /**
                     * 骨骼点的标识 "0"-NOSE, "1"-LEFT_EYE, "2"-RIGHT_EYE, "3"-LEFT_EAR, "4"-RIGHT_EAR, "5"-LEFT_SHOULDER, "6"-RIGHT_SHOULDER, "7"-LEFT_ELBOW, "8"-RIGHT_ELBOW, "9"-LEFT_WRIST, "10"-RIGHT_WRIST, "11"-LEFT_HIP, "12"-RIGHT_HIP, "13"-LEFT_KNEE, "14"-RIGHT_KNEE, "15"-LEFT_ANKLE, "16"-RIGHT_ANKLE, "17"-LEFT_HAND, "18"-RIGHT_HAND
                     */
                    id: string;
                }[];
            }) => any;
        }): Promise<void>;
        /**
         * 画布信息
         * @edata
         * @typedef {Object} CanvasInfo
         * @property {number} width 画布宽度
         * @property {number} height 画布高度
         */
        /**
         * 骨骼点信息
         * @edata
         * @typedef {Object} KeypointInfo
         * @property {number} x 横坐标（值域 [0, 画布宽]，单位是像素）
         * @property {number} y 纵坐标（值域 [0, 画布宽]，单位是像素）
         * @property {number} score 置信度（值越高表示识别得越准确）
         * @property {string} id 骨骼点的标识 "0"-NOSE, "1"-LEFT_EYE, "2"-RIGHT_EYE, "3"-LEFT_EAR, "4"-RIGHT_EAR, "5"-LEFT_SHOULDER, "6"-RIGHT_SHOULDER, "7"-LEFT_ELBOW, "8"-RIGHT_ELBOW, "9"-LEFT_WRIST, "10"-RIGHT_WRIST, "11"-LEFT_HIP, "12"-RIGHT_HIP, "13"-LEFT_KNEE, "14"-RIGHT_KNEE, "15"-LEFT_ANKLE, "16"-RIGHT_ANKLE, "17"-LEFT_HAND, "18"-RIGHT_HAND
         */
        /**
         * 骨骼识别消息
         * @edata
         * @typedef {Object} SkeletonResp
         * @property {CanvasInfo} canvas 画布信息
         * @property {Array.<KeypointInfo>} keypoints 骨骼点
         */
        /**
         * 骨骼识别回调
         * @edata
         * @callback SkeletonCallback
         * @param {SkeletonResp} recognition 骨骼识别消息
         */
        /**
         * 骨骼识别消息
         * @edata
         * @typedef {Object} HumanSkeletonDetectionParams
         * @property {SkeletonCallback} callback 骨骼识别回调
         */
        /**
         * 监听当前直播间肢体骨骼点检测消息
         * @summary 双面镜、两屏、三屏的时候提示接口不支持
         * - 开启左右翻转后点的下标和识别部位的对应关系会发生变化
         * @eapi
         * @param {HumanSkeletonDetectionParams} param 参数
         * @returns {Promise<void>} 调用结果
         */
        export function onHumanSkeletonDetection(param: {
            /**
             * 骨骼识别回调
             */
            callback: (recognition: {
                /**
                 * 画布信息
                 */
                canvas: {
                    /**
                     * 画布宽度
                     */
                    width: number;
                    /**
                     * 画布高度
                     */
                    height: number;
                };
                /**
                 * 骨骼点
                 */
                keypoints: {
                    /**
                     * 横坐标（值域 [0, 画布宽]，单位是像素）
                     */
                    x: number;
                    /**
                     * 纵坐标（值域 [0, 画布宽]，单位是像素）
                     */
                    y: number;
                    /**
                     * 置信度（值越高表示识别得越准确）
                     */
                    score: number;
                    /**
                     * 骨骼点的标识 "0"-NOSE, "1"-LEFT_EYE, "2"-RIGHT_EYE, "3"-LEFT_EAR, "4"-RIGHT_EAR, "5"-LEFT_SHOULDER, "6"-RIGHT_SHOULDER, "7"-LEFT_ELBOW, "8"-RIGHT_ELBOW, "9"-LEFT_WRIST, "10"-RIGHT_WRIST, "11"-LEFT_HIP, "12"-RIGHT_HIP, "13"-LEFT_KNEE, "14"-RIGHT_KNEE, "15"-LEFT_ANKLE, "16"-RIGHT_ANKLE, "17"-LEFT_HAND, "18"-RIGHT_HAND
                     */
                    id: string;
                }[];
            }) => any;
        }): Promise<void>;
        /**
         * 取消监听当前直播间肢体骨骼点检测消息
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function offHumanSkeletonDetection(): Promise<void>;
        /**
         * 取消监听当前直播间肢体骨骼点检测消息
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function offHumanSkeletonDetection(): Promise<void>;
        /**
         * 人脸框信息
         * @edata
         * @typedef {Object} FaceRect
         * @property {number} x 人脸框左上角横坐标（相对与视频区域左上角，单位是像素）
         * @property {number} y 人脸框左上角纵坐标（相对与视频区域左上角，单位是像素）
         * @property {number} width 人脸框宽度（相对与视频区域左上角，单位是像素）
         * @property {number} height 人脸框高度（相对与视频区域左上角，单位是像素）
         */
        /**
         * 人脸特征点信息
         * @edata
         * @typedef {Object} Landmark
         * @property {number} x 横坐标（值域 [0, 画布宽]，单位是像素）
         * @property {number} y 纵坐标（值域 [0, 画布高]，单位是像素）
         */
        /**
         * 人脸信息
         * @edata
         * @typedef {Object} FaceInfo
         * @property {FaceRect} faceRect 人脸框
         * @property {number} pitch	俯仰角（x轴），值域 [-90, 90]
         * @property {number} yaw	偏航角（y轴），值域 [-90, 90]
         * @property {number} roll 翻滚角（z轴），值域 [-180, 180]
         * @property {Array.<Landmark>} landmarks106 人脸特征点
         */
        /**
         * 人脸识别消息
         * @edata
         * @typedef {Object} FacialResp
         * @property {CanvasInfo} canvas 画布信息
         * @property {Array.<FaceInfo>} faces 人脸信息
         */
        /**
         * 人脸识别回调
         * @edata
         * @callback FacialCallback
         * @param {FacialResp} recognition 人脸识别消息
         */
        /**
         * @edata
         * @typedef {Object} FacialLandmarkDetectionParams
         * @property {FacialCallback} callback 人脸识别回调
         */
        /**
         * 监听当前直播间人脸特征点检测消息
         * @summary 双面镜、两屏、三屏的时候提示接口不支持
         * - 开启左右翻转后点的下标和识别部位的对应关系会发生变化
         * @eapi
         * @param {FacialLandmarkDetectionParams} param 参数
         * @returns {Promise<void>} 调用结果
         */
        export function onFacialLandmarkDetection(param: {
            /**
             * 人脸识别回调
             */
            callback: (recognition: {
                /**
                 * 画布信息
                 */
                canvas: {
                    /**
                     * 画布宽度
                     */
                    width: number;
                    /**
                     * 画布高度
                     */
                    height: number;
                };
                /**
                 * 人脸信息
                 */
                faces: {
                    /**
                     * 人脸框
                     */
                    faceRect: {
                        /**
                         * 人脸框左上角横坐标（相对与视频区域左上角，单位是像素）
                         */
                        x: number;
                        /**
                         * 人脸框左上角纵坐标（相对与视频区域左上角，单位是像素）
                         */
                        y: number;
                        /**
                         * 人脸框宽度（相对与视频区域左上角，单位是像素）
                         */
                        width: number;
                        /**
                         * 人脸框高度（相对与视频区域左上角，单位是像素）
                         */
                        height: number;
                    };
                    /**
                     * 俯仰角（x轴），值域 [-90, 90]
                     */
                    pitch: number;
                    /**
                     * 偏航角（y轴），值域 [-90, 90]
                     */
                    yaw: number;
                    /**
                     * 翻滚角（z轴），值域 [-180, 180]
                     */
                    roll: number;
                    /**
                     * 人脸特征点
                     */
                    landmarks106: {
                        /**
                         * 横坐标（值域 [0, 画布宽]，单位是像素）
                         */
                        x: number;
                        /**
                         * 纵坐标（值域 [0, 画布高]，单位是像素）
                         */
                        y: number;
                    }[];
                }[];
            }) => any;
        }): Promise<void>;
        /**
         * 人脸框信息
         * @edata
         * @typedef {Object} FaceRect
         * @property {number} x 人脸框左上角横坐标（相对与视频区域左上角，单位是像素）
         * @property {number} y 人脸框左上角纵坐标（相对与视频区域左上角，单位是像素）
         * @property {number} width 人脸框宽度（相对与视频区域左上角，单位是像素）
         * @property {number} height 人脸框高度（相对与视频区域左上角，单位是像素）
         */
        /**
         * 人脸特征点信息
         * @edata
         * @typedef {Object} Landmark
         * @property {number} x 横坐标（值域 [0, 画布宽]，单位是像素）
         * @property {number} y 纵坐标（值域 [0, 画布高]，单位是像素）
         */
        /**
         * 人脸信息
         * @edata
         * @typedef {Object} FaceInfo
         * @property {FaceRect} faceRect 人脸框
         * @property {number} pitch	俯仰角（x轴），值域 [-90, 90]
         * @property {number} yaw	偏航角（y轴），值域 [-90, 90]
         * @property {number} roll 翻滚角（z轴），值域 [-180, 180]
         * @property {Array.<Landmark>} landmarks106 人脸特征点
         */
        /**
         * 人脸识别消息
         * @edata
         * @typedef {Object} FacialResp
         * @property {CanvasInfo} canvas 画布信息
         * @property {Array.<FaceInfo>} faces 人脸信息
         */
        /**
         * 人脸识别回调
         * @edata
         * @callback FacialCallback
         * @param {FacialResp} recognition 人脸识别消息
         */
        /**
         * @edata
         * @typedef {Object} FacialLandmarkDetectionParams
         * @property {FacialCallback} callback 人脸识别回调
         */
        /**
         * 监听当前直播间人脸特征点检测消息
         * @summary 双面镜、两屏、三屏的时候提示接口不支持
         * - 开启左右翻转后点的下标和识别部位的对应关系会发生变化
         * @eapi
         * @param {FacialLandmarkDetectionParams} param 参数
         * @returns {Promise<void>} 调用结果
         */
        export function onFacialLandmarkDetection(param: {
            /**
             * 人脸识别回调
             */
            callback: (recognition: {
                /**
                 * 画布信息
                 */
                canvas: {
                    /**
                     * 画布宽度
                     */
                    width: number;
                    /**
                     * 画布高度
                     */
                    height: number;
                };
                /**
                 * 人脸信息
                 */
                faces: {
                    /**
                     * 人脸框
                     */
                    faceRect: {
                        /**
                         * 人脸框左上角横坐标（相对与视频区域左上角，单位是像素）
                         */
                        x: number;
                        /**
                         * 人脸框左上角纵坐标（相对与视频区域左上角，单位是像素）
                         */
                        y: number;
                        /**
                         * 人脸框宽度（相对与视频区域左上角，单位是像素）
                         */
                        width: number;
                        /**
                         * 人脸框高度（相对与视频区域左上角，单位是像素）
                         */
                        height: number;
                    };
                    /**
                     * 俯仰角（x轴），值域 [-90, 90]
                     */
                    pitch: number;
                    /**
                     * 偏航角（y轴），值域 [-90, 90]
                     */
                    yaw: number;
                    /**
                     * 翻滚角（z轴），值域 [-180, 180]
                     */
                    roll: number;
                    /**
                     * 人脸特征点
                     */
                    landmarks106: {
                        /**
                         * 横坐标（值域 [0, 画布宽]，单位是像素）
                         */
                        x: number;
                        /**
                         * 纵坐标（值域 [0, 画布高]，单位是像素）
                         */
                        y: number;
                    }[];
                }[];
            }) => any;
        }): Promise<void>;
        /**
         * 取消监听当前直播间肢体骨骼点检测消息
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function offFacialLandmarkDetection(): Promise<void>;
        /**
         * 取消监听当前直播间肢体骨骼点检测消息
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function offFacialLandmarkDetection(): Promise<void>;
        /**
         * 轮廓点信息
         * @edata
         * @typedef {Object} ContourPointInfo
         * @property {number} x 横坐标（值域 [0, 画布宽]，单位是像素）
         * @property {number} y 纵坐标（值域 [0, 画布高]，单位是像素）
         */
        /**
         * 人体轮廓识别消息
         * @edata
         * @typedef {Object} HumanResp
         * @property {CanvasInfo} canvas 画布信息
         * @property {Array.<ContourPointInfo>} contourPoints 轮廓点
         * @property {number} contourCount 轮廓数，值域为正整数
         */
        /**
         * 人体轮廓识别回调
         * @edata
         * @callback HumanCallback
         * @param {HumanResp} recognition 人体轮廓识别消息
         */
        /**
         * 人体轮廓识别消息参数
         * @edata
         * @typedef {Object} HumanContourDetectionParams
         * @property {HumanCallback} callback 画布信息
         */
        /**
         * 监听当前直播间人体轮廓点检测消息
         * @summary 双面镜、两屏、三屏的时候提示接口不支持
         * @eapi
         * @param {HumanContourDetectionParams} param 人体轮廓识别消息参数
         * @returns {Promise<void>} 调用结果
         */
        export function onHumanContourDetection(param: {
            /**
             * 画布信息
             */
            callback: (recognition: {
                /**
                 * 画布信息
                 */
                canvas: {
                    /**
                     * 画布宽度
                     */
                    width: number;
                    /**
                     * 画布高度
                     */
                    height: number;
                };
                /**
                 * 轮廓点
                 */
                contourPoints: {
                    /**
                     * 横坐标（值域 [0, 画布宽]，单位是像素）
                     */
                    x: number;
                    /**
                     * 纵坐标（值域 [0, 画布高]，单位是像素）
                     */
                    y: number;
                }[];
                /**
                 * 轮廓数，值域为正整数
                 */
                contourCount: number;
            }) => any;
        }): Promise<void>;
        /**
         * 轮廓点信息
         * @edata
         * @typedef {Object} ContourPointInfo
         * @property {number} x 横坐标（值域 [0, 画布宽]，单位是像素）
         * @property {number} y 纵坐标（值域 [0, 画布高]，单位是像素）
         */
        /**
         * 人体轮廓识别消息
         * @edata
         * @typedef {Object} HumanResp
         * @property {CanvasInfo} canvas 画布信息
         * @property {Array.<ContourPointInfo>} contourPoints 轮廓点
         * @property {number} contourCount 轮廓数，值域为正整数
         */
        /**
         * 人体轮廓识别回调
         * @edata
         * @callback HumanCallback
         * @param {HumanResp} recognition 人体轮廓识别消息
         */
        /**
         * 人体轮廓识别消息参数
         * @edata
         * @typedef {Object} HumanContourDetectionParams
         * @property {HumanCallback} callback 画布信息
         */
        /**
         * 监听当前直播间人体轮廓点检测消息
         * @summary 双面镜、两屏、三屏的时候提示接口不支持
         * @eapi
         * @param {HumanContourDetectionParams} param 人体轮廓识别消息参数
         * @returns {Promise<void>} 调用结果
         */
        export function onHumanContourDetection(param: {
            /**
             * 画布信息
             */
            callback: (recognition: {
                /**
                 * 画布信息
                 */
                canvas: {
                    /**
                     * 画布宽度
                     */
                    width: number;
                    /**
                     * 画布高度
                     */
                    height: number;
                };
                /**
                 * 轮廓点
                 */
                contourPoints: {
                    /**
                     * 横坐标（值域 [0, 画布宽]，单位是像素）
                     */
                    x: number;
                    /**
                     * 纵坐标（值域 [0, 画布高]，单位是像素）
                     */
                    y: number;
                }[];
                /**
                 * 轮廓数，值域为正整数
                 */
                contourCount: number;
            }) => any;
        }): Promise<void>;
        /**
         * 取消监听当前直播间人体轮廓点检测消息
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function offHumanContourDetection(): Promise<void>;
        /**
         * 取消监听当前直播间人体轮廓点检测消息
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function offHumanContourDetection(): Promise<void>;
        /**
         * 人体轮廓识别对象
         * @edata
         * @typedef {Object} CVRecognition
         * @property {string} cvRecKey key
         * @property {Object} cvRecValue value
         */
        /**
         * 人体轮廓识别回调
         * @edata
         * @callback OnCVRecognitionOptionsCallback
         * @param {Array.<CVRecognition>} recognitions 识别消息列表
         */
        /**
         * 人体轮廓识别参数
         * @edata
         * @typedef {Object} CVRecognitionParams
         * @property {Array.<string>} keys 识别标识
         * @property {OnCVRecognitionOptionsCallback} callback
         */
        /**
         * 监听当前直播间视觉识别消息
         * @eapi
         * @param {CVRecognitionParams} param 人体轮廓识别参数
         * @returns {Promise<void>} 调用结果
         */
        export function onCVRecognition(param: {
            /**
             * 识别标识
             */
            keys: string[];
            callback: (recognitions: {
                /**
                 * key
                 */
                cvRecKey: string;
                /**
                 * value
                 */
                cvRecValue: Object;
            }[]) => any;
        }): Promise<void>;
        /**
         * 人体轮廓识别对象
         * @edata
         * @typedef {Object} CVRecognition
         * @property {string} cvRecKey key
         * @property {Object} cvRecValue value
         */
        /**
         * 人体轮廓识别回调
         * @edata
         * @callback OnCVRecognitionOptionsCallback
         * @param {Array.<CVRecognition>} recognitions 识别消息列表
         */
        /**
         * 人体轮廓识别参数
         * @edata
         * @typedef {Object} CVRecognitionParams
         * @property {Array.<string>} keys 识别标识
         * @property {OnCVRecognitionOptionsCallback} callback
         */
        /**
         * 监听当前直播间视觉识别消息
         * @eapi
         * @param {CVRecognitionParams} param 人体轮廓识别参数
         * @returns {Promise<void>} 调用结果
         */
        export function onCVRecognition(param: {
            /**
             * 识别标识
             */
            keys: string[];
            callback: (recognitions: {
                /**
                 * key
                 */
                cvRecKey: string;
                /**
                 * value
                 */
                cvRecValue: Object;
            }[]) => any;
        }): Promise<void>;
        /**
         * 取消监听当前直播间视觉识别参数
         * @edata
         * @typedef {Object} OffCVRecognitionParams
         * @property {Array.<string>} keys 识别标识
         */
        /**
         * 取消监听当前直播间视觉识别消息
         * @eapi
         * @param {OffCVRecognitionParams} param 取消监听当前直播间视觉识别参数
         * @returns {Promise<void>} 调用结果
         */
        export function offCVRecognition(param: {
            /**
             * 识别标识
             */
            keys: string[];
        }): Promise<void>;
        /**
         * 取消监听当前直播间视觉识别参数
         * @edata
         * @typedef {Object} OffCVRecognitionParams
         * @property {Array.<string>} keys 识别标识
         */
        /**
         * 取消监听当前直播间视觉识别消息
         * @eapi
         * @param {OffCVRecognitionParams} param 取消监听当前直播间视觉识别参数
         * @returns {Promise<void>} 调用结果
         */
        export function offCVRecognition(param: {
            /**
             * 识别标识
             */
            keys: string[];
        }): Promise<void>;
        /**
         * 查询当前直播间视觉识别结果参数
         * @edata
         * @typedef {Object} QueryCVRecognitionParams
         * @property {Array.<string>} keys 识别标识
         */
        /**
         * 查询当前直播间视觉识别结果
         * @eapi
         * @param {QueryCVRecognitionParams} param 参数
         * @returns {Promise<Array.<CVRecognition>>} 识别消息列表
         */
        export function queryCVRecognition(param: {
            /**
             * 识别标识
             */
            keys: string[];
        }): Promise<{
            /**
             * key
             */
            cvRecKey: string;
            /**
             * value
             */
            cvRecValue: Object;
        }[]>;
        /**
         * 查询当前直播间视觉识别结果参数
         * @edata
         * @typedef {Object} QueryCVRecognitionParams
         * @property {Array.<string>} keys 识别标识
         */
        /**
         * 查询当前直播间视觉识别结果
         * @eapi
         * @param {QueryCVRecognitionParams} param 参数
         * @returns {Promise<Array.<CVRecognition>>} 识别消息列表
         */
        export function queryCVRecognition(param: {
            /**
             * 识别标识
             */
            keys: string[];
        }): Promise<{
            /**
             * key
             */
            cvRecKey: string;
            /**
             * value
             */
            cvRecValue: Object;
        }[]>;
        /**
         * 热词识别消息
         * @edata
         * @typedef {Object} KeywordResp
         * @property {string} data 识别出来的文字
         */
        /**
         * 热词识别回调
         * @edata
         * @callback SpeechKeywordCallback
         * @param {KeywordResp} recognition 热词识别消息
         */
        /**
         * @edata
         * @typedef {Object} SpeechKeywordParams 热词监听请求参数
         * @property {Array.<string>} hotwords 热词
         * @property {SpeechKeywordCallback} callback 热词识别回调
         */
        /**
         * 监听当前直播间语音关键字识别消息
         * @eapi
         * @param {SpeechKeywordParams} param 调用参数
         * @returns {Promise<void>} 调用结果
         */
        export function onSpeechKeywordRecognition(param: {
            /**
             * 热词
             */
            hotwords: string[];
            /**
             * 热词识别回调
             */
            callback: (recognition: {
                /**
                 * 识别出来的文字
                 */
                data: string;
            }) => any;
        }): Promise<void>;
        /**
         * 热词识别消息
         * @edata
         * @typedef {Object} KeywordResp
         * @property {string} data 识别出来的文字
         */
        /**
         * 热词识别回调
         * @edata
         * @callback SpeechKeywordCallback
         * @param {KeywordResp} recognition 热词识别消息
         */
        /**
         * @edata
         * @typedef {Object} SpeechKeywordParams 热词监听请求参数
         * @property {Array.<string>} hotwords 热词
         * @property {SpeechKeywordCallback} callback 热词识别回调
         */
        /**
         * 监听当前直播间语音关键字识别消息
         * @eapi
         * @param {SpeechKeywordParams} param 调用参数
         * @returns {Promise<void>} 调用结果
         */
        export function onSpeechKeywordRecognition(param: {
            /**
             * 热词
             */
            hotwords: string[];
            /**
             * 热词识别回调
             */
            callback: (recognition: {
                /**
                 * 识别出来的文字
                 */
                data: string;
            }) => any;
        }): Promise<void>;
        /**
         * 取消监听当前直播间肢体骨骼点检测消息
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function offSpeechKeywordRecognition(): Promise<void>;
        /**
         * 取消监听当前直播间肢体骨骼点检测消息
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function offSpeechKeywordRecognition(): Promise<void>;
        /**
         * 转换返回结果
         * @edata
         * @typedef {Object} TextToSpeechResp
         * @property {number} returnCode 返回码
         * @property {string} message 返回信息
         * @property {string} audioUrl 音频地址
         * @property {number} duration 音频长度
         */
        /**
         * 文本转语音参数
         * @edata
         * @typedef {Object} TextToSpeechParams
         * @property {string} text 文本
         * @property {number} tone 语调, 1-TONE_XIAOYU, 2-TONE_XIAOXIA, 3-TONE_XIAOXIN, 4-TONE_XIAOZE
         * @property {number} type 类型, 0-TYPE_WAV, 1-TYPE_PCM
         */
        /**
         * 文本转语音
         * @eapi
         * @param {TextToSpeechParams} param 传入参数
         * @returns {Promise<TextToSpeechResp>} 调用结果
         */
        export function textToSpeech(param: {
            /**
             * 文本
             */
            text: string;
            /**
             * 语调, 1-TONE_XIAOYU, 2-TONE_XIAOXIA, 3-TONE_XIAOXIN, 4-TONE_XIAOZE
             */
            tone: number;
            /**
             * 类型, 0-TYPE_WAV, 1-TYPE_PCM
             */
            type: number;
        }): Promise<{
            /**
             * 返回码
             */
            returnCode: number;
            /**
             * 返回信息
             */
            message: string;
            /**
             * 音频地址
             */
            audioUrl: string;
            /**
             * 音频长度
             */
            duration: number;
        }>;
        /**
         * 转换返回结果
         * @edata
         * @typedef {Object} TextToSpeechResp
         * @property {number} returnCode 返回码
         * @property {string} message 返回信息
         * @property {string} audioUrl 音频地址
         * @property {number} duration 音频长度
         */
        /**
         * 文本转语音参数
         * @edata
         * @typedef {Object} TextToSpeechParams
         * @property {string} text 文本
         * @property {number} tone 语调, 1-TONE_XIAOYU, 2-TONE_XIAOXIA, 3-TONE_XIAOXIN, 4-TONE_XIAOZE
         * @property {number} type 类型, 0-TYPE_WAV, 1-TYPE_PCM
         */
        /**
         * 文本转语音
         * @eapi
         * @param {TextToSpeechParams} param 传入参数
         * @returns {Promise<TextToSpeechResp>} 调用结果
         */
        export function textToSpeech(param: {
            /**
             * 文本
             */
            text: string;
            /**
             * 语调, 1-TONE_XIAOYU, 2-TONE_XIAOXIA, 3-TONE_XIAOXIN, 4-TONE_XIAOZE
             */
            tone: number;
            /**
             * 类型, 0-TYPE_WAV, 1-TYPE_PCM
             */
            type: number;
        }): Promise<{
            /**
             * 返回码
             */
            returnCode: number;
            /**
             * 返回信息
             */
            message: string;
            /**
             * 音频地址
             */
            audioUrl: string;
            /**
             * 音频长度
             */
            duration: number;
        }>;
    }
}
export default _default;
