declare namespace _default {
    export namespace revenue {
        /**
         * 营收统计参数
         * @edata
         * @typedef {Object} RevenueStatParams
         * @property {Object} eventData 上报数据
         */
        /**
         * 开始营收统计
         * @eapi
         * @param {RevenueStatParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function startRevenueStat(params: {
            /**
             * 上报数据
             */
            eventData: Object;
        }): Promise<void>;
        /**
         * 营收统计参数
         * @edata
         * @typedef {Object} RevenueStatParams
         * @property {Object} eventData 上报数据
         */
        /**
         * 开始营收统计
         * @eapi
         * @param {RevenueStatParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function startRevenueStat(params: {
            /**
             * 上报数据
             */
            eventData: Object;
        }): Promise<void>;
        /**
         * 停止营收统计
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function stopRevenueStat(): Promise<void>;
        /**
         * 停止营收统计
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function stopRevenueStat(): Promise<void>;
        /**
         * 否可以使用指定的商品
         * @edata
         * @typedef {Object} CanUseGoodsInfo
         * @property {boolean} isCanUse 是否可用
         */
        /**
         * 是否可以使用指定的商品参数
         * @edata
         * @typedef {Object} CanUseGoodsParams
         * @property {string} goodsUuid 商品id
         */
        /**
         * 判断当前主播是否可以使用指定的商品
         * @eapi
         * @param {CanUseGoodsParams} params 参数
         * @returns {Promise<CanUseGoodsInfo>} 调用结果
         */
        export function checkStreamerCanUseGoods(params: {
            /**
             * 商品id
             */
            goodsUuid: string;
        }): Promise<{
            /**
             * 是否可用
             */
            isCanUse: boolean;
        }>;
        /**
         * 否可以使用指定的商品
         * @edata
         * @typedef {Object} CanUseGoodsInfo
         * @property {boolean} isCanUse 是否可用
         */
        /**
         * 是否可以使用指定的商品参数
         * @edata
         * @typedef {Object} CanUseGoodsParams
         * @property {string} goodsUuid 商品id
         */
        /**
         * 判断当前主播是否可以使用指定的商品
         * @eapi
         * @param {CanUseGoodsParams} params 参数
         * @returns {Promise<CanUseGoodsInfo>} 调用结果
         */
        export function checkStreamerCanUseGoods(params: {
            /**
             * 商品id
             */
            goodsUuid: string;
        }): Promise<{
            /**
             * 是否可用
             */
            isCanUse: boolean;
        }>;
        /**
         * 停止统计参数
         * @edata
         * @typedef {Object} EndGiftRevenueStatParams
         * @property {string} goodsUuid 商品id
         */
        /**
         * 停止统计
         * @eapi
         * @param {EndGiftRevenueStatParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function endModuleGiftRevenueStat(params: {
            /**
             * 商品id
             */
            goodsUuid: string;
        }): Promise<void>;
        /**
         * 停止统计参数
         * @edata
         * @typedef {Object} EndGiftRevenueStatParams
         * @property {string} goodsUuid 商品id
         */
        /**
         * 停止统计
         * @eapi
         * @param {EndGiftRevenueStatParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function endModuleGiftRevenueStat(params: {
            /**
             * 商品id
             */
            goodsUuid: string;
        }): Promise<void>;
        /**
         * 开始统计参数
         * @edata
         * @typedef {Object} StartGiftRevenueStatParams
         * @property {string} goodsUuid 商品id
         * @property {string} [giftIds] 礼物id，多个用竖线分隔
         */
        /**
         * 开始统计
         * @eapi
         * @param {StartGiftRevenueStatParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function startModuleGiftRevenueStat(params: {
            /**
             * 商品id
             */
            goodsUuid: string;
            /**
             * 礼物id，多个用竖线分隔
             */
            giftIds?: string;
        }): Promise<void>;
        /**
         * 开始统计参数
         * @edata
         * @typedef {Object} StartGiftRevenueStatParams
         * @property {string} goodsUuid 商品id
         * @property {string} [giftIds] 礼物id，多个用竖线分隔
         */
        /**
         * 开始统计
         * @eapi
         * @param {StartGiftRevenueStatParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function startModuleGiftRevenueStat(params: {
            /**
             * 商品id
             */
            goodsUuid: string;
            /**
             * 礼物id，多个用竖线分隔
             */
            giftIds?: string;
        }): Promise<void>;
        /**
         * 指定商品的使用有效期信息
         * @edata
         * @typedef {Object} GoodsExpireInfo
         * @property {number} expire 主播指定商品的失效日期时间戳，没有购买过则返回-1
         * @property {boolean} hadBuy 是否有购买过
         */
        /**
         * 指定商品的使用有效期参数
         * @edata
         * @typedef {Object} GoodsExpireParams
         * @property {string} goodsUuid 商品id
         */
        /**
         * 判断当前主播指定的商品的使用有效期
         * @eapi
         * @param {GoodsExpireParams} params 参数
         * @returns {Promise<GoodsExpireInfo>} 调用结果
         */
        export function checkStreamerGoodsExpire(params: {
            /**
             * 商品id
             */
            goodsUuid: string;
        }): Promise<{
            /**
             * 主播指定商品的失效日期时间戳，没有购买过则返回-1
             */
            expire: number;
            /**
             * 是否有购买过
             */
            hadBuy: boolean;
        }>;
        /**
         * 指定商品的使用有效期信息
         * @edata
         * @typedef {Object} GoodsExpireInfo
         * @property {number} expire 主播指定商品的失效日期时间戳，没有购买过则返回-1
         * @property {boolean} hadBuy 是否有购买过
         */
        /**
         * 指定商品的使用有效期参数
         * @edata
         * @typedef {Object} GoodsExpireParams
         * @property {string} goodsUuid 商品id
         */
        /**
         * 判断当前主播指定的商品的使用有效期
         * @eapi
         * @param {GoodsExpireParams} params 参数
         * @returns {Promise<GoodsExpireInfo>} 调用结果
         */
        export function checkStreamerGoodsExpire(params: {
            /**
             * 商品id
             */
            goodsUuid: string;
        }): Promise<{
            /**
             * 主播指定商品的失效日期时间戳，没有购买过则返回-1
             */
            expire: number;
            /**
             * 是否有购买过
             */
            hadBuy: boolean;
        }>;
        /**
         * 购买商品参数
         * @edata
         * @typedef {Object} GoodsBuyParams
         * @property {string} goodsUuid 商品id
         */
        /**
         * 弹出商品购买的H5面板
         * @eapi
         * @param {GoodsBuyParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function popupGoodsBuyPanel(params: {
            /**
             * 商品id
             */
            goodsUuid: string;
        }): Promise<void>;
        /**
         * 购买商品参数
         * @edata
         * @typedef {Object} GoodsBuyParams
         * @property {string} goodsUuid 商品id
         */
        /**
         * 弹出商品购买的H5面板
         * @eapi
         * @param {GoodsBuyParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function popupGoodsBuyPanel(params: {
            /**
             * 商品id
             */
            goodsUuid: string;
        }): Promise<void>;
    }
}
export default _default;
