declare namespace _default {
    export namespace stream {
        /**
         * 直播间延迟模式
         * @edata
         * @typedef {Object} ViewerLatencyModeInfo
         * @property {number} mode 延迟模式标识, 0-普通模式, 1-低延迟模式
         */
        /**
         * 获取当前直播间的延迟模式
         * @summary 观众端专用
         * @eapi
         * @returns {Promise<ViewerLatencyModeInfo>} 调用结果
         */
        export function getViewerLatencyMode(): Promise<{
            /**
             * 延迟模式标识, 0-普通模式, 1-低延迟模式
             */
            mode: number;
        }>;
        /**
         * 直播间延迟模式
         * @edata
         * @typedef {Object} ViewerLatencyModeInfo
         * @property {number} mode 延迟模式标识, 0-普通模式, 1-低延迟模式
         */
        /**
         * 获取当前直播间的延迟模式
         * @summary 观众端专用
         * @eapi
         * @returns {Promise<ViewerLatencyModeInfo>} 调用结果
         */
        export function getViewerLatencyMode(): Promise<{
            /**
             * 延迟模式标识, 0-普通模式, 1-低延迟模式
             */
            mode: number;
        }>;
        /**
         * 设置直播间延迟模式参数
         * @edata
         * @typedef {Object} ViewerLatencyModeParams
         * @property {number} mode 延迟模式标识, 0-普通模式(默认), 1-低延迟模式
         */
        /**
         * 设置当前直播间的延迟模式
         * @summary 观众端专用
         * @eapi
         * @param {ViewerLatencyModeParams} params 设置直播间延迟模式参数
         * @returns {Promise<void>} 调用结果
         */
        export function setViewerLatencyMode(params: {
            /**
             * 延迟模式标识, 0-普通模式(默认), 1-低延迟模式
             */
            mode: number;
        }): Promise<void>;
        /**
         * 设置直播间延迟模式参数
         * @edata
         * @typedef {Object} ViewerLatencyModeParams
         * @property {number} mode 延迟模式标识, 0-普通模式(默认), 1-低延迟模式
         */
        /**
         * 设置当前直播间的延迟模式
         * @summary 观众端专用
         * @eapi
         * @param {ViewerLatencyModeParams} params 设置直播间延迟模式参数
         * @returns {Promise<void>} 调用结果
         */
        export function setViewerLatencyMode(params: {
            /**
             * 延迟模式标识, 0-普通模式(默认), 1-低延迟模式
             */
            mode: number;
        }): Promise<void>;
        /**
         * 白板信息
         * @edata
         * @typedef {Object} WhiteBoardInfo
         * @property {string} wbId 白板ID
         */
        /**
         * 创建独立白板参数
         * @edata
         * @typedef {Object} WhiteBoardParams
         * @property {Object} [param] 独立白板的初始参数
         * @property {number} width 独立白板的宽度
         * @property {number} height 独立白板的高度
         */
        /**
         * 创建小程序独立白板
         * @eapi
         * @param {WhiteBoardParams} params 创建独立白板参数
         * @returns {Promise<WhiteBoardInfo>} 返回白板信息
         */
        export function addExtraWhiteBoard(params: {
            /**
             * 独立白板的初始参数
             */
            param?: Object;
            /**
             * 独立白板的宽度
             */
            width: number;
            /**
             * 独立白板的高度
             */
            height: number;
        }): Promise<{
            /**
             * 白板ID
             */
            wbId: string;
        }>;
        /**
         * 白板信息
         * @edata
         * @typedef {Object} WhiteBoardInfo
         * @property {string} wbId 白板ID
         */
        /**
         * 创建独立白板参数
         * @edata
         * @typedef {Object} WhiteBoardParams
         * @property {Object} [param] 独立白板的初始参数
         * @property {number} width 独立白板的宽度
         * @property {number} height 独立白板的高度
         */
        /**
         * 创建小程序独立白板
         * @eapi
         * @param {WhiteBoardParams} params 创建独立白板参数
         * @returns {Promise<WhiteBoardInfo>} 返回白板信息
         */
        export function addExtraWhiteBoard(params: {
            /**
             * 独立白板的初始参数
             */
            param?: Object;
            /**
             * 独立白板的宽度
             */
            width: number;
            /**
             * 独立白板的高度
             */
            height: number;
        }): Promise<{
            /**
             * 白板ID
             */
            wbId: string;
        }>;
        /**
         * 移除小程序独立白板
         * @eapi
         * @param {WhiteBoardInfo} params 移除独立白板参数
         * @returns {Promise<void>} 调用结果
         */
        export function removeExtraWhiteBoard(params: {
            /**
             * 白板ID
             */
            wbId: string;
        }): Promise<void>;
        /**
         * 移除小程序独立白板
         * @eapi
         * @param {WhiteBoardInfo} params 移除独立白板参数
         * @returns {Promise<void>} 调用结果
         */
        export function removeExtraWhiteBoard(params: {
            /**
             * 白板ID
             */
            wbId: string;
        }): Promise<void>;
        /**
         * 发送到白板的消息
         * @edata
         * @typedef {Object} WhiteBoardMsg
         * @property {string} wbId 独立白板的Id
         * @property {string} [data] 要发送的消息
         */
        /**
         * 发送消息到小程序独立白板
         * @eapi
         * @param {WhiteBoardMsg} params 发送到白板的消息
         * @returns {Promise<void>} 调用结果
         */
        export function sendToExtraWhiteBoard(params: {
            /**
             * 独立白板的Id
             */
            wbId: string;
            /**
             * 要发送的消息
             */
            data?: string;
        }): Promise<void>;
        /**
         * 发送到白板的消息
         * @edata
         * @typedef {Object} WhiteBoardMsg
         * @property {string} wbId 独立白板的Id
         * @property {string} [data] 要发送的消息
         */
        /**
         * 发送消息到小程序独立白板
         * @eapi
         * @param {WhiteBoardMsg} params 发送到白板的消息
         * @returns {Promise<void>} 调用结果
         */
        export function sendToExtraWhiteBoard(params: {
            /**
             * 独立白板的Id
             */
            wbId: string;
            /**
             * 要发送的消息
             */
            data?: string;
        }): Promise<void>;
        /**
         * 推流的分辨率
         * @edata
         * @typedef {Object} StreamResolutionInfo
         * @property {number} width 宽度（单位是像素）
         * @property {number} height 高度（单位是像素）
         */
        /**
         * 获取推流的分辨率
         * @eapi
         * @returns {Promise<StreamResolutionInfo>} 返回推流的分辨率
         */
        export function getStreamResolution(): Promise<{
            /**
             * 宽度（单位是像素）
             */
            width: number;
            /**
             * 高度（单位是像素）
             */
            height: number;
        }>;
        /**
         * 推流的分辨率
         * @edata
         * @typedef {Object} StreamResolutionInfo
         * @property {number} width 宽度（单位是像素）
         * @property {number} height 高度（单位是像素）
         */
        /**
         * 获取推流的分辨率
         * @eapi
         * @returns {Promise<StreamResolutionInfo>} 返回推流的分辨率
         */
        export function getStreamResolution(): Promise<{
            /**
             * 宽度（单位是像素）
             */
            width: number;
            /**
             * 高度（单位是像素）
             */
            height: number;
        }>;
        /**
         * 推流分辨率参数
         * @edata
         * @typedef {Object} StreamResolutionParams
         * @property {number} width 宽度（单位是像素）
         * @property {number} height 高度（单位是像素）
         */
        /**
         * 设置推流分辨率
         * @eapi
         * @param {StreamResolutionParams} params 推流分辨率参数
         * @returns {Promise<void>} 调用结果
         */
        export function setStreamResolution(params: {
            /**
             * 宽度（单位是像素）
             */
            width: number;
            /**
             * 高度（单位是像素）
             */
            height: number;
        }): Promise<void>;
        /**
         * 推流分辨率参数
         * @edata
         * @typedef {Object} StreamResolutionParams
         * @property {number} width 宽度（单位是像素）
         * @property {number} height 高度（单位是像素）
         */
        /**
         * 设置推流分辨率
         * @eapi
         * @param {StreamResolutionParams} params 推流分辨率参数
         * @returns {Promise<void>} 调用结果
         */
        export function setStreamResolution(params: {
            /**
             * 宽度（单位是像素）
             */
            width: number;
            /**
             * 高度（单位是像素）
             */
            height: number;
        }): Promise<void>;
        /**
         * 直播间延迟模式信息
         * @edata
         * @typedef {Object} StreamerLatencyModeInfo
         * @property {number} mode 延迟模式标识, 0-普通模式, 1-低延迟模式
         */
        /**
         * 获取当前直播间的延迟模式
         * @summary 主播端专用
         * @eapi
         * @returns {Promise<StreamerLatencyModeInfo>} 调用结果
         */
        export function getStreamerLatencyMode(): Promise<{
            /**
             * 延迟模式标识, 0-普通模式, 1-低延迟模式
             */
            mode: number;
        }>;
        /**
         * 直播间延迟模式信息
         * @edata
         * @typedef {Object} StreamerLatencyModeInfo
         * @property {number} mode 延迟模式标识, 0-普通模式, 1-低延迟模式
         */
        /**
         * 获取当前直播间的延迟模式
         * @summary 主播端专用
         * @eapi
         * @returns {Promise<StreamerLatencyModeInfo>} 调用结果
         */
        export function getStreamerLatencyMode(): Promise<{
            /**
             * 延迟模式标识, 0-普通模式, 1-低延迟模式
             */
            mode: number;
        }>;
        /**
         * 设置当前直播间的延迟模式
         * @summary 主播端专用
         * @eapi
         * @param {StreamerLatencyModeInfo} params 延迟模式参数
         * @returns {Promise<void>} 调用结果
         */
        export function setStreamerLatencyMode(params: {
            /**
             * 延迟模式标识, 0-普通模式, 1-低延迟模式
             */
            mode: number;
        }): Promise<void>;
        /**
         * 设置当前直播间的延迟模式
         * @summary 主播端专用
         * @eapi
         * @param {StreamerLatencyModeInfo} params 延迟模式参数
         * @returns {Promise<void>} 调用结果
         */
        export function setStreamerLatencyMode(params: {
            /**
             * 延迟模式标识, 0-普通模式, 1-低延迟模式
             */
            mode: number;
        }): Promise<void>;
        /**
         * 创建图层信息参数
         * @edata
         * @typedef {Object} LayerInfoParam
         * @property {string} type 图层类型, PK-PK图层(默认), IMAGE-图片图层, VIDEO-视频图层
         * @property {string} [layerName] 业务传入的图层标识
         * @property {number} offsetX 图层相对推流出去的界面左侧的偏移量（单位是像素）
         * @property {number} offsetY 图层相对推流出去的界面顶部的偏移量（单位是像素）
         * @property {number} canvasWidth 推流出去的界面里图层占的宽度（单位是像素）
         * @property {number} canvasHeight 推流出去的界面里图层占的高度（单位是像素）
         * @property {number} [weight] 权重
         * @property {boolean} [force] 强制使用当前配置
         * @property {Object} [param] 参数
         */
        /**
         * 创建图层结果
         * @edata
         * @typedef {Object} LayerId
         * @property {string} layerId 图层id
         */
        /**
         * 批量创建图层
         * @eapi
         * @param {Array.<LayerInfoParam>} params 图层信息队列
         * @returns {Promise<Array.<LayerId>>} 调用结果
         */
        export function addLayers(params: {
            /**
             * 图层类型, PK-PK图层(默认), IMAGE-图片图层, VIDEO-视频图层
             */
            type: string;
            /**
             * 业务传入的图层标识
             */
            layerName?: string;
            /**
             * 图层相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 图层相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里图层占的高度（单位是像素）
             */
            canvasHeight: number;
            /**
             * 权重
             */
            weight?: number;
            /**
             * 强制使用当前配置
             */
            force?: boolean;
            /**
             * 参数
             */
            param?: Object;
        }[]): Promise<{
            /**
             * 图层id
             */
            layerId: string;
        }[]>;
        /**
         * 创建图层信息参数
         * @edata
         * @typedef {Object} LayerInfoParam
         * @property {string} type 图层类型, PK-PK图层(默认), IMAGE-图片图层, VIDEO-视频图层
         * @property {string} [layerName] 业务传入的图层标识
         * @property {number} offsetX 图层相对推流出去的界面左侧的偏移量（单位是像素）
         * @property {number} offsetY 图层相对推流出去的界面顶部的偏移量（单位是像素）
         * @property {number} canvasWidth 推流出去的界面里图层占的宽度（单位是像素）
         * @property {number} canvasHeight 推流出去的界面里图层占的高度（单位是像素）
         * @property {number} [weight] 权重
         * @property {boolean} [force] 强制使用当前配置
         * @property {Object} [param] 参数
         */
        /**
         * 创建图层结果
         * @edata
         * @typedef {Object} LayerId
         * @property {string} layerId 图层id
         */
        /**
         * 批量创建图层
         * @eapi
         * @param {Array.<LayerInfoParam>} params 图层信息队列
         * @returns {Promise<Array.<LayerId>>} 调用结果
         */
        export function addLayers(params: {
            /**
             * 图层类型, PK-PK图层(默认), IMAGE-图片图层, VIDEO-视频图层
             */
            type: string;
            /**
             * 业务传入的图层标识
             */
            layerName?: string;
            /**
             * 图层相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 图层相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里图层占的高度（单位是像素）
             */
            canvasHeight: number;
            /**
             * 权重
             */
            weight?: number;
            /**
             * 强制使用当前配置
             */
            force?: boolean;
            /**
             * 参数
             */
            param?: Object;
        }[]): Promise<{
            /**
             * 图层id
             */
            layerId: string;
        }[]>;
        /**
         * 图层信息
         * @edata
         * @typedef {Object} LayerInfo
         * @property {string} layerId 图层id
         * @property {string} type 图层类型
         * @property {string} layerName 业务传入的图层标识
         * @property {number} offsetX 图层相对推流出去的界面左侧的偏移量（单位是像素）
         * @property {number} offsetY 图层相对推流出去的界面顶部的偏移量（单位是像素）
         * @property {number} canvasWidth 推流出去的界面里图层占的宽度（单位是像素）
         * @property {number} canvasHeight 推流出去的界面里图层占的高度（单位是像素）
         * @property {number} weight 权重
         * @property {Object} param 参数
         */
        /**
         * 获取图层信息
         * @eapi
         * @returns {Promise<Array.<LayerInfo>>} 调用结果
         */
        export function getLayers(): Promise<{
            /**
             * 图层id
             */
            layerId: string;
            /**
             * 图层类型
             */
            type: string;
            /**
             * 业务传入的图层标识
             */
            layerName: string;
            /**
             * 图层相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 图层相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里图层占的高度（单位是像素）
             */
            canvasHeight: number;
            /**
             * 权重
             */
            weight: number;
            /**
             * 参数
             */
            param: Object;
        }[]>;
        /**
         * 图层信息
         * @edata
         * @typedef {Object} LayerInfo
         * @property {string} layerId 图层id
         * @property {string} type 图层类型
         * @property {string} layerName 业务传入的图层标识
         * @property {number} offsetX 图层相对推流出去的界面左侧的偏移量（单位是像素）
         * @property {number} offsetY 图层相对推流出去的界面顶部的偏移量（单位是像素）
         * @property {number} canvasWidth 推流出去的界面里图层占的宽度（单位是像素）
         * @property {number} canvasHeight 推流出去的界面里图层占的高度（单位是像素）
         * @property {number} weight 权重
         * @property {Object} param 参数
         */
        /**
         * 获取图层信息
         * @eapi
         * @returns {Promise<Array.<LayerInfo>>} 调用结果
         */
        export function getLayers(): Promise<{
            /**
             * 图层id
             */
            layerId: string;
            /**
             * 图层类型
             */
            type: string;
            /**
             * 业务传入的图层标识
             */
            layerName: string;
            /**
             * 图层相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 图层相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里图层占的高度（单位是像素）
             */
            canvasHeight: number;
            /**
             * 权重
             */
            weight: number;
            /**
             * 参数
             */
            param: Object;
        }[]>;
        /**
         * 更新操作结果
         * @edata
         * @typedef {Object} ChangePesp
         * @property {number} res 操作结果，0成功，非0失败
         */
        /**
         * 批量更新图层
         * @eapi
         * @param {Array.<LayerInfoParam|LayerId>} params 携带图层id的图层信息队列
         * @returns {Promise<Array.<ChangePesp>>} 调用结果
         */
        export function updateLayers(params: ({
            /**
             * 图层类型, PK-PK图层(默认), IMAGE-图片图层, VIDEO-视频图层
             */
            type: string;
            /**
             * 业务传入的图层标识
             */
            layerName?: string;
            /**
             * 图层相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 图层相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里图层占的高度（单位是像素）
             */
            canvasHeight: number;
            /**
             * 权重
             */
            weight?: number;
            /**
             * 强制使用当前配置
             */
            force?: boolean;
            /**
             * 参数
             */
            param?: Object;
        } | {
            /**
             * 图层id
             */
            layerId: string;
        })[]): Promise<{
            /**
             * 操作结果，0成功，非0失败
             */
            res: number;
        }[]>;
        /**
         * 更新操作结果
         * @edata
         * @typedef {Object} ChangePesp
         * @property {number} res 操作结果，0成功，非0失败
         */
        /**
         * 批量更新图层
         * @eapi
         * @param {Array.<LayerInfoParam|LayerId>} params 携带图层id的图层信息队列
         * @returns {Promise<Array.<ChangePesp>>} 调用结果
         */
        export function updateLayers(params: ({
            /**
             * 图层类型, PK-PK图层(默认), IMAGE-图片图层, VIDEO-视频图层
             */
            type: string;
            /**
             * 业务传入的图层标识
             */
            layerName?: string;
            /**
             * 图层相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 图层相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里图层占的高度（单位是像素）
             */
            canvasHeight: number;
            /**
             * 权重
             */
            weight?: number;
            /**
             * 强制使用当前配置
             */
            force?: boolean;
            /**
             * 参数
             */
            param?: Object;
        } | {
            /**
             * 图层id
             */
            layerId: string;
        })[]): Promise<{
            /**
             * 操作结果，0成功，非0失败
             */
            res: number;
        }[]>;
        /**
         * 批量删除图层
         * @eapi
         * @param {Array.<LayerId>} params 参数
         * @returns {Promise<Array.<ChangePesp>>} 调用结果
         */
        export function removeLayers(params: {
            /**
             * 图层id
             */
            layerId: string;
        }[]): Promise<{
            /**
             * 操作结果，0成功，非0失败
             */
            res: number;
        }[]>;
        /**
         * 批量删除图层
         * @eapi
         * @param {Array.<LayerId>} params 参数
         * @returns {Promise<Array.<ChangePesp>>} 调用结果
         */
        export function removeLayers(params: {
            /**
             * 图层id
             */
            layerId: string;
        }[]): Promise<{
            /**
             * 操作结果，0成功，非0失败
             */
            res: number;
        }[]>;
        /**
         * 元素配置
         * @edata
         * @typedef {Object} ZoneOptions
         * @property {string} screenColor 透明底色配置，默认为空，即不启用透明底色
         */
        /**
         * 添加元素参数
         * @edata
         * @typedef {Object} ZoneParams
         * @property {any} elem 截取的HTML元素/React组件
         * @property {ZoneOptions} [options] 截取选项
         */
        /**
         * 截取小程序的某个元素并让其内容显示到视频流中，截取的内容可以在开播端的“预览”界面进行编辑
         * @eapi
         * @param {ZoneParams} params 添加元素参数
         * @returns {Promise<void>} 调用结果
         */
        export function addZone(params: {
            /**
             * 截取的HTML元素/React组件
             */
            elem: any;
            /**
             * 截取选项
             */
            options?: {
                /**
                 * 透明底色配置，默认为空，即不启用透明底色
                 */
                screenColor: string;
            };
        }): Promise<void>;
        /**
         * 元素配置
         * @edata
         * @typedef {Object} ZoneOptions
         * @property {string} screenColor 透明底色配置，默认为空，即不启用透明底色
         */
        /**
         * 添加元素参数
         * @edata
         * @typedef {Object} ZoneParams
         * @property {any} elem 截取的HTML元素/React组件
         * @property {ZoneOptions} [options] 截取选项
         */
        /**
         * 截取小程序的某个元素并让其内容显示到视频流中，截取的内容可以在开播端的“预览”界面进行编辑
         * @eapi
         * @param {ZoneParams} params 添加元素参数
         * @returns {Promise<void>} 调用结果
         */
        export function addZone(params: {
            /**
             * 截取的HTML元素/React组件
             */
            elem: any;
            /**
             * 截取选项
             */
            options?: {
                /**
                 * 透明底色配置，默认为空，即不启用透明底色
                 */
                screenColor: string;
            };
        }): Promise<void>;
        /**
         * 删除投射区域
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function removeZone(): Promise<void>;
        /**
         * 删除投射区域
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function removeZone(): Promise<void>;
        /**
         * 创建普通白板参数
         * @edata
         * @typedef {Object} AddWhiteBoardParams
         * @property {Object} [param] 独立白板的初始参数
         * @property {number} width 普通白板的宽度
         * @property {number} height 普通白板的高度
         * @property {number} x 普通白板的左上角横坐标
         * @property {number} y 普通白板的左上角纵坐标
         */
        /**
         * 创建小程序普通白板
         * @eapi
         * @param {AddWhiteBoardParams} params 创建普通白板参数
         * @returns {Promise<WhiteBoardInfo>} 调用结果
         */
        export function addWhiteBoard(params: {
            /**
             * 独立白板的初始参数
             */
            param?: Object;
            /**
             * 普通白板的宽度
             */
            width: number;
            /**
             * 普通白板的高度
             */
            height: number;
            /**
             * 普通白板的左上角横坐标
             */
            x: number;
            /**
             * 普通白板的左上角纵坐标
             */
            y: number;
        }): Promise<{
            /**
             * 白板ID
             */
            wbId: string;
        }>;
        /**
         * 创建普通白板参数
         * @edata
         * @typedef {Object} AddWhiteBoardParams
         * @property {Object} [param] 独立白板的初始参数
         * @property {number} width 普通白板的宽度
         * @property {number} height 普通白板的高度
         * @property {number} x 普通白板的左上角横坐标
         * @property {number} y 普通白板的左上角纵坐标
         */
        /**
         * 创建小程序普通白板
         * @eapi
         * @param {AddWhiteBoardParams} params 创建普通白板参数
         * @returns {Promise<WhiteBoardInfo>} 调用结果
         */
        export function addWhiteBoard(params: {
            /**
             * 独立白板的初始参数
             */
            param?: Object;
            /**
             * 普通白板的宽度
             */
            width: number;
            /**
             * 普通白板的高度
             */
            height: number;
            /**
             * 普通白板的左上角横坐标
             */
            x: number;
            /**
             * 普通白板的左上角纵坐标
             */
            y: number;
        }): Promise<{
            /**
             * 白板ID
             */
            wbId: string;
        }>;
        /**
         * 移除小程序普通白板
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function removeWhiteBoard(): Promise<void>;
        /**
         * 移除小程序普通白板
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function removeWhiteBoard(): Promise<void>;
        /**
         * 创建图片图层参数
         * @edata
         * @typedef {Object} ImageLayerParams
         * @property {string} md5 图片资源md5
         * @property {number} [frameRate] 帧率
         */
        /**
         * 创建小程序图片图层
         * @summary 增加图层（需要先使用hyExt.pc.downloadRes下载对应的图层资源）
         * - 目前仅支持一张apng文件，或者包含n张png文件的zip包，小程序会遍历zip包里面的所有图片进行轮播
         * - zip包里面的子目录会忽略
         * @eapi
         * @param {ImageLayerParams} params 创建图片图层参数
         * @returns {Promise<LayerId>} 调用结果
         */
        export function addImageLayer(params: {
            /**
             * 图片资源md5
             */
            md5: string;
            /**
             * 帧率
             */
            frameRate?: number;
        }): Promise<{
            /**
             * 图层id
             */
            layerId: string;
        }>;
        /**
         * 创建图片图层参数
         * @edata
         * @typedef {Object} ImageLayerParams
         * @property {string} md5 图片资源md5
         * @property {number} [frameRate] 帧率
         */
        /**
         * 创建小程序图片图层
         * @summary 增加图层（需要先使用hyExt.pc.downloadRes下载对应的图层资源）
         * - 目前仅支持一张apng文件，或者包含n张png文件的zip包，小程序会遍历zip包里面的所有图片进行轮播
         * - zip包里面的子目录会忽略
         * @eapi
         * @param {ImageLayerParams} params 创建图片图层参数
         * @returns {Promise<LayerId>} 调用结果
         */
        export function addImageLayer(params: {
            /**
             * 图片资源md5
             */
            md5: string;
            /**
             * 帧率
             */
            frameRate?: number;
        }): Promise<{
            /**
             * 图层id
             */
            layerId: string;
        }>;
        /**
         * 移除小程序图片图层
         * @eapi
         * @param {LayerId} params 移除涂图层信息
         * @returns {Promise<void>} 调用结果
         */
        export function removeImageLayer(params: {
            /**
             * 图层id
             */
            layerId: string;
        }): Promise<void>;
        /**
         * 移除小程序图片图层
         * @eapi
         * @param {LayerId} params 移除涂图层信息
         * @returns {Promise<void>} 调用结果
         */
        export function removeImageLayer(params: {
            /**
             * 图层id
             */
            layerId: string;
        }): Promise<void>;
        /**
         * 脸部效果参数
         * @edata
         * @typedef {Object} FaceEffectParams
         * @property {string} md5 变脸效果的md5
         * @property {boolean} enable 是否启用
         */
        /**
         * 使用脸部效果
         * @summary 要用摄像头开播，打开美颜模式才有效果
         * @eapi
         * @param {FaceEffectParams} params 调用参数
         * @returns {Promise<void>} 调用结果
         */
        export function enableFaceEffect(params: {
            /**
             * 变脸效果的md5
             */
            md5: string;
            /**
             * 是否启用
             */
            enable: boolean;
        }): Promise<void>;
        /**
         * 脸部效果参数
         * @edata
         * @typedef {Object} FaceEffectParams
         * @property {string} md5 变脸效果的md5
         * @property {boolean} enable 是否启用
         */
        /**
         * 使用脸部效果
         * @summary 要用摄像头开播，打开美颜模式才有效果
         * @eapi
         * @param {FaceEffectParams} params 调用参数
         * @returns {Promise<void>} 调用结果
         */
        export function enableFaceEffect(params: {
            /**
             * 变脸效果的md5
             */
            md5: string;
            /**
             * 是否启用
             */
            enable: boolean;
        }): Promise<void>;
        /**
         * 创建EXE白板参数
         * @edata
         * @typedef {Object} ExeWhiteBoardParams
         * @property {string} shareHandler EXE的共享句柄
         * @property {number} x EXE白板的左上角横坐标
         * @property {number} y EXE白板的左上角纵坐标
         * @property {number} width EXE白板的宽度
         * @property {number} height EXE白板的高度
         */
        /**
         * 创建小程序EXE白板
         * @eapi
         * @param {ExeWhiteBoardParams} params 创建EXE白板参数
         * @returns {Promise<void>} 调用结果
         */
        export function addExeWhiteBoard(params: {
            /**
             * EXE的共享句柄
             */
            shareHandler: string;
            /**
             * EXE白板的左上角横坐标
             */
            x: number;
            /**
             * EXE白板的左上角纵坐标
             */
            y: number;
            /**
             * EXE白板的宽度
             */
            width: number;
            /**
             * EXE白板的高度
             */
            height: number;
        }): Promise<void>;
        /**
         * 创建EXE白板参数
         * @edata
         * @typedef {Object} ExeWhiteBoardParams
         * @property {string} shareHandler EXE的共享句柄
         * @property {number} x EXE白板的左上角横坐标
         * @property {number} y EXE白板的左上角纵坐标
         * @property {number} width EXE白板的宽度
         * @property {number} height EXE白板的高度
         */
        /**
         * 创建小程序EXE白板
         * @eapi
         * @param {ExeWhiteBoardParams} params 创建EXE白板参数
         * @returns {Promise<void>} 调用结果
         */
        export function addExeWhiteBoard(params: {
            /**
             * EXE的共享句柄
             */
            shareHandler: string;
            /**
             * EXE白板的左上角横坐标
             */
            x: number;
            /**
             * EXE白板的左上角纵坐标
             */
            y: number;
            /**
             * EXE白板的宽度
             */
            width: number;
            /**
             * EXE白板的高度
             */
            height: number;
        }): Promise<void>;
        /**
         * 移除小程序EXE白板
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function removeExeWhiteBoard(): Promise<void>;
        /**
         * 移除小程序EXE白板
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function removeExeWhiteBoard(): Promise<void>;
        /**
         * 独立白板消息回调
         * @edata
         * @callback WhiteBoardMessageCallback
         * @param {string} data 消息内容
         */
        /**
         * 监听独立白板消息参数
         * @edata
         * @typedef {Object} WhiteBoardMessageParams
         * @property {WhiteBoardMessageCallback} callback 独立白板消息回调
         */
        /**
         * 监听小程序独立白板消息
         * @eapi
         * @param {WhiteBoardMessageParams} params 监听独立白板消息参数
         * @returns {Promise<void>} 调用结果
         */
        export function onExtraWhiteBoardMessage(params: {
            /**
             * 独立白板消息回调
             */
            callback: (data: string) => any;
        }): Promise<void>;
        /**
         * 独立白板消息回调
         * @edata
         * @callback WhiteBoardMessageCallback
         * @param {string} data 消息内容
         */
        /**
         * 监听独立白板消息参数
         * @edata
         * @typedef {Object} WhiteBoardMessageParams
         * @property {WhiteBoardMessageCallback} callback 独立白板消息回调
         */
        /**
         * 监听小程序独立白板消息
         * @eapi
         * @param {WhiteBoardMessageParams} params 监听独立白板消息参数
         * @returns {Promise<void>} 调用结果
         */
        export function onExtraWhiteBoardMessage(params: {
            /**
             * 独立白板消息回调
             */
            callback: (data: string) => any;
        }): Promise<void>;
        /**
         * 创建文字图层参数
         * @edata
         * @typedef {Object} TextLayerParams
         * @property {string} [layerId] 文字图层id
         * @property {string} text 文字图层内容
         * @property {string} [fontFamily] 文字图层字体
         * @property {number} [fontSize] 文字图层字体大小
         * @property {string} [fontColor] 字图层字体颜色
         * @property {boolean} [useBackground] 是否带背景
         * @property {string} [backgroundColor] 文字图层背景颜色
         * @property {number} [alpha] 文字图层不透明度
         * @property {boolean} [bold] 是否加粗
         * @property {boolean} [italic] 是否斜体
         * @property {boolean} [underline] 是否带下划线
         * @property {boolean} [scroll] 是否滚动
         */
        /**
         * 创建小程序文字图层
         * @eapi
         * @param {TextLayerParams} params 文字图层参数
         * @returns {Promise<LayerId>} 调用结果
         */
        export function addTextLayer(params: {
            /**
             * 文字图层id
             */
            layerId?: string;
            /**
             * 文字图层内容
             */
            text: string;
            /**
             * 文字图层字体
             */
            fontFamily?: string;
            /**
             * 文字图层字体大小
             */
            fontSize?: number;
            /**
             * 字图层字体颜色
             */
            fontColor?: string;
            /**
             * 是否带背景
             */
            useBackground?: boolean;
            /**
             * 文字图层背景颜色
             */
            backgroundColor?: string;
            /**
             * 文字图层不透明度
             */
            alpha?: number;
            /**
             * 是否加粗
             */
            bold?: boolean;
            /**
             * 是否斜体
             */
            italic?: boolean;
            /**
             * 是否带下划线
             */
            underline?: boolean;
            /**
             * 是否滚动
             */
            scroll?: boolean;
        }): Promise<{
            /**
             * 图层id
             */
            layerId: string;
        }>;
        /**
         * 创建文字图层参数
         * @edata
         * @typedef {Object} TextLayerParams
         * @property {string} [layerId] 文字图层id
         * @property {string} text 文字图层内容
         * @property {string} [fontFamily] 文字图层字体
         * @property {number} [fontSize] 文字图层字体大小
         * @property {string} [fontColor] 字图层字体颜色
         * @property {boolean} [useBackground] 是否带背景
         * @property {string} [backgroundColor] 文字图层背景颜色
         * @property {number} [alpha] 文字图层不透明度
         * @property {boolean} [bold] 是否加粗
         * @property {boolean} [italic] 是否斜体
         * @property {boolean} [underline] 是否带下划线
         * @property {boolean} [scroll] 是否滚动
         */
        /**
         * 创建小程序文字图层
         * @eapi
         * @param {TextLayerParams} params 文字图层参数
         * @returns {Promise<LayerId>} 调用结果
         */
        export function addTextLayer(params: {
            /**
             * 文字图层id
             */
            layerId?: string;
            /**
             * 文字图层内容
             */
            text: string;
            /**
             * 文字图层字体
             */
            fontFamily?: string;
            /**
             * 文字图层字体大小
             */
            fontSize?: number;
            /**
             * 字图层字体颜色
             */
            fontColor?: string;
            /**
             * 是否带背景
             */
            useBackground?: boolean;
            /**
             * 文字图层背景颜色
             */
            backgroundColor?: string;
            /**
             * 文字图层不透明度
             */
            alpha?: number;
            /**
             * 是否加粗
             */
            bold?: boolean;
            /**
             * 是否斜体
             */
            italic?: boolean;
            /**
             * 是否带下划线
             */
            underline?: boolean;
            /**
             * 是否滚动
             */
            scroll?: boolean;
        }): Promise<{
            /**
             * 图层id
             */
            layerId: string;
        }>;
        /**
         * 移除文本图层
         * @param {LayerId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function removeTextLayer(params: {
            /**
             * 图层id
             */
            layerId: string;
        }): Promise<void>;
        /**
         * 移除文本图层
         * @param {LayerId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function removeTextLayer(params: {
            /**
             * 图层id
             */
            layerId: string;
        }): Promise<void>;
        /**
         * 启用背景分离
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function enableBackgroundSegmentation(): Promise<void>;
        /**
         * 启用背景分离
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function enableBackgroundSegmentation(): Promise<void>;
        /**
         * 禁用背景分离
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function disableBackgroundSegmentation(): Promise<void>;
        /**
         * 禁用背景分离
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function disableBackgroundSegmentation(): Promise<void>;
        /**
         * 创建白板参数
         * @edata
         * @typedef {Object} WBParams
         * @property {string} type 白板类型, EXTRA-独立白板, EXE-EXE白板, NORMAL-普通白板
         * @property {string} [wbName] 业务传入的白板标识
         * @property {number} offsetX 相对推流出去的界面左侧的偏移量（单位是像素）
         * @property {number} offsetY 相对推流出去的界面顶部的偏移量（单位是像素）
         * @property {number} canvasWidth 推流出去的界面里白板图层占的宽度（单位是像素）
         * @property {number} canvasHeight 推流出去的界面里白板图层占的高度（单位是像素
         * @property {number} x 白板左侧偏移量（单位是像素
         * @property {number} y 白板顶部偏移量（单位是像素）
         * @property {number} width 白板区域宽度（单位是像素）
         * @property {number} height 白板高度（单位是像素）
         * @property {boolean} [force] 强制使用当前配置
         * @property {Object} [param] 参数
         */
        /**
         * 创建白板
         * @eapi
         * @param {WBParams} params 创建白板参数
         * @returns {Promise<WhiteBoardInfo>} 调用结果
         */
        export function createWB(params: {
            /**
             * 白板类型, EXTRA-独立白板, EXE-EXE白板, NORMAL-普通白板
             */
            type: string;
            /**
             * 业务传入的白板标识
             */
            wbName?: string;
            /**
             * 相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里白板图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里白板图层占的高度（单位是像素
             */
            canvasHeight: number;
            /**
             * 白板左侧偏移量（单位是像素
             */
            x: number;
            /**
             * 白板顶部偏移量（单位是像素）
             */
            y: number;
            /**
             * 白板区域宽度（单位是像素）
             */
            width: number;
            /**
             * 白板高度（单位是像素）
             */
            height: number;
            /**
             * 强制使用当前配置
             */
            force?: boolean;
            /**
             * 参数
             */
            param?: Object;
        }): Promise<{
            /**
             * 白板ID
             */
            wbId: string;
        }>;
        /**
         * 创建白板参数
         * @edata
         * @typedef {Object} WBParams
         * @property {string} type 白板类型, EXTRA-独立白板, EXE-EXE白板, NORMAL-普通白板
         * @property {string} [wbName] 业务传入的白板标识
         * @property {number} offsetX 相对推流出去的界面左侧的偏移量（单位是像素）
         * @property {number} offsetY 相对推流出去的界面顶部的偏移量（单位是像素）
         * @property {number} canvasWidth 推流出去的界面里白板图层占的宽度（单位是像素）
         * @property {number} canvasHeight 推流出去的界面里白板图层占的高度（单位是像素
         * @property {number} x 白板左侧偏移量（单位是像素
         * @property {number} y 白板顶部偏移量（单位是像素）
         * @property {number} width 白板区域宽度（单位是像素）
         * @property {number} height 白板高度（单位是像素）
         * @property {boolean} [force] 强制使用当前配置
         * @property {Object} [param] 参数
         */
        /**
         * 创建白板
         * @eapi
         * @param {WBParams} params 创建白板参数
         * @returns {Promise<WhiteBoardInfo>} 调用结果
         */
        export function createWB(params: {
            /**
             * 白板类型, EXTRA-独立白板, EXE-EXE白板, NORMAL-普通白板
             */
            type: string;
            /**
             * 业务传入的白板标识
             */
            wbName?: string;
            /**
             * 相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里白板图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里白板图层占的高度（单位是像素
             */
            canvasHeight: number;
            /**
             * 白板左侧偏移量（单位是像素
             */
            x: number;
            /**
             * 白板顶部偏移量（单位是像素）
             */
            y: number;
            /**
             * 白板区域宽度（单位是像素）
             */
            width: number;
            /**
             * 白板高度（单位是像素）
             */
            height: number;
            /**
             * 强制使用当前配置
             */
            force?: boolean;
            /**
             * 参数
             */
            param?: Object;
        }): Promise<{
            /**
             * 白板ID
             */
            wbId: string;
        }>;
        /**
         * 删除白板
         * @eapi
         * @param {WhiteBoardInfo} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function deleteWB(params: {
            /**
             * 白板ID
             */
            wbId: string;
        }): Promise<void>;
        /**
         * 删除白板
         * @eapi
         * @param {WhiteBoardInfo} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function deleteWB(params: {
            /**
             * 白板ID
             */
            wbId: string;
        }): Promise<void>;
        /**
         * 白板布局数据
         * @edata
         * @typedef {Object} WBLayoutInfo
         * @property {number} offsetX 相对推流出去的界面左侧的偏移量（PC主播端单位是像素，助手单位是点）
         * @property {number} offsetY 相对推流出去的界面顶部的偏移量（PC主播端单位是像素，助手单位是点）
         * @property {number} canvasWidth 推流出去的界面里白板图层占的宽度（PC主播端单位是像素，助手单位是点）
         * @property {number} canvasHeight 推流出去的界面里白板图层占的高度（PC主播端单位是像素，助手单位是点）
         */
        /**
         * 白板布局变化信息
         * @edata
         * @typedef {Object} ChangedLayoutInfo
         * @property {WBLayoutInfo} data 布局数据
         */
        /**
         * 白板布局变化回调
         * @edata
         * @callback WBLayoutChangeCallback
         * @param {ChangedLayoutInfo} layoutInfo 布局信息
         */
        /**
         * 监听参数
         * @edata
         * @typedef {Object} WBLayoutChangeParams
         * @property {string} wbId 白板id
         * @property {string} [wbName] 业务传入的白板标识
         * @property {WBLayoutChangeCallback} callback 回调函数
         */
        /**
         * 监听白板布局变化消息
         * @eapi
         * @param {WBLayoutChangeParams} params 监听参数
         * @returns {Promise<void>} 调用结果
         */
        export function onWBLayoutChange(params: {
            /**
             * 白板id
             */
            wbId: string;
            /**
             * 业务传入的白板标识
             */
            wbName?: string;
            /**
             * 回调函数
             */
            callback: (layoutInfo: {
                /**
                 * 布局数据
                 */
                data: {
                    /**
                     * 相对推流出去的界面左侧的偏移量（PC主播端单位是像素，助手单位是点）
                     */
                    offsetX: number;
                    /**
                     * 相对推流出去的界面顶部的偏移量（PC主播端单位是像素，助手单位是点）
                     */
                    offsetY: number;
                    /**
                     * 推流出去的界面里白板图层占的宽度（PC主播端单位是像素，助手单位是点）
                     */
                    canvasWidth: number;
                    /**
                     * 推流出去的界面里白板图层占的高度（PC主播端单位是像素，助手单位是点）
                     */
                    canvasHeight: number;
                };
            }) => any;
        }): Promise<void>;
        /**
         * 白板布局数据
         * @edata
         * @typedef {Object} WBLayoutInfo
         * @property {number} offsetX 相对推流出去的界面左侧的偏移量（PC主播端单位是像素，助手单位是点）
         * @property {number} offsetY 相对推流出去的界面顶部的偏移量（PC主播端单位是像素，助手单位是点）
         * @property {number} canvasWidth 推流出去的界面里白板图层占的宽度（PC主播端单位是像素，助手单位是点）
         * @property {number} canvasHeight 推流出去的界面里白板图层占的高度（PC主播端单位是像素，助手单位是点）
         */
        /**
         * 白板布局变化信息
         * @edata
         * @typedef {Object} ChangedLayoutInfo
         * @property {WBLayoutInfo} data 布局数据
         */
        /**
         * 白板布局变化回调
         * @edata
         * @callback WBLayoutChangeCallback
         * @param {ChangedLayoutInfo} layoutInfo 布局信息
         */
        /**
         * 监听参数
         * @edata
         * @typedef {Object} WBLayoutChangeParams
         * @property {string} wbId 白板id
         * @property {string} [wbName] 业务传入的白板标识
         * @property {WBLayoutChangeCallback} callback 回调函数
         */
        /**
         * 监听白板布局变化消息
         * @eapi
         * @param {WBLayoutChangeParams} params 监听参数
         * @returns {Promise<void>} 调用结果
         */
        export function onWBLayoutChange(params: {
            /**
             * 白板id
             */
            wbId: string;
            /**
             * 业务传入的白板标识
             */
            wbName?: string;
            /**
             * 回调函数
             */
            callback: (layoutInfo: {
                /**
                 * 布局数据
                 */
                data: {
                    /**
                     * 相对推流出去的界面左侧的偏移量（PC主播端单位是像素，助手单位是点）
                     */
                    offsetX: number;
                    /**
                     * 相对推流出去的界面顶部的偏移量（PC主播端单位是像素，助手单位是点）
                     */
                    offsetY: number;
                    /**
                     * 推流出去的界面里白板图层占的宽度（PC主播端单位是像素，助手单位是点）
                     */
                    canvasWidth: number;
                    /**
                     * 推流出去的界面里白板图层占的高度（PC主播端单位是像素，助手单位是点）
                     */
                    canvasHeight: number;
                };
            }) => any;
        }): Promise<void>;
        /**
         * 更新白板参数
         * @edata
         * @typedef {Object} ChangeWBParams
         * @property {string} wbId 白板id
         * @property {string} [wbName] 业务传入的白板标识
         * @property {number} offsetX 相对推流出去的界面左侧的偏移量(单位是像素)
         * @property {number} offsetY 相对推流出去的界面顶部的偏移量(单位是像素)
         * @property {number} canvasWidth 推流出去的界面里白板图层占的宽度(单位是像素)
         * @property {number} canvasHeight 推流出去的界面里白板图层占的高度(单位是像素)
         */
        /**
         * 更新白板
         * @eapi
         * @param {ChangeWBParams} params 更新参数
         * @returns {Promise<void>} 调用结果
         */
        export function updateWB(params: {
            /**
             * 白板id
             */
            wbId: string;
            /**
             * 业务传入的白板标识
             */
            wbName?: string;
            /**
             * 相对推流出去的界面左侧的偏移量(单位是像素)
             */
            offsetX: number;
            /**
             * 相对推流出去的界面顶部的偏移量(单位是像素)
             */
            offsetY: number;
            /**
             * 推流出去的界面里白板图层占的宽度(单位是像素)
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里白板图层占的高度(单位是像素)
             */
            canvasHeight: number;
        }): Promise<void>;
        /**
         * 更新白板参数
         * @edata
         * @typedef {Object} ChangeWBParams
         * @property {string} wbId 白板id
         * @property {string} [wbName] 业务传入的白板标识
         * @property {number} offsetX 相对推流出去的界面左侧的偏移量(单位是像素)
         * @property {number} offsetY 相对推流出去的界面顶部的偏移量(单位是像素)
         * @property {number} canvasWidth 推流出去的界面里白板图层占的宽度(单位是像素)
         * @property {number} canvasHeight 推流出去的界面里白板图层占的高度(单位是像素)
         */
        /**
         * 更新白板
         * @eapi
         * @param {ChangeWBParams} params 更新参数
         * @returns {Promise<void>} 调用结果
         */
        export function updateWB(params: {
            /**
             * 白板id
             */
            wbId: string;
            /**
             * 业务传入的白板标识
             */
            wbName?: string;
            /**
             * 相对推流出去的界面左侧的偏移量(单位是像素)
             */
            offsetX: number;
            /**
             * 相对推流出去的界面顶部的偏移量(单位是像素)
             */
            offsetY: number;
            /**
             * 推流出去的界面里白板图层占的宽度(单位是像素)
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里白板图层占的高度(单位是像素)
             */
            canvasHeight: number;
        }): Promise<void>;
        /**
         * 图层布局改变回调
         * @edata
         * @callback LayerLayoutChangeCallback
         * @param {LayerInfo} layoutInfo 布局信息
         */
        /**
         * 布局改变参数
         * @edata
         * @typedef {Object} LayerLayoutChangeParams
         * @property {string} layerId 图层id
         * @property {LayerLayoutChangeCallback} callback 回调函数
         */
        /**
         * 布局改变
         * @eapi
         * @param {LayerLayoutChangeParams} params 布局改变参数
         * @returns {Promise<void>} 调用结果
         */
        export function onLayerLayoutChange(params: {
            /**
             * 图层id
             */
            layerId: string;
            /**
             * 回调函数
             */
            callback: (layoutInfo: {
                /**
                 * 图层id
                 */
                layerId: string;
                /**
                 * 图层类型
                 */
                type: string;
                /**
                 * 业务传入的图层标识
                 */
                layerName: string;
                /**
                 * 图层相对推流出去的界面左侧的偏移量（单位是像素）
                 */
                offsetX: number;
                /**
                 * 图层相对推流出去的界面顶部的偏移量（单位是像素）
                 */
                offsetY: number;
                /**
                 * 推流出去的界面里图层占的宽度（单位是像素）
                 */
                canvasWidth: number;
                /**
                 * 推流出去的界面里图层占的高度（单位是像素）
                 */
                canvasHeight: number;
                /**
                 * 权重
                 */
                weight: number;
                /**
                 * 参数
                 */
                param: Object;
            }) => any;
        }): Promise<void>;
        /**
         * 图层布局改变回调
         * @edata
         * @callback LayerLayoutChangeCallback
         * @param {LayerInfo} layoutInfo 布局信息
         */
        /**
         * 布局改变参数
         * @edata
         * @typedef {Object} LayerLayoutChangeParams
         * @property {string} layerId 图层id
         * @property {LayerLayoutChangeCallback} callback 回调函数
         */
        /**
         * 布局改变
         * @eapi
         * @param {LayerLayoutChangeParams} params 布局改变参数
         * @returns {Promise<void>} 调用结果
         */
        export function onLayerLayoutChange(params: {
            /**
             * 图层id
             */
            layerId: string;
            /**
             * 回调函数
             */
            callback: (layoutInfo: {
                /**
                 * 图层id
                 */
                layerId: string;
                /**
                 * 图层类型
                 */
                type: string;
                /**
                 * 业务传入的图层标识
                 */
                layerName: string;
                /**
                 * 图层相对推流出去的界面左侧的偏移量（单位是像素）
                 */
                offsetX: number;
                /**
                 * 图层相对推流出去的界面顶部的偏移量（单位是像素）
                 */
                offsetY: number;
                /**
                 * 推流出去的界面里图层占的宽度（单位是像素）
                 */
                canvasWidth: number;
                /**
                 * 推流出去的界面里图层占的高度（单位是像素）
                 */
                canvasHeight: number;
                /**
                 * 权重
                 */
                weight: number;
                /**
                 * 参数
                 */
                param: Object;
            }) => any;
        }): Promise<void>;
        /**
         * 布局信息
         * @edata
         * @typedef {Object} StreamLayoutInfo
         * @property {number} width 宽度（单位是像素)
         * @property {number} height 高度（单位是像素）
         * @property {number} x 普通白板的左上角横坐标
         * @property {number} y 普通白板的左上角纵坐标
         */
        /**
         * 获取图层画布布局信息
         * @summary 适用于获取颜值PK时视频区域相对于小程序容器的布局信息
         * @eapi
         * @returns {Promise<StreamLayoutInfo>} 调用结果
         */
        export function getStreamCanvasLayout(): Promise<{
            /**
             * 宽度（单位是像素)
             */
            width: number;
            /**
             * 高度（单位是像素）
             */
            height: number;
            /**
             * 普通白板的左上角横坐标
             */
            x: number;
            /**
             * 普通白板的左上角纵坐标
             */
            y: number;
        }>;
        /**
         * 布局信息
         * @edata
         * @typedef {Object} StreamLayoutInfo
         * @property {number} width 宽度（单位是像素)
         * @property {number} height 高度（单位是像素）
         * @property {number} x 普通白板的左上角横坐标
         * @property {number} y 普通白板的左上角纵坐标
         */
        /**
         * 获取图层画布布局信息
         * @summary 适用于获取颜值PK时视频区域相对于小程序容器的布局信息
         * @eapi
         * @returns {Promise<StreamLayoutInfo>} 调用结果
         */
        export function getStreamCanvasLayout(): Promise<{
            /**
             * 宽度（单位是像素)
             */
            width: number;
            /**
             * 高度（单位是像素）
             */
            height: number;
            /**
             * 普通白板的左上角横坐标
             */
            x: number;
            /**
             * 普通白板的左上角纵坐标
             */
            y: number;
        }>;
        /**
         * 设置图层画布布局信息
         * @summary 适用于设置颜值PK时视频区域相对于小程序容器的布局信息
         * @eapi
         * @param {StreamLayoutInfo} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function setStreamCanvasLayout(params: {
            /**
             * 宽度（单位是像素)
             */
            width: number;
            /**
             * 高度（单位是像素）
             */
            height: number;
            /**
             * 普通白板的左上角横坐标
             */
            x: number;
            /**
             * 普通白板的左上角纵坐标
             */
            y: number;
        }): Promise<void>;
        /**
         * 设置图层画布布局信息
         * @summary 适用于设置颜值PK时视频区域相对于小程序容器的布局信息
         * @eapi
         * @param {StreamLayoutInfo} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function setStreamCanvasLayout(params: {
            /**
             * 宽度（单位是像素)
             */
            width: number;
            /**
             * 高度（单位是像素）
             */
            height: number;
            /**
             * 普通白板的左上角横坐标
             */
            x: number;
            /**
             * 普通白板的左上角纵坐标
             */
            y: number;
        }): Promise<void>;
        /**
         * 创建图层
         * @eapi
         * @param {LayerInfo} params 图层信息
         * @returns {Promise<LayerId>} 调用结果
         */
        export function addLayer(params: {
            /**
             * 图层id
             */
            layerId: string;
            /**
             * 图层类型
             */
            type: string;
            /**
             * 业务传入的图层标识
             */
            layerName: string;
            /**
             * 图层相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 图层相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里图层占的高度（单位是像素）
             */
            canvasHeight: number;
            /**
             * 权重
             */
            weight: number;
            /**
             * 参数
             */
            param: Object;
        }): Promise<{
            /**
             * 图层id
             */
            layerId: string;
        }>;
        /**
         * 创建图层
         * @eapi
         * @param {LayerInfo} params 图层信息
         * @returns {Promise<LayerId>} 调用结果
         */
        export function addLayer(params: {
            /**
             * 图层id
             */
            layerId: string;
            /**
             * 图层类型
             */
            type: string;
            /**
             * 业务传入的图层标识
             */
            layerName: string;
            /**
             * 图层相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 图层相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里图层占的高度（单位是像素）
             */
            canvasHeight: number;
            /**
             * 权重
             */
            weight: number;
            /**
             * 参数
             */
            param: Object;
        }): Promise<{
            /**
             * 图层id
             */
            layerId: string;
        }>;
        /**
         * 更新图层
         * @summary 视频图层暂不支持
         * @eapi
         * @param {LayerInfoParam|LayerId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function updateLayer(params: {
            /**
             * 图层类型, PK-PK图层(默认), IMAGE-图片图层, VIDEO-视频图层
             */
            type: string;
            /**
             * 业务传入的图层标识
             */
            layerName?: string;
            /**
             * 图层相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 图层相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里图层占的高度（单位是像素）
             */
            canvasHeight: number;
            /**
             * 权重
             */
            weight?: number;
            /**
             * 强制使用当前配置
             */
            force?: boolean;
            /**
             * 参数
             */
            param?: Object;
        } | {
            /**
             * 图层id
             */
            layerId: string;
        }): Promise<void>;
        /**
         * 更新图层
         * @summary 视频图层暂不支持
         * @eapi
         * @param {LayerInfoParam|LayerId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function updateLayer(params: {
            /**
             * 图层类型, PK-PK图层(默认), IMAGE-图片图层, VIDEO-视频图层
             */
            type: string;
            /**
             * 业务传入的图层标识
             */
            layerName?: string;
            /**
             * 图层相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 图层相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里图层占的高度（单位是像素）
             */
            canvasHeight: number;
            /**
             * 权重
             */
            weight?: number;
            /**
             * 强制使用当前配置
             */
            force?: boolean;
            /**
             * 参数
             */
            param?: Object;
        } | {
            /**
             * 图层id
             */
            layerId: string;
        }): Promise<void>;
        /**
         * 删除图层
         * @eapi
         * @param {LayerId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function removeLayer(params: {
            /**
             * 图层id
             */
            layerId: string;
        }): Promise<void>;
        /**
         * 删除图层
         * @eapi
         * @param {LayerId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function removeLayer(params: {
            /**
             * 图层id
             */
            layerId: string;
        }): Promise<void>;
        /**
         * 特效信息
         * @edata
         * @typedef {Object} EffectParams
         * @property {string} md5 资源的md5
         * @property {string} fileName 文件名
         * @property {Object} [param] 额外参数
         */
        /**
         * 增加特效
         * @eapi
         * @param {EffectParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function addEffect(params: {
            /**
             * 资源的md5
             */
            md5: string;
            /**
             * 文件名
             */
            fileName: string;
            /**
             * 额外参数
             */
            param?: Object;
        }): Promise<void>;
        /**
         * 特效信息
         * @edata
         * @typedef {Object} EffectParams
         * @property {string} md5 资源的md5
         * @property {string} fileName 文件名
         * @property {Object} [param] 额外参数
         */
        /**
         * 增加特效
         * @eapi
         * @param {EffectParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function addEffect(params: {
            /**
             * 资源的md5
             */
            md5: string;
            /**
             * 文件名
             */
            fileName: string;
            /**
             * 额外参数
             */
            param?: Object;
        }): Promise<void>;
        /**
         * 移除资源参数
         * @edata
         * @typedef {Object} RemoveEffectParams
         * @property {string} md5 资源的md5
         * @property {string} fileName 文件名
         */
        /**
         * 移除特效
         * @eapi
         * @param {RemoveEffectParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function removeEffect(params: {
            /**
             * 资源的md5
             */
            md5: string;
            /**
             * 文件名
             */
            fileName: string;
        }): Promise<void>;
        /**
         * 移除资源参数
         * @edata
         * @typedef {Object} RemoveEffectParams
         * @property {string} md5 资源的md5
         * @property {string} fileName 文件名
         */
        /**
         * 移除特效
         * @eapi
         * @param {RemoveEffectParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function removeEffect(params: {
            /**
             * 资源的md5
             */
            md5: string;
            /**
             * 文件名
             */
            fileName: string;
        }): Promise<void>;
        /**
         * 麦克风信息
         * @edata
         * @typedef {Object} MicInfo
         * @property {boolean} isOn 是否打开
         * @property {number} volume 音量
         */
        /**
         * 扬声器信息
         * @edata
         * @typedef {Object} SpeakerInfo
         * @property {boolean} isOn 是否打开
         * @property {number} volume 音量
         */
        /**
         * 伴奏信息
         * @edata
         * @typedef {Object} MusicInfo
         * @property {boolean} isOn 是否打开
         * @property {number} volume 音量
         */
        /**
         * 可见性信息
         * @edata
         * @typedef {Object} AccessibilityInfo
         * @property {boolean} isPrivate 是否打开隐私模式
         * @property {boolean} isPassword 是否打开加密模式
         */
        /**
         * 镜头信息
         * @edata
         * @typedef {Object} CameraInfo
         * @property {boolean} isOn 摄像头是否打开
         * @property {boolean} isFlip 是否开启翻转(仅PC主播端支持)
         * @property {boolean} isSplitScreen 是否开启分屏(仅PC主播端支持)
         * @property {boolean} isRhythm 是否开启律动(仅PC主播端支持)
         */
        /**
         * 特效信息
         * @edata
         * @typedef {Object} EffectInfo
         * @property {number} id id
         * @property {string} name name
         * @property {number} tab_id tab_id
         * @property {string} tab_name tab_name
         */
        /**
         * 特效信息列表
         * @edata
         * @typedef {Object} EffectListInfo
         * @property {boolean} isOn 特效是否打开
         * @property {Array.<EffectInfo>} effectList 特效信息列表
         */
        /**
         * 分辨率信息
         * @edata
         * @typedef {Object} ResolutionInfo
         * @property {number} width 横向分辨率(单位是像素)
         * @property {number} height 纵向分辨率(单位是像素)
         */
        /**
         * 画质信息
         * @edata
         * @typedef {Object} QualityInfo
         * @property {number} bitRate 码率
         * @property {number} frameRate 帧率
         * @property {ResolutionInfo} resolution 分辨率信息
         */
        /**
         * 延迟信息
         * @edata
         * @typedef {Object} DelayInfo
         * @property {number} delayTime 延迟时间(单位是秒)
         */
        /**
         * 开播信息
         * @edata
         * @typedef {Object} StreamingInfo
         * @property {MicInfo} mic 麦克风信息
         * @property {SpeakerInfo} speaker 扬声器信息（仅PC主播端支持）
         * @property {MusicInfo} music 伴奏信息
         * @property {AccessibilityInfo} accessibility 可见性信息
         * @property {CameraInfo} camera 镜头信息
         * @property {EffectListInfo} effect 特效信息
         * @property {QualityInfo} quality 画质信息
         * @property {DelayInfo} delay 延迟信息（仅PC主播端支持）
         */
        /**
         * 获取开播信息参数
         * @edata
         * @typedef {Object} StreamingInfoParams
         * @property {Array.<string>} keys 查询的关键字
         */
        /**
         * 获取开播信息
         * @eapi
         * @summary 各个端支持的信息字段有差异
         * - 如果某个端没有指定的信息，则返回null
         * - 传入对应的key值返回对应的value值
         * @param {StreamingInfoParams} params 参数
         * @returns {Promise<StreamingInfo>} 调用结果
         */
        export function getStreamingInfo(params: {
            /**
             * 查询的关键字
             */
            keys: string[];
        }): Promise<{
            /**
             * 麦克风信息
             */
            mic: {
                /**
                 * 是否打开
                 */
                isOn: boolean;
                /**
                 * 音量
                 */
                volume: number;
            };
            /**
             * 扬声器信息（仅PC主播端支持）
             */
            speaker: {
                /**
                 * 是否打开
                 */
                isOn: boolean;
                /**
                 * 音量
                 */
                volume: number;
            };
            /**
             * 伴奏信息
             */
            music: {
                /**
                 * 是否打开
                 */
                isOn: boolean;
                /**
                 * 音量
                 */
                volume: number;
            };
            /**
             * 可见性信息
             */
            accessibility: {
                /**
                 * 是否打开隐私模式
                 */
                isPrivate: boolean;
                /**
                 * 是否打开加密模式
                 */
                isPassword: boolean;
            };
            /**
             * 镜头信息
             */
            camera: {
                /**
                 * 摄像头是否打开
                 */
                isOn: boolean;
                /**
                 * 是否开启翻转(仅PC主播端支持)
                 */
                isFlip: boolean;
                /**
                 * 是否开启分屏(仅PC主播端支持)
                 */
                isSplitScreen: boolean;
                /**
                 * 是否开启律动(仅PC主播端支持)
                 */
                isRhythm: boolean;
            };
            /**
             * 特效信息
             */
            effect: {
                /**
                 * 特效是否打开
                 */
                isOn: boolean;
                /**
                 * 特效信息列表
                 */
                effectList: {
                    /**
                     * id
                     */
                    id: number;
                    /**
                     * name
                     */
                    name: string;
                    /**
                     * tab_id
                     */
                    tab_id: number;
                    /**
                     * tab_name
                     */
                    tab_name: string;
                }[];
            };
            /**
             * 画质信息
             */
            quality: {
                /**
                 * 码率
                 */
                bitRate: number;
                /**
                 * 帧率
                 */
                frameRate: number;
                /**
                 * 分辨率信息
                 */
                resolution: {
                    /**
                     * 横向分辨率(单位是像素)
                     */
                    width: number;
                    /**
                     * 纵向分辨率(单位是像素)
                     */
                    height: number;
                };
            };
            /**
             * 延迟信息（仅PC主播端支持）
             */
            delay: {
                /**
                 * 延迟时间(单位是秒)
                 */
                delayTime: number;
            };
        }>;
        /**
         * 麦克风信息
         * @edata
         * @typedef {Object} MicInfo
         * @property {boolean} isOn 是否打开
         * @property {number} volume 音量
         */
        /**
         * 扬声器信息
         * @edata
         * @typedef {Object} SpeakerInfo
         * @property {boolean} isOn 是否打开
         * @property {number} volume 音量
         */
        /**
         * 伴奏信息
         * @edata
         * @typedef {Object} MusicInfo
         * @property {boolean} isOn 是否打开
         * @property {number} volume 音量
         */
        /**
         * 可见性信息
         * @edata
         * @typedef {Object} AccessibilityInfo
         * @property {boolean} isPrivate 是否打开隐私模式
         * @property {boolean} isPassword 是否打开加密模式
         */
        /**
         * 镜头信息
         * @edata
         * @typedef {Object} CameraInfo
         * @property {boolean} isOn 摄像头是否打开
         * @property {boolean} isFlip 是否开启翻转(仅PC主播端支持)
         * @property {boolean} isSplitScreen 是否开启分屏(仅PC主播端支持)
         * @property {boolean} isRhythm 是否开启律动(仅PC主播端支持)
         */
        /**
         * 特效信息
         * @edata
         * @typedef {Object} EffectInfo
         * @property {number} id id
         * @property {string} name name
         * @property {number} tab_id tab_id
         * @property {string} tab_name tab_name
         */
        /**
         * 特效信息列表
         * @edata
         * @typedef {Object} EffectListInfo
         * @property {boolean} isOn 特效是否打开
         * @property {Array.<EffectInfo>} effectList 特效信息列表
         */
        /**
         * 分辨率信息
         * @edata
         * @typedef {Object} ResolutionInfo
         * @property {number} width 横向分辨率(单位是像素)
         * @property {number} height 纵向分辨率(单位是像素)
         */
        /**
         * 画质信息
         * @edata
         * @typedef {Object} QualityInfo
         * @property {number} bitRate 码率
         * @property {number} frameRate 帧率
         * @property {ResolutionInfo} resolution 分辨率信息
         */
        /**
         * 延迟信息
         * @edata
         * @typedef {Object} DelayInfo
         * @property {number} delayTime 延迟时间(单位是秒)
         */
        /**
         * 开播信息
         * @edata
         * @typedef {Object} StreamingInfo
         * @property {MicInfo} mic 麦克风信息
         * @property {SpeakerInfo} speaker 扬声器信息（仅PC主播端支持）
         * @property {MusicInfo} music 伴奏信息
         * @property {AccessibilityInfo} accessibility 可见性信息
         * @property {CameraInfo} camera 镜头信息
         * @property {EffectListInfo} effect 特效信息
         * @property {QualityInfo} quality 画质信息
         * @property {DelayInfo} delay 延迟信息（仅PC主播端支持）
         */
        /**
         * 获取开播信息参数
         * @edata
         * @typedef {Object} StreamingInfoParams
         * @property {Array.<string>} keys 查询的关键字
         */
        /**
         * 获取开播信息
         * @eapi
         * @summary 各个端支持的信息字段有差异
         * - 如果某个端没有指定的信息，则返回null
         * - 传入对应的key值返回对应的value值
         * @param {StreamingInfoParams} params 参数
         * @returns {Promise<StreamingInfo>} 调用结果
         */
        export function getStreamingInfo(params: {
            /**
             * 查询的关键字
             */
            keys: string[];
        }): Promise<{
            /**
             * 麦克风信息
             */
            mic: {
                /**
                 * 是否打开
                 */
                isOn: boolean;
                /**
                 * 音量
                 */
                volume: number;
            };
            /**
             * 扬声器信息（仅PC主播端支持）
             */
            speaker: {
                /**
                 * 是否打开
                 */
                isOn: boolean;
                /**
                 * 音量
                 */
                volume: number;
            };
            /**
             * 伴奏信息
             */
            music: {
                /**
                 * 是否打开
                 */
                isOn: boolean;
                /**
                 * 音量
                 */
                volume: number;
            };
            /**
             * 可见性信息
             */
            accessibility: {
                /**
                 * 是否打开隐私模式
                 */
                isPrivate: boolean;
                /**
                 * 是否打开加密模式
                 */
                isPassword: boolean;
            };
            /**
             * 镜头信息
             */
            camera: {
                /**
                 * 摄像头是否打开
                 */
                isOn: boolean;
                /**
                 * 是否开启翻转(仅PC主播端支持)
                 */
                isFlip: boolean;
                /**
                 * 是否开启分屏(仅PC主播端支持)
                 */
                isSplitScreen: boolean;
                /**
                 * 是否开启律动(仅PC主播端支持)
                 */
                isRhythm: boolean;
            };
            /**
             * 特效信息
             */
            effect: {
                /**
                 * 特效是否打开
                 */
                isOn: boolean;
                /**
                 * 特效信息列表
                 */
                effectList: {
                    /**
                     * id
                     */
                    id: number;
                    /**
                     * name
                     */
                    name: string;
                    /**
                     * tab_id
                     */
                    tab_id: number;
                    /**
                     * tab_name
                     */
                    tab_name: string;
                }[];
            };
            /**
             * 画质信息
             */
            quality: {
                /**
                 * 码率
                 */
                bitRate: number;
                /**
                 * 帧率
                 */
                frameRate: number;
                /**
                 * 分辨率信息
                 */
                resolution: {
                    /**
                     * 横向分辨率(单位是像素)
                     */
                    width: number;
                    /**
                     * 纵向分辨率(单位是像素)
                     */
                    height: number;
                };
            };
            /**
             * 延迟信息（仅PC主播端支持）
             */
            delay: {
                /**
                 * 延迟时间(单位是秒)
                 */
                delayTime: number;
            };
        }>;
        /**
         * 是否启用白板编辑模式参数
         * @edata
         * @typedef {Object} SetWBEditModeParams
         * @property {boolean} enable 是否启用
         */
        /**
         * 设置是否启用白板编辑模式
         * @eapi
         * @param {SetWBEditModeParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function setWBEditMode(params: {
            /**
             * 是否启用
             */
            enable: boolean;
        }): Promise<void>;
        /**
         * 是否启用白板编辑模式参数
         * @edata
         * @typedef {Object} SetWBEditModeParams
         * @property {boolean} enable 是否启用
         */
        /**
         * 设置是否启用白板编辑模式
         * @eapi
         * @param {SetWBEditModeParams} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function setWBEditMode(params: {
            /**
             * 是否启用
             */
            enable: boolean;
        }): Promise<void>;
        /**
         * 当前特效信息
         * @edata
         * @typedef {Object} CurrentEffectInfo
         * @property {string} md5 资源的md5
         * @property {string} fileName 文件名
         * @property {Object} param 额外参数
         */
        /**
         * 获取当前特效列表
         * @eapi
         * @returns {Promise<Array.<CurrentEffectInfo>>} 当前应用的特效列表
         */
        export function getCurrentEffects(params: any): Promise<{
            /**
             * 资源的md5
             */
            md5: string;
            /**
             * 文件名
             */
            fileName: string;
            /**
             * 额外参数
             */
            param: Object;
        }[]>;
        /**
         * 当前特效信息
         * @edata
         * @typedef {Object} CurrentEffectInfo
         * @property {string} md5 资源的md5
         * @property {string} fileName 文件名
         * @property {Object} param 额外参数
         */
        /**
         * 获取当前特效列表
         * @eapi
         * @returns {Promise<Array.<CurrentEffectInfo>>} 当前应用的特效列表
         */
        export function getCurrentEffects(params: any): Promise<{
            /**
             * 资源的md5
             */
            md5: string;
            /**
             * 文件名
             */
            fileName: string;
            /**
             * 额外参数
             */
            param: Object;
        }[]>;
        /**
         * pk连麦图层布局信息
         * @edata
         * @typedef {Object} LinkLayerLayout
         * @property {number} offsetX 图层相对推流出去的界面左侧的偏移量（单位是像素）
         * @property {number} offsetY 图层相对推流出去的界面顶部的偏移量（单位是像素）
         * @property {number} canvasWidth 推流出去的界面里图层占的宽度（单位是像素）
         * @property {number} canvasHeight 推流出去的界面里图层占的高度（单位是像素）
         */
        /**
         * 获取PK连麦的视频图层布局信息
         * @eapi
         * @returns {Promise<Array.<LinkLayerLayout>>} 返回布局信息
         */
        export function getLinkLayersLayout(): Promise<{
            /**
             * 图层相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 图层相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里图层占的高度（单位是像素）
             */
            canvasHeight: number;
        }[]>;
        /**
         * pk连麦图层布局信息
         * @edata
         * @typedef {Object} LinkLayerLayout
         * @property {number} offsetX 图层相对推流出去的界面左侧的偏移量（单位是像素）
         * @property {number} offsetY 图层相对推流出去的界面顶部的偏移量（单位是像素）
         * @property {number} canvasWidth 推流出去的界面里图层占的宽度（单位是像素）
         * @property {number} canvasHeight 推流出去的界面里图层占的高度（单位是像素）
         */
        /**
         * 获取PK连麦的视频图层布局信息
         * @eapi
         * @returns {Promise<Array.<LinkLayerLayout>>} 返回布局信息
         */
        export function getLinkLayersLayout(): Promise<{
            /**
             * 图层相对推流出去的界面左侧的偏移量（单位是像素）
             */
            offsetX: number;
            /**
             * 图层相对推流出去的界面顶部的偏移量（单位是像素）
             */
            offsetY: number;
            /**
             * 推流出去的界面里图层占的宽度（单位是像素）
             */
            canvasWidth: number;
            /**
             * 推流出去的界面里图层占的高度（单位是像素）
             */
            canvasHeight: number;
        }[]>;
    }
}
export default _default;
