declare namespace _default {
    export namespace view {
        /**
         * 分身信息
         * @edata
         * @typedef {Object} SubViewId
         * @property {string} subViewId 分身Id
         */
        /**
         * 布局信息
         * @edata
         * @typedef {Object} Layout
         * @property {number} width 宽度占位置的比例
         * @property {number} ratio 宽高比
         * @property {number} top 左上角的纵坐标占位置的比例
         * @property {number} left 左上角的横坐标占位置的比例
         */
        /**
         * 创建分身参数
         * @edata
         * @typedef {Object} SubViewParams
         * @property {string} position 位置, player-视频区, chatroom-公屏
         * @property {Layout} layout 布局信息
         * @property {number} [level] 层级
         * @property {number} [weight] 权重
         * @property {Object} [param] 初始化参数
         */
        /**
         * 创建分身
         * @eapi
         * @param {SubViewParams} params 创建分身参数
         * @returns {Promise<SubViewId>} 调用结果
         */
        export function createSubView(params: {
            /**
             * 位置, player-视频区, chatroom-公屏
             */
            position: string;
            /**
             * 布局信息
             */
            layout: {
                /**
                 * 宽度占位置的比例
                 */
                width: number;
                /**
                 * 宽高比
                 */
                ratio: number;
                /**
                 * 左上角的纵坐标占位置的比例
                 */
                top: number;
                /**
                 * 左上角的横坐标占位置的比例
                 */
                left: number;
            };
            /**
             * 层级
             */
            level?: number;
            /**
             * 权重
             */
            weight?: number;
            /**
             * 初始化参数
             */
            param?: Object;
        }): Promise<{
            /**
             * 分身Id
             */
            subViewId: string;
        }>;
        /**
         * 分身信息
         * @edata
         * @typedef {Object} SubViewId
         * @property {string} subViewId 分身Id
         */
        /**
         * 布局信息
         * @edata
         * @typedef {Object} Layout
         * @property {number} width 宽度占位置的比例
         * @property {number} ratio 宽高比
         * @property {number} top 左上角的纵坐标占位置的比例
         * @property {number} left 左上角的横坐标占位置的比例
         */
        /**
         * 创建分身参数
         * @edata
         * @typedef {Object} SubViewParams
         * @property {string} position 位置, player-视频区, chatroom-公屏
         * @property {Layout} layout 布局信息
         * @property {number} [level] 层级
         * @property {number} [weight] 权重
         * @property {Object} [param] 初始化参数
         */
        /**
         * 创建分身
         * @eapi
         * @param {SubViewParams} params 创建分身参数
         * @returns {Promise<SubViewId>} 调用结果
         */
        export function createSubView(params: {
            /**
             * 位置, player-视频区, chatroom-公屏
             */
            position: string;
            /**
             * 布局信息
             */
            layout: {
                /**
                 * 宽度占位置的比例
                 */
                width: number;
                /**
                 * 宽高比
                 */
                ratio: number;
                /**
                 * 左上角的纵坐标占位置的比例
                 */
                top: number;
                /**
                 * 左上角的横坐标占位置的比例
                 */
                left: number;
            };
            /**
             * 层级
             */
            level?: number;
            /**
             * 权重
             */
            weight?: number;
            /**
             * 初始化参数
             */
            param?: Object;
        }): Promise<{
            /**
             * 分身Id
             */
            subViewId: string;
        }>;
        /**
         * 销毁分身
         * @param {SubViewId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function destroySubView(params: {
            /**
             * 分身Id
             */
            subViewId: string;
        }): Promise<void>;
        /**
         * 销毁分身
         * @param {SubViewId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function destroySubView(params: {
            /**
             * 分身Id
             */
            subViewId: string;
        }): Promise<void>;
        /**
         * 隐藏当前分身
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function hideCurrentView(): Promise<void>;
        /**
         * 隐藏当前分身
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function hideCurrentView(): Promise<void>;
        /**
         * 隐藏分身
         * @eapi
         * @param {SubViewId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function hideSubView(params: {
            /**
             * 分身Id
             */
            subViewId: string;
        }): Promise<void>;
        /**
         * 隐藏分身
         * @eapi
         * @param {SubViewId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function hideSubView(params: {
            /**
             * 分身Id
             */
            subViewId: string;
        }): Promise<void>;
        /**
         * 显示分身
         * @eapi
         * @param {SubViewId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function showSubView(params: {
            /**
             * 分身Id
             */
            subViewId: string;
        }): Promise<void>;
        /**
         * 显示分身
         * @eapi
         * @param {SubViewId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function showSubView(params: {
            /**
             * 分身Id
             */
            subViewId: string;
        }): Promise<void>;
        /**
         * 弹窗信息
         * @edata
         * @typedef {Object} PopupId
         * @property {string} popupId 弹窗id
         */
        /**
         * 配置参数
         * @edata
         * @typedef {Object} PopupConfig
         * @property {number} handleX handleX
         * @property {number} handleY handleY
         * @property {number} handleWidth handleWidth
         * @property {number} handleHeight handleHeight
         */
        /**
         * 创建浮窗参数
         * @edata
         * @typedef {Object} PopupParams
         * @property {number} width 宽
         * @property {number} height 高
         * @property {PopupConfig} [config] 配置参数
         * @property {Object} [param] 传给弹窗的初始化参数
         */
        /**
         * 创建浮窗
         * @eapi
         * @param {PopupParams} params 创建浮窗参数
         * @returns {Promise<PopupId>} 调用结果
         */
        export function createPopup(params: {
            /**
             * 宽
             */
            width: number;
            /**
             * 高
             */
            height: number;
            /**
             * 配置参数
             */
            config?: {
                /**
                 * handleX
                 */
                handleX: number;
                /**
                 * handleY
                 */
                handleY: number;
                /**
                 * handleWidth
                 */
                handleWidth: number;
                /**
                 * handleHeight
                 */
                handleHeight: number;
            };
            /**
             * 传给弹窗的初始化参数
             */
            param?: Object;
        }): Promise<{
            /**
             * 弹窗id
             */
            popupId: string;
        }>;
        /**
         * 弹窗信息
         * @edata
         * @typedef {Object} PopupId
         * @property {string} popupId 弹窗id
         */
        /**
         * 配置参数
         * @edata
         * @typedef {Object} PopupConfig
         * @property {number} handleX handleX
         * @property {number} handleY handleY
         * @property {number} handleWidth handleWidth
         * @property {number} handleHeight handleHeight
         */
        /**
         * 创建浮窗参数
         * @edata
         * @typedef {Object} PopupParams
         * @property {number} width 宽
         * @property {number} height 高
         * @property {PopupConfig} [config] 配置参数
         * @property {Object} [param] 传给弹窗的初始化参数
         */
        /**
         * 创建浮窗
         * @eapi
         * @param {PopupParams} params 创建浮窗参数
         * @returns {Promise<PopupId>} 调用结果
         */
        export function createPopup(params: {
            /**
             * 宽
             */
            width: number;
            /**
             * 高
             */
            height: number;
            /**
             * 配置参数
             */
            config?: {
                /**
                 * handleX
                 */
                handleX: number;
                /**
                 * handleY
                 */
                handleY: number;
                /**
                 * handleWidth
                 */
                handleWidth: number;
                /**
                 * handleHeight
                 */
                handleHeight: number;
            };
            /**
             * 传给弹窗的初始化参数
             */
            param?: Object;
        }): Promise<{
            /**
             * 弹窗id
             */
            popupId: string;
        }>;
        /**
         * 摧毁浮窗
         * @eapi
         * @param {PopupId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function destroyPopup(params: {
            /**
             * 弹窗id
             */
            popupId: string;
        }): Promise<void>;
        /**
         * 摧毁浮窗
         * @eapi
         * @param {PopupId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function destroyPopup(params: {
            /**
             * 弹窗id
             */
            popupId: string;
        }): Promise<void>;
        /**
         * 隐藏当前浮窗
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function hideCurrentPopup(): Promise<void>;
        /**
         * 隐藏当前浮窗
         * @eapi
         * @returns {Promise<void>} 调用结果
         */
        export function hideCurrentPopup(): Promise<void>;
        /**
         * 隐藏浮窗
         * @eapi
         * @param {PopupId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function hidePopup(params: {
            /**
             * 弹窗id
             */
            popupId: string;
        }): Promise<void>;
        /**
         * 隐藏浮窗
         * @eapi
         * @param {PopupId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function hidePopup(params: {
            /**
             * 弹窗id
             */
            popupId: string;
        }): Promise<void>;
        /**
         * 展示浮窗
         * @eapi
         * @param {PopupId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function showPopup(params: {
            /**
             * 弹窗id
             */
            popupId: string;
        }): Promise<void>;
        /**
         * 展示浮窗
         * @eapi
         * @param {PopupId} params 参数
         * @returns {Promise<void>} 调用结果
         */
        export function showPopup(params: {
            /**
             * 弹窗id
             */
            popupId: string;
        }): Promise<void>;
    }
}
export default _default;
